@@ -5,7 +5,7 @@
 /***********************************************************************/
 /*
  * THE - The Hessling Editor. A text editor similar to VM/CMS xedit.
- * Copyright (C) 1991-1997 Mark Hessling
+ * Copyright (C) 1991-1999 Mark Hessling
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -31,16 +31,14 @@
  * This software is going to be maintained and enhanced as deemed
  * necessary by the community.
  *
- * Mark Hessling                 Email:             M.Hessling@qut.edu.au
- * PO Box 203                    Phone:                    +617 3802 0800
- * Bellara                       http://www.gu.edu.au/gext/the/markh.html
- * QLD 4507                      **** Maintainer PDCurses & REXX/SQL ****
- * Australia                     ************* Author of THE ************
+ * Mark Hessling,  M.Hessling@qut.edu.au  http://www.lightlink.com/hessling/
+ * PO Box 203, Bellara, QLD 4507, AUSTRALIA
+ * Author of THE, a Free XEDIT/KEDIT editor and, Rexx/SQL
+ * Maintainer of PDCurses: Public Domain Curses and, Regina Rexx interpreter
+ * Use Rexx ? join the Rexx Language Association: http://www.rexxla.org
  */
 
-/*
-$Id: comm1.c 2.1 1995/06/24 16:28:44 MH Rel MH $
-*/
+static char RCSid[] = "$Id: comm1.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
 
 #include <the.h>
 #include <proto.h>
@@ -95,8 +93,6 @@ CHARTYPE *params;
 #endif
 /***********************************************************************/
 {
-/*-------------------------- external data ----------------------------*/
- extern bool curses_started;
 /*--------------------------- local data ------------------------------*/
 #define ADD_PARAMS  1
  CHARTYPE *word[ADD_PARAMS+1];
@@ -104,7 +100,7 @@ CHARTYPE *params;
  unsigned short num_params=0;
  LINETYPE num_lines=0L;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("comm1.c:   Add");
 #endif
 /*---------------------------------------------------------------------*/
@@ -122,7 +118,7 @@ CHARTYPE *params;
  if (num_params != 1)
    {
     display_error(1,word[1],FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_INVALID_OPERAND);
@@ -130,7 +126,7 @@ CHARTYPE *params;
  if (!valid_positive_integer(word[0]))
    {
     display_error(4,word[0],FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_INVALID_OPERAND);
@@ -140,13 +136,70 @@ CHARTYPE *params;
  insert_new_line((CHARTYPE *)"",0,num_lines,get_true_line(TRUE),FALSE,FALSE,TRUE,CURRENT_VIEW->display_low,TRUE,FALSE);
  if (curses_started
  && CURRENT_VIEW->current_window == WINDOW_COMMAND)
-    cursor_home(TRUE);
-#ifdef TRACE
+    THEcursor_home(TRUE);
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(RC_OK);
 }
 /*man-start*********************************************************************
+COMMAND
+     alert - display a user configurable dialog box with notification
+
+SYNTAX
+     ALERT /prompt/ [EDITfield [/val/]] [TITLE /title/] [OK|OKCANCEL|YESNO|YESNOCANCEL] [DEFBUTTON n]
+
+DESCRIPTION
+     The ALERT command is identical to the <DIALOG> command except that
+     if <SET BEEP> is on, a beep is played.
+
+     On exit from the ALERT command, the following Rexx variables are set:
+
+          ALERT.0 - 2
+          ALERT.1 - value of 'EDITfield'
+          ALERT.2 - button selected as specified in the call to the command.
+
+     The colours for the alert box are the same as for a dialog box, except
+     the prompt area which uses the colour set by <SET COLOR> ALERT.
+
+COMPATIBILITY
+     XEDIT: N/A
+     KEDIT: Compatible. Does not support bitmap icons or font options.
+
+SEE ALSO
+     <POPUP>, <DIALOG>, <READV>, <SET COLOR>
+
+STATUS
+     Complete.
+**man-end**********************************************************************/
+#ifdef HAVE_PROTO
+short Alert(CHARTYPE *params)
+#else
+short Alert(params)
+CHARTYPE *params;
+#endif
+/***********************************************************************/
+{
+/*--------------------------- local data ------------------------------*/
+   short rc=RC_OK;
+/*--------------------------- processing ------------------------------*/
+#ifdef THE_TRACE
+   trace_function("comm2.c:   Alert");
+#endif
+   /*
+    * If we have a beep() functiond and its ON, ring it..
+    */
+#ifdef HAVE_BEEP
+   if ( BEEPx )
+      beep();
+#endif
+   rc = prepare_dialog( params, TRUE, "ALERT" );
+#ifdef THE_TRACE
+   trace_return();
+#endif
+ return(rc);
+}
+/*man-start*********************************************************************
 COMMAND
      all - select and display restricted set of lines
 
@@ -189,7 +242,6 @@ CHARTYPE *params;
 #endif
 /***********************************************************************/
 {
-/*-------------------------- external data ----------------------------*/
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
  LINE *curr=NULL;
@@ -202,14 +254,14 @@ CHARTYPE *params;
  bool save_scope=FALSE;
  LINETYPE num_lines=0L;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("comm1.c:   All");
 #endif
  if (strlen((DEFCHAR *)params) == 0)
    {
     if (CURRENT_FILE->number_lines == 0L)
       {
-#ifdef TRACE
+#ifdef THE_TRACE
        trace_return();
 #endif
        return(rc);
@@ -227,7 +279,7 @@ CHARTYPE *params;
     CURRENT_VIEW->display_high = 0;
     build_screen(current_screen); 
     display_screen(current_screen);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(rc);
@@ -235,7 +287,7 @@ CHARTYPE *params;
  if (CURRENT_FILE->number_lines == 0L)
    {
     display_error(17,params,FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_TARGET_NOT_FOUND);
@@ -248,7 +300,7 @@ CHARTYPE *params;
  if (rc != RC_OK)
    {
     free_target(&target);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_INVALID_OPERAND);
@@ -329,7 +381,7 @@ CHARTYPE *params;
        rc = status;
    }
  free_target(&target);
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
@@ -373,7 +425,6 @@ CHARTYPE *params;
 #endif
 /***********************************************************************/
 {
-/*-------------------------- external data ----------------------------*/
 /*--------------------------- local data ------------------------------*/
 #define BAC_PARAMS  1
  CHARTYPE *word[BAC_PARAMS+1];
@@ -382,7 +433,7 @@ CHARTYPE *params;
  LINETYPE num_pages=0L;
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("comm1.c:   Backward");
 #endif
 /*---------------------------------------------------------------------*/
@@ -398,7 +449,7 @@ CHARTYPE *params;
  if (num_params != 1)
     {
      display_error(1,(CHARTYPE *)word[1],FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
      return(RC_INVALID_OPERAND);
@@ -409,7 +460,7 @@ CHARTYPE *params;
  if (strcmp((DEFCHAR *)word[0],"*") == 0)
    {
     rc = Top((CHARTYPE *)"");
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(rc);
@@ -420,7 +471,7 @@ CHARTYPE *params;
  if (!valid_integer(word[0]))
    {
     display_error(1,(CHARTYPE *)word[0],FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_INVALID_OPERAND);
@@ -435,7 +486,7 @@ CHARTYPE *params;
  if (num_pages < 0L)
    {
     display_error(5,(CHARTYPE *)word[0],FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_INVALID_OPERAND);
@@ -448,7 +499,7 @@ CHARTYPE *params;
  || CURRENT_TOF)
    {
     rc = Bottom((CHARTYPE *)"");
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(rc);
@@ -457,7 +508,7 @@ CHARTYPE *params;
 /* Scroll the screen num_pages...                                      */
 /*---------------------------------------------------------------------*/
  rc = scroll_page(DIRECTION_BACKWARD,num_pages,FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
@@ -491,13 +542,11 @@ CHARTYPE *params;
 #endif
 /***********************************************************************/
 {
-/*-------------------------- external data ----------------------------*/
- extern bool curses_started;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
  unsigned short x=0,y=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("comm1.c:   Bottom");
 #endif
 /*---------------------------------------------------------------------*/
@@ -506,7 +555,7 @@ CHARTYPE *params;
  if (strcmp((DEFCHAR *)params,"") != 0)
    {
     display_error(1,(CHARTYPE *)params,FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_INVALID_OPERAND);
@@ -534,7 +583,7 @@ CHARTYPE *params;
     else
        wmove(CURRENT_WINDOW,y,x);
    }
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
@@ -569,17 +618,12 @@ CHARTYPE *params;
 #endif
 /***********************************************************************/
 {
-/*-------------------------- external data ----------------------------*/
- extern VIEW_DETAILS *vd_first;
- extern bool curses_started;
- extern CHARTYPE number_of_files;
- extern CHARTYPE *temp_cmd;
 /*--------------------------- local data ------------------------------*/
  VIEW_DETAILS *save_current_view=(VIEW_DETAILS *)NULL;
  CHARTYPE save_number_of_files=number_of_files;
  register int i=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("comm1.c:   Cancel");
 #endif
 /*---------------------------------------------------------------------*/
@@ -588,7 +632,7 @@ CHARTYPE *params;
  if (strcmp((DEFCHAR *)params,"") != 0)
    {
     display_error(1,(CHARTYPE *)params,FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_INVALID_OPERAND);
@@ -642,7 +686,7 @@ CHARTYPE *params;
     sprintf((DEFCHAR *)temp_cmd,"%d file(s) remain with outstanding changes",number_of_files);
     display_error(0,(CHARTYPE *)temp_cmd,TRUE);
    }
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(QUIT);
@@ -679,15 +723,14 @@ CHARTYPE *params;
 #endif
 /***********************************************************************/
 {
-/*-------------------------- external data ----------------------------*/
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("comm1.c:   Cappend");
 #endif
  rc = column_command(params,COLUMN_CAPPEND);
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
@@ -722,11 +765,9 @@ CHARTYPE *params;
 #endif
 /***********************************************************************/
 {
-/*-------------------------- external data ----------------------------*/
- extern VIEW_DETAILS *vd_first;
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("comm1.c:   Ccancel");
 #endif
 /*---------------------------------------------------------------------*/
@@ -735,7 +776,7 @@ CHARTYPE *params;
  if (strcmp((DEFCHAR *)params,"") != 0)
    {
     display_error(1,(CHARTYPE *)params,FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_INVALID_OPERAND);
@@ -745,7 +786,7 @@ CHARTYPE *params;
    {
     free_view_memory(TRUE,FALSE);
    }
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(QUIT);
@@ -779,9 +820,6 @@ CHARTYPE *params;
 #endif
 /***********************************************************************/
 {
-/*-------------------------- external data ----------------------------*/
- extern CHARTYPE *rec;
- extern LENGTHTYPE rec_len;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
  short target_type=TARGET_ABSOLUTE|TARGET_RELATIVE|TARGET_STRING|TARGET_BLANK;
@@ -789,7 +827,7 @@ CHARTYPE *params;
  LENGTHTYPE start_col=0,del_start=0;
  unsigned int y=0,x=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("comm1.c:   Cdelete");
 #endif
 /*---------------------------------------------------------------------*/
@@ -803,7 +841,7 @@ CHARTYPE *params;
       {
        case LINE_SHADOW:
             display_error(87,(CHARTYPE *)"",FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
             trace_return();
 #endif
             return(RC_INVALID_OPERAND);
@@ -812,7 +850,7 @@ CHARTYPE *params;
        case LINE_TOF:
        case LINE_EOF:
             display_error(36,(CHARTYPE *)"",FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
             trace_return();
 #endif
             return(RC_INVALID_OPERAND);
@@ -849,7 +887,7 @@ CHARTYPE *params;
  if (rc != RC_OK)
    {
     free_target(&target);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_INVALID_OPERAND);
@@ -890,7 +928,7 @@ CHARTYPE *params;
        pre_process_line(CURRENT_VIEW,CURRENT_VIEW->focus_line,(LINE *)NULL);
       }
     else
-      rc = cursor_column();
+      rc = THEcursor_column();
     build_screen(current_screen);
     display_screen(current_screen);
    }
@@ -903,7 +941,7 @@ CHARTYPE *params;
       }
    }
  free_target(&target);
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
@@ -937,12 +975,11 @@ CHARTYPE *params;
 #endif
 /***********************************************************************/
 {
-/*-------------------------- external data ----------------------------*/
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
  bool need_to_redisplay=FALSE;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("comm1.c:   Cfirst");
 #endif
 /*---------------------------------------------------------------------*/
@@ -951,7 +988,7 @@ CHARTYPE *params;
  if (strcmp((DEFCHAR *)params,"") != 0)
    {
     display_error(1,(CHARTYPE *)params,FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_INVALID_OPERAND);
@@ -963,7 +1000,7 @@ CHARTYPE *params;
     need_to_redisplay = TRUE;
  if (need_to_redisplay)
     display_screen(current_screen);
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
@@ -1019,12 +1056,10 @@ CHARTYPE *params;
 #endif
 /***********************************************************************/
 {
-/*-------------------------- external data ----------------------------*/
- extern CHARTYPE last_change_command[MAX_COMMAND_LENGTH];
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("comm1.c:   Change");
 #endif
 /*---------------------------------------------------------------------*/
@@ -1036,19 +1071,19 @@ CHARTYPE *params;
     if (blank_field(last_change_command))
       {
        display_error(39,(CHARTYPE *)params,FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
        trace_return();
 #endif
        return(RC_INVALID_OPERAND);
       }
     rc = execute_change_command(last_change_command,FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(rc);
    }
  rc = execute_change_command(params,FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
@@ -1082,15 +1117,14 @@ CHARTYPE *params;
 #endif
 /***********************************************************************/
 {
-/*-------------------------- external data ----------------------------*/
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("comm1.c:   Cinsert");
 #endif
  rc = column_command(params,COLUMN_CINSERT);
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
@@ -1124,12 +1158,11 @@ CHARTYPE *params;
 #endif
 /***********************************************************************/
 {
-/*-------------------------- external data ----------------------------*/
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
  bool need_to_redisplay=FALSE;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("comm1.c:   Clast");
 #endif
 /*---------------------------------------------------------------------*/
@@ -1138,7 +1171,7 @@ CHARTYPE *params;
  if (strcmp((DEFCHAR *)params,"") != 0)
    {
     display_error(1,(CHARTYPE *)params,FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_INVALID_OPERAND);
@@ -1150,7 +1183,7 @@ CHARTYPE *params;
     need_to_redisplay = TRUE;
  if (need_to_redisplay)
     display_screen(current_screen);
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
@@ -1184,10 +1217,6 @@ CHARTYPE *params;
 #endif
 /***********************************************************************/
 {
-/*-------------------------- external data ----------------------------*/
- extern CHARTYPE *rec;
- extern LENGTHTYPE rec_len;
- extern short compatible_feel;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
  short target_type=TARGET_ABSOLUTE|TARGET_RELATIVE|TARGET_STRING|TARGET_BLANK;
@@ -1197,7 +1226,7 @@ CHARTYPE *params;
  LENGTHTYPE len=0,start_col=0;
  unsigned int y=0,x=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("comm1.c:   Clocate");
 #endif
 /*---------------------------------------------------------------------*/
@@ -1245,7 +1274,7 @@ CHARTYPE *params;
  if (rc != RC_OK)
    {
     free_target(&target);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_INVALID_OPERAND);
@@ -1257,12 +1286,12 @@ CHARTYPE *params;
    {
     CURRENT_VIEW->current_column = start_col + target.num_lines;
     if (CURRENT_VIEW->current_window != WINDOW_COMMAND)
-       rc = cursor_column();
+       rc = THEcursor_column();
     build_screen(current_screen);
     display_screen(current_screen);
    }
  free_target(&target);
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
@@ -1296,8 +1325,6 @@ CHARTYPE *params;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern CHARTYPE *rec;
 /*--------------------------- local data ------------------------------*/
  static CHARTYPE *match = (CHARTYPE *)"[]{}<>()";
  unsigned short x=0,y=0,current_y=0;
@@ -1310,7 +1337,7 @@ CHARTYPE *params;
  LINETYPE focus_line=0L;
  bool use_current=TRUE;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("comm1.c:   Cmatch");
 #endif
  getyx(CURRENT_WINDOW,y,x);
@@ -1341,7 +1368,7 @@ CHARTYPE *params;
  ||  BOF(focus_line))
    {
     display_error(66,(CHARTYPE *)"",FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_TOF_EOF_REACHED);
@@ -1352,7 +1379,7 @@ CHARTYPE *params;
  if (CURRENT_SCREEN.sl[y].line_type == LINE_SHADOW)
    {
     display_error(87,(CHARTYPE *)"",FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_TARGET_NOT_FOUND);
@@ -1371,7 +1398,7 @@ CHARTYPE *params;
  if (match_ch == 0)
    {
     display_error(67,(CHARTYPE *)"",FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_INVALID_OPERAND);
@@ -1436,7 +1463,7 @@ CHARTYPE *params;
  if (match_col == (-1))  /* no match found */
    {
     display_error(68,(CHARTYPE *)"",FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_TARGET_NOT_FOUND);
@@ -1464,7 +1491,7 @@ CHARTYPE *params;
          }
        else
           wmove(CURRENT_WINDOW,y,match_col-(CURRENT_VIEW->verify_col-1));
-#ifdef TRACE
+#ifdef THE_TRACE
        trace_return();
 #endif
        return(RC_OK);
@@ -1476,7 +1503,7 @@ CHARTYPE *params;
        build_screen(current_screen); 
        display_screen(current_screen);
        wmove(CURRENT_WINDOW,y,(match_col-(CURRENT_VIEW->verify_col-1)));
-#ifdef TRACE
+#ifdef THE_TRACE
        trace_return();
 #endif
        return(RC_OK);
@@ -1486,7 +1513,7 @@ CHARTYPE *params;
 /* If a match IS found on a different line, further checks are required*/
 /* for SCOPE.                                                          */
 /*---------------------------------------------------------------------*/
- if (in_scope(CURRENT_VIEW,curr))
+ if (IN_SCOPE(CURRENT_VIEW,curr))
    {
 /*---------------------------------------------------------------------*/
 /* Set the cursor position for the matching character.                 */
@@ -1540,7 +1567,7 @@ CHARTYPE *params;
     else
       {
        display_error(68,(CHARTYPE *)"",FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
        trace_return();
 #endif
        return(RC_TARGET_NOT_FOUND);
@@ -1558,7 +1585,7 @@ CHARTYPE *params;
  build_screen(current_screen); 
  display_screen(current_screen);
  wmove(CURRENT_WINDOW,y,x);
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(RC_OK);
@@ -1592,14 +1619,9 @@ CHARTYPE *params;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern CHARTYPE *cmd_rec;
- extern LENGTHTYPE cmd_rec_len;
- extern bool clear_command;
- extern bool curses_started;
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("comm1.c:   Cmsg");
 #endif
  memset(cmd_rec,' ',max_line_length);
@@ -1613,7 +1635,7 @@ CHARTYPE *params;
     put_string(CURRENT_WINDOW_COMMAND,0,0,cmd_rec,cmd_rec_len);
     clear_command = FALSE;
    }
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(RC_OK);
@@ -1647,15 +1669,14 @@ CHARTYPE *params;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("comm1.c:   THECommand");
 #endif
  rc = command_line(params,COMMAND_ONLY_TRUE);
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
@@ -1691,15 +1712,14 @@ CHARTYPE *params;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("comm1.c:   Compress");
 #endif
  rc = execute_expand_compress(params,FALSE,TRUE,TRUE,TRUE);
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
@@ -1730,12 +1750,11 @@ CHARTYPE *params;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
 /*--------------------------- local data ------------------------------*/
  unsigned short y=0,x=0;
  int key=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("comm1.c:   ControlChar");
 #endif
  getyx(CURRENT_WINDOW,y,x);
@@ -1748,7 +1767,7 @@ CHARTYPE *params;
     if (CURRENT_SCREEN.sl[y].line_type != LINE_LINE)
       {
        display_error(38,(CHARTYPE *)"",FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
        trace_return();
 #endif
        return(RC_INVALID_ENVIRON);
@@ -1758,19 +1777,19 @@ CHARTYPE *params;
  wmove(CURRENT_WINDOW,y,x);
  wrefresh(CURRENT_WINDOW);
  key = my_getch(CURRENT_WINDOW);
- clear_msgline();
+ clear_msgline(-1);
  if (islower(key))
     key = toupper(key);
  if (key >= (int)'A'    /* was '@' for ASCII 0, but Text() command fails */
  &&  key <= (int)'_')
    {
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return((RAW_KEY*2)+(short)key-(short)'@');
    }
  display_error(69,(CHARTYPE *)"- must be between 'A' and '_'",FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(RC_INVALID_OPERAND);
@@ -1809,8 +1828,6 @@ CHARTYPE *params;
 #endif
 /***********************************************************************/
 {
-/*-------------------------- external data ----------------------------*/
- extern VIEW_DETAILS *vd_mark;
 /*--------------------------- local data ------------------------------*/
  CHARTYPE reset_block=SOURCE_UNKNOWN;
  short rc=RC_OK;
@@ -1821,7 +1838,7 @@ CHARTYPE *params;
  short target_type2=TARGET_NORMAL;
  bool lines_based_on_scope=FALSE;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("comm1.c:   Copy");
 #endif
  initialise_target(&target1);
@@ -1829,7 +1846,7 @@ CHARTYPE *params;
  if ((rc = validate_target(params,&target1,target_type1,get_true_line(TRUE),TRUE,TRUE)) != RC_OK)
    {
     free_target(&target1);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(rc);
@@ -1845,7 +1862,7 @@ CHARTYPE *params;
       {
        free_target(&target1);
        display_error(3,(CHARTYPE *)"",FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
        trace_return();
 #endif
        return(RC_INVALID_OPERAND);
@@ -1874,7 +1891,7 @@ CHARTYPE *params;
            {
             free_target(&target1);
             box_operations(BOX_C,reset_block,FALSE,' ');
-#ifdef TRACE
+#ifdef THE_TRACE
             trace_return();
 #endif
             return(RC_OK);
@@ -1890,7 +1907,7 @@ CHARTYPE *params;
          if ((rc = validate_target(target1.rt[target1.spare].string,&target2,target_type2,get_true_line(TRUE),TRUE,TRUE)) != RC_OK)
            {
             free_target(&target2);
-#ifdef TRACE
+#ifdef THE_TRACE
             trace_return();
 #endif
             return(rc);
@@ -1905,7 +1922,10 @@ CHARTYPE *params;
            }
 #endif
          start_line = target1.true_line;
-         end_line = (target1.true_line + target1.num_lines) - 1L;
+         if (target1.num_lines < 0)
+            end_line = (target1.true_line + target1.num_lines) + 1L;
+         else
+            end_line = (target1.true_line + target1.num_lines) - 1L;
          true_line = target2.true_line + target2.num_lines;
          lines_based_on_scope = TRUE;
          break;
@@ -1924,7 +1944,7 @@ CHARTYPE *params;
                             end_line,true_line,1,source_view,dest_view,lines_based_on_scope,
                             &lines_affected);
 
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
@@ -1961,15 +1981,14 @@ CHARTYPE *params;
 #endif
 /***********************************************************************/
 {
-/*-------------------------- external data ----------------------------*/
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("comm1.c:   Coverlay");
 #endif
  rc = column_command(params,COLUMN_COVERLAY);
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
@@ -2000,15 +2019,14 @@ CHARTYPE *params;
 #endif
 /***********************************************************************/
 {
-/*-------------------------- external data ----------------------------*/
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("comm1.c:   Creplace");
 #endif
  rc = column_command(params,COLUMN_CREPLACE);
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
@@ -2120,7 +2138,7 @@ CHARTYPE *params;
  short row=0,col=0;
  LINETYPE line=0L;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("comm1.c:   Cursor");
 #endif
  strip[0]=STRIP_BOTH;
@@ -2131,7 +2149,7 @@ CHARTYPE *params;
  if (num_params ==0)
    {
     display_error(3,(CHARTYPE *)"",FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_INVALID_OPERAND);
@@ -2165,7 +2183,7 @@ CHARTYPE *params;
                   error_number = 1;
                   break;
                  }
-               rc = cursor_left(TRUE,FALSE);
+               rc = THEcursor_left(TRUE,FALSE);
                time_to_leave = TRUE;
                break;
               }
@@ -2178,7 +2196,7 @@ CHARTYPE *params;
                   error_number = 1;
                   break;
                  }
-               rc = cursor_right(TRUE,FALSE);
+               rc = THEcursor_right(TRUE,FALSE);
                time_to_leave = TRUE;
                break;
               }
@@ -2191,7 +2209,7 @@ CHARTYPE *params;
                   error_number = 1;
                   break;
                  }
-               rc = cursor_up(TRUE);
+               rc = THEcursor_up(TRUE);
                time_to_leave = TRUE;
                break;
               }
@@ -2204,7 +2222,7 @@ CHARTYPE *params;
                   error_number = 1;
                   break;
                  }
-               rc = cursor_down(TRUE);
+               rc = THEcursor_down(TRUE);
                time_to_leave = TRUE;
                break;
               }
@@ -2263,9 +2281,9 @@ CHARTYPE *params;
                break;
               }
             if (num_params == 2)
-               rc = cursor_home(TRUE);
+               rc = THEcursor_home(TRUE);
             else
-               rc = cursor_home(FALSE);
+               rc = THEcursor_home(FALSE);
             time_to_leave = TRUE;
             break;
        case CURSOR_COLUMN:
@@ -2276,7 +2294,7 @@ CHARTYPE *params;
                error_number = 1;
                break;
               }
-            rc = cursor_column();
+            rc = THEcursor_column();
             time_to_leave = TRUE;
             break;
        case CURSOR_FILE:
@@ -2315,7 +2333,7 @@ CHARTYPE *params;
               }
             else
                col = 0;
-            rc = cursor_file(line,col);
+            rc = THEcursor_file(line,col);
             time_to_leave = TRUE;
             break;
        case CURSOR_MOUSE:
@@ -2326,7 +2344,7 @@ CHARTYPE *params;
                error_number = 1;
                break;
               }
-            rc = cursor_mouse();
+            rc = THEcursor_mouse();
             time_to_leave = TRUE;
             break;
        case CURSOR_CMDLINE:
@@ -2348,7 +2366,7 @@ CHARTYPE *params;
                   break;
                  }
               }
-            rc = cursor_cmdline(colno);
+            rc = THEcursor_cmdline(colno);
             time_to_leave = TRUE;
             break;
        case CURSOR_SCREEN:
@@ -2366,7 +2384,7 @@ CHARTYPE *params;
                   error_number = 1;
                   break;
                  }
-               rc = cursor_left(escreen,FALSE);
+               rc = THEcursor_left(escreen,FALSE);
                time_to_leave = TRUE;
                break;
               }
@@ -2379,7 +2397,7 @@ CHARTYPE *params;
                   error_number = 1;
                   break;
                  }
-               rc = cursor_right(escreen,FALSE);
+               rc = THEcursor_right(escreen,FALSE);
                time_to_leave = TRUE;
                break;
               }
@@ -2392,7 +2410,7 @@ CHARTYPE *params;
                   error_number = 1;
                   break;
                  }
-               rc = cursor_up(escreen);
+               rc = THEcursor_up(escreen);
                time_to_leave = TRUE;
                break;
               }
@@ -2405,7 +2423,7 @@ CHARTYPE *params;
                   error_number = 1;
                   break;
                  }
-               rc = cursor_down(escreen);
+               rc = THEcursor_down(escreen);
                time_to_leave = TRUE;
                break;
               }
@@ -2461,7 +2479,7 @@ CHARTYPE *params;
                     }
                  }
               }
-            rc = cursor_move((escreen)?FALSE:TRUE,row,col); /* MH 0501 - was just escreen */
+            rc = THEcursor_move((escreen)?FALSE:TRUE,row,col); /* MH 0501 - was just escreen */
             time_to_leave = TRUE;
             break;
        case CURSOR_KEDIT:
@@ -2474,7 +2492,7 @@ CHARTYPE *params;
                   error_number = 1;
                   break;
                  }
-               rc = cursor_left(TRUE,TRUE);
+               rc = THEcursor_left(TRUE,TRUE);
                time_to_leave = TRUE;
                break;
               }
@@ -2487,7 +2505,7 @@ CHARTYPE *params;
                   error_number = 1;
                   break;
                  }
-               rc = cursor_right(TRUE,TRUE);
+               rc = THEcursor_right(TRUE,TRUE);
                time_to_leave = TRUE;
                break;
               }
@@ -2504,7 +2522,7 @@ CHARTYPE *params;
     if (time_to_leave)
        break;
    }
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
