@@ -1,6 +1,6 @@
 /*
  * THE - The Hessling Editor. A text editor similar to VM/CMS xedit.
- * Copyright (C) 1991-1997 Mark Hessling
+ * Copyright (C) 1991-1999 Mark Hessling
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -26,15 +26,15 @@
  * This software is going to be maintained and enhanced as deemed
  * necessary by the community.
  *
- * Mark Hessling                 Email:             M.Hessling@qut.edu.au
- * PO Box 203                    Phone:                    +617 3802 0800
- * Bellara                       http://www.gu.edu.au/gext/the/markh.html
- * QLD 4507                      **** Maintainer PDCurses & REXX/SQL ****
- * Australia                     ************* Author of THE ************
+ * Mark Hessling,  M.Hessling@qut.edu.au  http://www.lightlink.com/hessling/
+ * PO Box 203, Bellara, QLD 4507, AUSTRALIA
+ * Author of THE, a Free XEDIT/KEDIT editor and, Rexx/SQL
+ * Maintainer of PDCurses: Public Domain Curses and, Regina Rexx interpreter
+ * Use Rexx ? join the Rexx Language Association: http://www.rexxla.org
  */
 
 /*
-$Id: command.h 2.1 1995/06/24 16:29:02 MH Rel MH $
+$Id: command.h,v 1.2 1999/07/06 04:06:04 mark Exp mark $
 */
 
 struct commands
@@ -80,20 +80,24 @@ COMMAND command[] =
  {(CHARTYPE *)"cursor",      0,  KEY_DOWN,        Cursor,           FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"down"},  /* comm1.c */
  {(CHARTYPE *)"cursor",      0,  KEY_UP,          Cursor,           FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"up"},  /* comm1.c */
 #endif
-#if defined(XCURSES)
+#if defined(HAVE_SB_INIT)
  {(CHARTYPE *)"scrollbar",   0,  KEY_SF,          ScrollbarVert,    FALSE,FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* mouse.c */
  {(CHARTYPE *)"scrollbar",   0,  KEY_SR,          ScrollbarHorz,    FALSE,FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* mouse.c */
 #endif
- {(CHARTYPE *)"add",         1,  (-1),            Add,              TRUE, FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"1"}, /* comm1.c */
+ {(CHARTYPE *)"add",         1,  (-1),            Add,              TRUE, FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""}, /* comm1.c */
+ {(CHARTYPE *)"alert",       5,  (-1),            Alert,            FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,FALSE,(CHARTYPE *)""},  /* comm1.c */
  {(CHARTYPE *)"all",         3,  (-1),            All,              TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm1.c */
  {(CHARTYPE *)"arbchar",     3,  (-1),            Arbchar,          TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
  {(CHARTYPE *)"alt",         3,  (-1),            Alt,              TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
+ {(CHARTYPE *)"autocolour", 10,  (-1),            Autocolour,       TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
+ {(CHARTYPE *)"autocolor",   9,  (-1),            Autocolour,       TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
  {(CHARTYPE *)"autosave",    2,  (-1),            Autosave,         TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
+ {(CHARTYPE *)"autoscroll",  6,  (-1),            Autoscroll,       TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
 #if defined(DOS) || defined(OS2) || defined(USE_XCURSES) || defined(WIN32)
- {(CHARTYPE *)"backward",    2,  KEY_PGUP,        Backward,         TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"1"}, /* comm1.c */
+ {(CHARTYPE *)"backward",    2,  KEY_PGUP,        Backward,         TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""}, /* comm1.c */
 #else
- {(CHARTYPE *)"backward",    2,  KEY_PPAGE,       Backward,         TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"1"}, /* comm1.c */
- {(CHARTYPE *)"backward",    2,  KEY_PrevScreen,  Backward,         TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"1"}, /* comm1.c */
+ {(CHARTYPE *)"backward",    2,  KEY_PPAGE,       Backward,         TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""}, /* comm1.c */
+ {(CHARTYPE *)"backward",    2,  KEY_PrevScreen,  Backward,         TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""}, /* comm1.c */
 #endif
  {(CHARTYPE *)"backup",      4,  (-1),            Backup,           TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
  {(CHARTYPE *)"beep",        4,  (-1),            BeepSound,        TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
@@ -107,6 +111,7 @@ COMMAND command[] =
  {(CHARTYPE *)"change",      1,  (-1),            Change,           TRUE, FALSE,FALSE,FALSE,FALSE,STRIP_NONE,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm1.c */
  {(CHARTYPE *)"cinsert",     2,  (-1),            Cinsert,          TRUE, FALSE,FALSE,FALSE,FALSE,STRIP_NONE,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm1.c */
  {(CHARTYPE *)"clast",       3,  (-1),            Clast,            TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm1.c */
+ {(CHARTYPE *)"clearerrorkey", 6,(-1),            Clearerrorkey,    TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
  {(CHARTYPE *)"clearscreen", 6,  (-1),            Clearscreen,      TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
  {(CHARTYPE *)"clocate",     2,  (-1),            Clocate,          TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm1.c */
  {(CHARTYPE *)"clock",       5,  (-1),            Clock,            TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
@@ -121,6 +126,8 @@ COMMAND command[] =
  {(CHARTYPE *)"command",     7,  (-1),            THECommand,       TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm1.c */
  {(CHARTYPE *)"colour",      6,  (-1),            Colour,           TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
  {(CHARTYPE *)"color",       5,  (-1),            Colour,           TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
+ {(CHARTYPE *)"colouring",   9,  (-1),            Colouring,        TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
+ {(CHARTYPE *)"coloring",    8,  (-1),            Colouring,        TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
  {(CHARTYPE *)"compat",      6,  (-1),            Compat,           TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
  {(CHARTYPE *)"compress",    4,  (-1),            Compress,         TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_NONE,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm1.c */
  {(CHARTYPE *)"copy",        4,  (-1),            Copy,             FALSE,FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm1.c */
@@ -141,23 +148,25 @@ COMMAND command[] =
  {(CHARTYPE *)"cursor",      3,  KEY_HOME,        Cursor,           TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"home save"},  /* comm1.c */
  {(CHARTYPE *)"cursor",      0,  KEY_F16,         Cursor,           FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"home save"},  /* comm1.c */
 #endif
+ {(CHARTYPE *)"ctlchar",     3,  (-1),            Ctlchar,          TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
  {(CHARTYPE *)"coverlay",    3,  (-1),            Coverlay,         TRUE, FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm1.c */
  {(CHARTYPE *)"creplace",    2,  (-1),            Creplace,         TRUE, FALSE,FALSE,FALSE,FALSE,STRIP_NONE,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm1.c */
  {(CHARTYPE *)"curline",     4,  (-1),            Curline,          TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
  {(CHARTYPE *)"cursorstay",  8,  (-1),            CursorStay,       TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
  {(CHARTYPE *)"define",      3,  (-1),            Define,           TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm2.c */
- {(CHARTYPE *)"delete",      3,  (-1),            DeleteLine,       TRUE, FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"1"}, /* comm2.c */
+ {(CHARTYPE *)"delete",      3,  (-1),            DeleteLine,       TRUE, FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""}, /* comm2.c */
 #if defined(DOS) || defined(OS2) || defined(WIN32)
  {(CHARTYPE *)"delete",      0,  ALT_G,           DeleteLine,       FALSE,FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"block"}, /* comm2.c */
 #else
  {(CHARTYPE *)"delete",      0,  KEY_C_g,         DeleteLine,       FALSE,FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"block"}, /* comm2.c */
 #endif
+ {(CHARTYPE *)"dialog",      6,  (-1),            Dialog,           FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,FALSE,(CHARTYPE *)""},  /* comm2.c */
  {(CHARTYPE *)"directory",   3,  (-1),            Directory,        FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,FALSE,(CHARTYPE *)""},  /* comm2.c */
  {(CHARTYPE *)"dirinclude",  4,  (-1),            Dirinclude,       TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"*"}, /* commset1.c */
  {(CHARTYPE *)"ls",          2,  (-1),            Directory,        FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,FALSE,(CHARTYPE *)""},  /* comm2.c */
  {(CHARTYPE *)"defsort",     7,  (-1),            Defsort,          TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
  {(CHARTYPE *)"display",     4,  (-1),            Display,          TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
- {(CHARTYPE *)"down",        1,  (-1),            THENext,          TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"1"}, /* comm3.c */
+ {(CHARTYPE *)"down",        1,  (-1),            THENext,          TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""}, /* comm3.c */
  {(CHARTYPE *)"duplicate",   3,  (-1),            Duplicate,        TRUE, FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm2.c */
 #if defined(DOS) || defined(OS2) || defined(WIN32)
  {(CHARTYPE *)"duplicate",   0,  ALT_D,           Duplicate,        TRUE, FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"1 BLOCK"},  /* comm2.c */
@@ -171,6 +180,8 @@ COMMAND command[] =
 #else
  {(CHARTYPE *)"enter",       0,  KEY_RETURN,      Enter,            FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm2.c */
 #endif
+ {(CHARTYPE *)"ecolor",      6,  (-1),            Ecolour,          TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
+ {(CHARTYPE *)"ecolour",     7,  (-1),            Ecolour,          TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
  {(CHARTYPE *)"editv",       5,  (-1),            THEEditv,         TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm2.c */
  {(CHARTYPE *)"emsg",        4,  (-1),            Emsg,             TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_NONE,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm2.c */
  {(CHARTYPE *)"eolout",      4,  (-1),            Eolout,           TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
@@ -200,11 +211,11 @@ COMMAND command[] =
  {(CHARTYPE *)"fpath",       2,  (-1),            Fpath,            TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
  {(CHARTYPE *)"ftype",       2,  (-1),            Fext,             TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
 #if defined(DOS) || defined(OS2) || defined(USE_XCURSES) || defined(WIN32)
- {(CHARTYPE *)"forward",     2,  KEY_PGDN,        Forward,          TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"1"}, /* comm2.c */
+ {(CHARTYPE *)"forward",     2,  KEY_PGDN,        Forward,          TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""}, /* comm2.c */
  {(CHARTYPE *)"forward",     2,  CTL_PGDN,        Forward,          TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"*"}, /* comm2.c */
 #else
- {(CHARTYPE *)"forward",     2,  KEY_NPAGE,       Forward,          TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"1"}, /* comm2.c */
- {(CHARTYPE *)"forward",     2,  KEY_NextScreen,  Forward,          TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"1"}, /* comm2.c */
+ {(CHARTYPE *)"forward",     2,  KEY_NPAGE,       Forward,          TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""}, /* comm2.c */
+ {(CHARTYPE *)"forward",     2,  KEY_NextScreen,  Forward,          TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""}, /* comm2.c */
 #endif
  {(CHARTYPE *)"fullfname",   6,  (-1),            Fullfname,        TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
  {(CHARTYPE *)"get",         3,  (-1),            Get,              TRUE, FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm2.c */
@@ -226,13 +237,14 @@ COMMAND command[] =
  {(CHARTYPE *)"input",       1,  (-1),            Input,            TRUE, FALSE,FALSE,FALSE,FALSE,STRIP_NONE,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm2.c */
  {(CHARTYPE *)"inputmode",   6,  (-1),            Inputmode,        TRUE, TRUE, FALSE,FALSE,FALSE,STRIP_BOTH,TRUE, FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
 #if defined(DOS) || defined(OS2) || defined(USE_XCURSES) || defined(WIN32)
- {(CHARTYPE *)"insertmode",  7,  KEY_INS,         Insertmode,       TRUE, TRUE, FALSE,FALSE,FALSE,STRIP_BOTH,TRUE, FALSE,TRUE ,(CHARTYPE *)"toggle"},  /* commset1.c */
+ {(CHARTYPE *)"insertmode",  7,  KEY_INS,         Insertmode,       TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,TRUE, FALSE,TRUE ,(CHARTYPE *)"toggle"},  /* commset1.c */
  {(CHARTYPE *)"locate",      1,  KEY_S_F1,        Locate,           TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm3.c */
 #else
- {(CHARTYPE *)"insertmode",  7,  KEY_IC,          Insertmode,       TRUE, TRUE, FALSE,FALSE,FALSE,STRIP_BOTH,TRUE, FALSE,TRUE ,(CHARTYPE *)"toggle"},  /* commset1.c */
+ {(CHARTYPE *)"insertmode",  7,  KEY_IC,          Insertmode,       TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,TRUE, FALSE,TRUE ,(CHARTYPE *)"toggle"},  /* commset1.c */
  {(CHARTYPE *)"locate",      1,  KEY_F(11),       Locate,           TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm3.c */
 #endif
  {(CHARTYPE *)"left",        2,  (-1),            Left,             TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm3.c */
+ {(CHARTYPE *)"lineflag",    8,  (-1),            Lineflag,         TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
  {(CHARTYPE *)"linend",      5,  (-1),            Linend,           TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
  {(CHARTYPE *)"lowercase",   3,  (-1),            Lowercase,        TRUE, FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm3.c */
  {(CHARTYPE *)"macro",       5,  (-1),            Macro,            TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm3.c */
@@ -240,21 +252,21 @@ COMMAND command[] =
  {(CHARTYPE *)"macroext",    6,  (-1),            Macroext,         TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
  {(CHARTYPE *)"macropath",   6,  (-1),            Macropath,        TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
  {(CHARTYPE *)"margins",     3,  (-1),            Margins,          TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
- {(CHARTYPE *)"mark",        4,  (-1),            Mark,             FALSE,FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm3.c */
+ {(CHARTYPE *)"mark",        4,  (-1),            Mark,             FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm3.c */
  {(CHARTYPE *)"modify",      3,  (-1),            Modify,           FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm3.c */
  {(CHARTYPE *)"mouse",       5,  (-1),            Mouse,            TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
-#if defined(MOUSE_SUPPORT_ENABLED)
+#if defined(PDCURSES_MOUSE_ENABLED) || defined(NCURSES_MOUSE_VERSION)
  {(CHARTYPE *)"",            0,  KEY_MOUSE,       THEMouse,         FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm3.c */
 #endif
 #if defined(DOS) || defined(OS2) || defined(WIN32)
- {(CHARTYPE *)"mark",        0,  ALT_L,           Mark,             FALSE,FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"line"},  /* comm3.c */
- {(CHARTYPE *)"mark",        0,  ALT_B,           Mark,             FALSE,FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"box"},  /* comm3.c */
+ {(CHARTYPE *)"mark",        0,  ALT_L,           Mark,             FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"line"},  /* comm3.c */
+ {(CHARTYPE *)"mark",        0,  ALT_B,           Mark,             FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"box"},  /* comm3.c */
  {(CHARTYPE *)"move",        4,  ALT_M,           THEMove,          FALSE,FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"block reset"},  /* comm3.c */
  {(CHARTYPE *)"nextwindow",  5,  KEY_F2,          Nextwindow,       FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""}, /* comm3.c */
  {(CHARTYPE *)"overlaybox",  8,  ALT_O,           Overlaybox,       FALSE,FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""}, /* comm3.c */
 #else
- {(CHARTYPE *)"mark",        0,  KEY_C_l,         Mark,             FALSE,FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"line"},  /* comm3.c */
- {(CHARTYPE *)"mark",        0,  KEY_C_b,         Mark,             FALSE,FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"box"},  /* comm3.c */
+ {(CHARTYPE *)"mark",        0,  KEY_C_l,         Mark,             FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"line"},  /* comm3.c */
+ {(CHARTYPE *)"mark",        0,  KEY_C_b,         Mark,             FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"box"},  /* comm3.c */
  {(CHARTYPE *)"move",        4,  KEY_C_v,         THEMove,          FALSE,FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"block reset"},  /* comm3.c */
 #  if defined(USE_XCURSES)
  {(CHARTYPE *)"nextwindow",  5,  KEY_F2,          Nextwindow,       FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm3.c */
@@ -271,21 +283,23 @@ COMMAND command[] =
  {(CHARTYPE *)"msgline",     4,  (-1),            Msgline,          TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
  {(CHARTYPE *)"msgmode",     4,  (-1),            Msgmode,          TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
  {(CHARTYPE *)"newlines",    4,  (-1),            Newlines,         TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
- {(CHARTYPE *)"next",        1,  (-1),            THENext,          TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"1"}, /* comm3.c */
+ {(CHARTYPE *)"next",        1,  (-1),            THENext,          TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""}, /* comm3.c */
  {(CHARTYPE *)"nomsg",       5,  (-1),            Nomsg,            TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm3.c */
  {(CHARTYPE *)"nondisp",     4,  (-1),            Nondisp,          TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset1.c */
  {(CHARTYPE *)"nop",         3,  (-1),            Nop,              FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm3.c */
  {(CHARTYPE *)"number",      3,  (-1),            Number,           TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset2.c */
  {(CHARTYPE *)"osnowait",    3,  (-1),            Osnowait,         FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm3.c */
  {(CHARTYPE *)"osquiet",     3,  (-1),            Osquiet,          FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm3.c */
- {(CHARTYPE *)"osredir",     3,  (-1),            Osredir,          FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm3.c */
+ {(CHARTYPE *)"osredir",     3,  (-1),            Osredir,          TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm3.c */
  {(CHARTYPE *)"os",          2,  (-1),            Os,               FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm3.c */
  {(CHARTYPE *)"dosnowait",   4,  (-1),            Osnowait,         FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm3.c */
  {(CHARTYPE *)"dosquiet",    4,  (-1),            Osquiet,          FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm3.c */
  {(CHARTYPE *)"dos",         3,  (-1),            Os,               FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm3.c */
  {(CHARTYPE *)"!",           1,  (-1),            Os,               FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm3.c */
+ {(CHARTYPE *)"parser",      6,  (-1),            Parser,           TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset2.c */
  {(CHARTYPE *)"pending",     4,  (-1),            Pending,          TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset2.c */
  {(CHARTYPE *)"point",       1,  (-1),            Point,            TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset2.c */
+ {(CHARTYPE *)"popup",       5,  (-1),            Popup,            FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm4.c */
 #if defined(DOS) || defined(OS2) || defined(USE_XCURSES) || defined(WIN32)
  {(CHARTYPE *)"point",       0,  KEY_C_F11,       Point,            TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)".a"},/* commset2.c */
  {(CHARTYPE *)"locate",      0,  KEY_C_F12,       Locate,           TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)".a"},/* commset2.c */
@@ -300,7 +314,7 @@ COMMAND command[] =
  {(CHARTYPE *)"printer",     7,  (-1),            THEPrinter,       TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset2.c */
  {(CHARTYPE *)"print",       2,  (-1),            Print,            TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm4.c */
  {(CHARTYPE *)"pscreen",     4,  (-1),            Pscreen,          TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset2.c */
- {(CHARTYPE *)"put",         3,  (-1),            Put,              TRUE, FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm4.c */
+ {(CHARTYPE *)"put",         3,  (-1),            Put,              TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm4.c */
  {(CHARTYPE *)"putd",        4,  (-1),            Putd,             TRUE, FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm4.c */
 #if defined(DOS) || defined(OS2) || defined(USE_XCURSES) || defined(WIN32)
  {(CHARTYPE *)"qquit",       2,  KEY_S_F3,        Qquit,            TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm4.c */
@@ -310,11 +324,12 @@ COMMAND command[] =
  {(CHARTYPE *)"quit",        4,  (-1),            Quit,             TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm4.c */
  {(CHARTYPE *)"query",       1,  (-1),            Query,            FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm4.c */
 #if defined(DOS) || defined(OS2) || defined(USE_XCURSES) || defined(WIN32)
- {(CHARTYPE *)"recover",     3,  KEY_F8,          Recover,          FALSE,FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"1"},  /* comm4.c */
+ {(CHARTYPE *)"recover",     3,  KEY_F8,          Recover,          FALSE,FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm4.c */
 #else
- {(CHARTYPE *)"recover",     3,  KEY_F(8),        Recover,          FALSE,FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"1"},  /* comm4.c */
+ {(CHARTYPE *)"recover",     3,  KEY_F(8),        Recover,          FALSE,FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm4.c */
 #endif
  {(CHARTYPE *)"readv",       5,  (-1),            Readv,            TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm4.c */
+ {(CHARTYPE *)"readonly",    8,  (-1),            THEReadonly,      TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset2.c */
  {(CHARTYPE *)"redraw",      6,  KEY_C_r,         Redraw,           FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm4.c */
  {(CHARTYPE *)"refresh",     7,  (-1),            THERefresh,       FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm4.c */
  {(CHARTYPE *)"repeat",      4,  (-1),            Repeat,           TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm4.c */
@@ -441,6 +456,7 @@ COMMAND command[] =
  {(CHARTYPE *)"ssave",       2,  (-1),            Ssave,            TRUE, FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm4.c */
  {(CHARTYPE *)"status",      4,  (-1),            Status,           TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm4.c */
  {(CHARTYPE *)"statusline",  7,  (-1),            Statusline,       TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset2.c */
+ {(CHARTYPE *)"statopt",     7,  (-1),            Statopt,          TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset2.c */
  {(CHARTYPE *)"stay",        4,  (-1),            Stay,             TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset2.c */
  {(CHARTYPE *)"synonym",     3,  (-1),            Synonym,          TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset2.c */
  {(CHARTYPE *)"suspend",     4,  KEY_C_z,         Suspend,          FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm4.c */
@@ -455,7 +471,11 @@ COMMAND command[] =
  {(CHARTYPE *)"tabs",        4,  (-1),            Tabs,             TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset2.c */
  {(CHARTYPE *)"tabsin",      5,  (-1),            Tabsin,           TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset2.c */
  {(CHARTYPE *)"tabsout",     5,  (-1),            Tabsout,          TRUE, TRUE, FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset2.c */
+ {(CHARTYPE *)"tag",         3,  (-1),            Tag,              TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm5.c */
  {(CHARTYPE *)"text",        4,  (-1),            Text,             FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_NONE,TRUE, FALSE,TRUE ,(CHARTYPE *)""},  /* comm5.c */
+ {(CHARTYPE *)"timecheck",   9,  (-1),            Timecheck,        TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset2.c */
+ {(CHARTYPE *)"toascii",     7,  (-1),            Toascii,          FALSE,FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm5.c */
+ {(CHARTYPE *)"tofeof",      6,  (-1),            Tofeof,           TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset2.c */
 #if defined(DOS) || defined(OS2) || defined(USE_XCURSES) || defined(WIN32)
  {(CHARTYPE *)"top",         3,  CTL_PGUP,        Top,              TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm5.c */
 #else
@@ -464,7 +484,7 @@ COMMAND command[] =
  {(CHARTYPE *)"trunc",       5,  (-1),            Trunc,            TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset2.c */
  {(CHARTYPE *)"typeahead",   5,  (-1),            THETypeahead,     TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset2.c */
  {(CHARTYPE *)"undoing",     7,  (-1),            Undoing,          TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset2.c */
- {(CHARTYPE *)"up",          1,  (-1),            Up,               TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)"1"}, /* comm5.c */
+ {(CHARTYPE *)"up",          1,  (-1),            Up,               TRUE, FALSE,FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""}, /* comm5.c */
  {(CHARTYPE *)"uppercase",   3,  (-1),            Uppercase,        TRUE, FALSE,FALSE,FALSE,FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* comm5.c */
  {(CHARTYPE *)"verify",      1,  (-1),            Verify,           TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset2.c */
  {(CHARTYPE *)"width",       5,  (-1),            Width,            TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset2.c */
@@ -474,6 +494,7 @@ COMMAND command[] =
  {(CHARTYPE *)"xterminal",   5,  (-1),            Xterminal,        TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset2.c */
  {(CHARTYPE *)"edit",        1,  (-1),            Xedit,            TRUE, FALSE,FALSE,TRUE, TRUE, STRIP_BOTH,FALSE,FALSE,FALSE,(CHARTYPE *)""},  /* comm5.c */
  {(CHARTYPE *)"xedit",       1,  (-1),            Xedit,            TRUE, FALSE,FALSE,TRUE, TRUE, STRIP_BOTH,FALSE,FALSE,FALSE,(CHARTYPE *)""},  /* comm5.c */
+ {(CHARTYPE *)"kedit",       1,  (-1),            Xedit,            TRUE, FALSE,FALSE,TRUE, TRUE, STRIP_BOTH,FALSE,FALSE,FALSE,(CHARTYPE *)""},  /* comm5.c */
  {(CHARTYPE *)"the",         3,  (-1),            Xedit,            TRUE, FALSE,FALSE,TRUE, TRUE, STRIP_BOTH,FALSE,FALSE,FALSE,(CHARTYPE *)""},  /* comm5.c */
  {(CHARTYPE *)"untaa",       5,  (-1),            Untaa,            TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset2.c */
  {(CHARTYPE *)"zone",        1,  (-1),            Zone,             TRUE, TRUE, FALSE,TRUE, FALSE,STRIP_BOTH,FALSE,FALSE,TRUE ,(CHARTYPE *)""},  /* commset2.c */
