@@ -5,7 +5,7 @@
 /***********************************************************************/
 /*
  * THE - The Hessling Editor. A text editor similar to VM/CMS xedit.
- * Copyright (C) 1991-1997 Mark Hessling
+ * Copyright (C) 1991-1999 Mark Hessling
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -31,43 +31,39 @@
  * This software is going to be maintained and enhanced as deemed
  * necessary by the community.
  *
- * Mark Hessling                 Email:             M.Hessling@qut.edu.au
- * PO Box 203                    Phone:                    +617 3802 0800
- * Bellara                       http://www.gu.edu.au/gext/the/markh.html
- * QLD 4507                      **** Maintainer PDCurses & REXX/SQL ****
- * Australia                     ************* Author of THE ************
+ * Mark Hessling,  M.Hessling@qut.edu.au  http://www.lightlink.com/hessling/
+ * PO Box 203, Bellara, QLD 4507, AUSTRALIA
+ * Author of THE, a Free XEDIT/KEDIT editor and, Rexx/SQL
+ * Maintainer of PDCurses: Public Domain Curses and, Regina Rexx interpreter
+ * Use Rexx ? join the Rexx Language Association: http://www.rexxla.org
  */
 
-/*
-$Id: cursor.c 2.1 1995/06/24 16:29:25 MH Rel MH $
-*/
+static char RCSid[] = "$Id: cursor.c,v 1.3 1999/07/06 04:07:58 mark Exp mark $";
 
 #include <the.h>
 #include <proto.h>
 
 /***********************************************************************/
 #ifdef HAVE_PROTO
-short cursor_cmdline(short col)
+short THEcursor_cmdline(short col)
 #else
-short cursor_cmdline(col)
+short THEcursor_cmdline(col)
 short col;
 #endif
 /***********************************************************************/
 {
-/*-------------------------- external data ----------------------------*/
- extern bool in_readv;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
- trace_function("cursor.c:  cursor_cmdline");
+#ifdef THE_TRACE
+ trace_function("cursor.c:  THEcursor_cmdline");
 #endif
 /*---------------------------------------------------------------------*/
 /* If in READV CMDLINE, return without doing anything                  */
 /*---------------------------------------------------------------------*/
  if (in_readv)
    {
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_OK);
@@ -77,7 +73,7 @@ short col;
 /*---------------------------------------------------------------------*/
  if (CURRENT_WINDOW_COMMAND == (WINDOW *)NULL)
    {
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(rc);
@@ -89,35 +85,33 @@ short col;
     CURRENT_VIEW->current_window = WINDOW_COMMAND;
    }
  wmove(CURRENT_WINDOW,0,col-1);
-
-#ifdef TRACE
+ CURRENT_VIEW->cmdline_col = col-1;
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
 }
 /***********************************************************************/
 #ifdef HAVE_PROTO
-short cursor_column(void)
+short THEcursor_column(void)
 #else
-short cursor_column()
+short THEcursor_column()
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern bool in_readv;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
  unsigned short x=0,y=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
- trace_function("cursor.c:  cursor_column");
+#ifdef THE_TRACE
+ trace_function("cursor.c:  THEcursor_column");
 #endif
 /*---------------------------------------------------------------------*/
 /* If in READV CMDLINE, return without doing anything                  */
 /*---------------------------------------------------------------------*/
  if (in_readv)
    {
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_OK);
@@ -125,7 +119,7 @@ short cursor_column()
  switch(CURRENT_VIEW->current_window)
    {
     case WINDOW_COMMAND:
-         rc = cursor_home(FALSE);
+         rc = THEcursor_home(FALSE);
          break;
     case WINDOW_PREFIX:
          getyx(CURRENT_WINDOW,y,x);
@@ -134,35 +128,32 @@ short cursor_column()
          break;
    }
  rc = execute_move_cursor(CURRENT_VIEW->current_column-1);
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
 }
 /***********************************************************************/
 #ifdef HAVE_PROTO
-short cursor_down(bool escreen)
+short THEcursor_down(bool escreen)
 #else
-short cursor_down(escreen)
+short THEcursor_down(escreen)
 bool escreen;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern CHARTYPE CMDARROWSTABCMDx;
- extern bool in_readv;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
- trace_function("cursor.c:  cursor_down");
+#ifdef THE_TRACE
+ trace_function("cursor.c:  THEcursor_down");
 #endif
 /*---------------------------------------------------------------------*/
 /* If in READV CMDLINE, return without doing anything                  */
 /*---------------------------------------------------------------------*/
  if (in_readv)
    {
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_OK);
@@ -186,36 +177,34 @@ bool escreen;
          display_error(2,(CHARTYPE *)"",FALSE);
          break;
    }
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
 }
 /***********************************************************************/
 #ifdef HAVE_PROTO
-short cursor_file(LINETYPE line,LENGTHTYPE col)
+short THEcursor_file(LINETYPE line,LENGTHTYPE col)
 #else
-short cursor_file(line,col)
+short THEcursor_file(line,col)
 LINETYPE line;
 LENGTHTYPE col;
 #endif
 /***********************************************************************/
 {
-/*-------------------------- external data ----------------------------*/
- extern bool in_readv;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
  unsigned short y=0,x=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
- trace_function("cursor.c:  cursor_file");
+#ifdef THE_TRACE
+ trace_function("cursor.c:  THEcursor_file");
 #endif
 /*---------------------------------------------------------------------*/
 /* If in READV CMDLINE, return without doing anything                  */
 /*---------------------------------------------------------------------*/
  if (in_readv)
    {
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_OK);
@@ -226,7 +215,7 @@ LENGTHTYPE col;
  if (!line_in_view(current_screen,line))
    {
     display_error(63,(CHARTYPE *)"",FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_INVALID_OPERAND);
@@ -241,7 +230,7 @@ LENGTHTYPE col;
     if (!column_in_view(current_screen,col-1))
       {
        display_error(63,(CHARTYPE *)"",FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
        trace_return();
 #endif
        return(RC_INVALID_OPERAND);
@@ -249,30 +238,28 @@ LENGTHTYPE col;
     x = (LENGTHTYPE)((LINETYPE)col - (LINETYPE)CURRENT_VIEW->verify_col + 1);
    }
  y = get_row_for_focus_line(current_screen,line,CURRENT_VIEW->current_line);
- rc = cursor_move(FALSE,y+1,x);
-#ifdef TRACE
+ rc = THEcursor_move(FALSE,y+1,x);
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
 }
 /***********************************************************************/
 #ifdef HAVE_PROTO
-short cursor_home(bool save)
+short THEcursor_home(bool save)
 #else
-short cursor_home(save)
+short THEcursor_home(save)
 bool save;
 #endif
 /***********************************************************************/
 {
-/*-------------------------- external data ----------------------------*/
- extern bool in_readv;
 /*--------------------------- local data ------------------------------*/
  CHARTYPE last_win=0;
  unsigned short x=0,y=0;
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
- trace_function("cursor.c:  cursor_home");
+#ifdef THE_TRACE
+ trace_function("cursor.c:  THEcursor_home");
 #endif
 /*---------------------------------------------------------------------*/
 /* If CMDLINE is OFF or in READV CMDLINE, return without doing anything*/
@@ -280,7 +267,7 @@ bool save;
  if (CURRENT_WINDOW_COMMAND == (WINDOW *)NULL
  ||  in_readv)
    {
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(rc);
@@ -319,28 +306,26 @@ bool save;
     wmove(CURRENT_WINDOW,y,x);
    }
  build_screen(current_screen);
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
 }
 /***********************************************************************/
 #ifdef HAVE_PROTO
-short cursor_left(bool escreen,bool kedit_defaults)
+short THEcursor_left(bool escreen,bool kedit_defaults)
 #else
-short cursor_left(escreen,kedit_defaults)
+short THEcursor_left(escreen,kedit_defaults)
 bool escreen,kedit_defaults;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
 /*--------------------------- local data ------------------------------*/
  unsigned short x=0,y=0;
- short col=0,old_col=0;
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
- trace_function("cursor.c:  cursor_left");
+#ifdef THE_TRACE
+ trace_function("cursor.c:  THEcursor_left");
 #endif
 /*---------------------------------------------------------------------*/
 /* The following should be a temporary fix for KEDIT compatability...  */
@@ -355,7 +340,7 @@ bool escreen,kedit_defaults;
  if (x > 0)
    {
     wmove(CURRENT_WINDOW,y,x-1);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_OK);
@@ -375,29 +360,22 @@ bool escreen,kedit_defaults;
            }
          else
            {
-#ifdef VERSHIFT
-            if (CURRENT_VIEW->verify_col != 1)
+            if (CURRENT_VIEW->verify_col != 1
+            &&  CURRENT_VIEW->autoscroll != 0)
               {
-               rc = execute_move_cursor(CURRENT_VIEW->verify_col-2);
-#else
-/*           if (CURRENT_VIEW->verify_start != CURRENT_VIEW->verify_col)*/
-            if (CURRENT_VIEW->verify_col != 1)
-              {
-               old_col = (CURRENT_VIEW->verify_col-1);
-               x = min(CURRENT_SCREEN.cols[WINDOW_FILEAREA],CURRENT_VIEW->verify_end-CURRENT_VIEW->verify_start+1) / 2;
-               col = max(1,old_col - (short)x);
-               CURRENT_VIEW->verify_col = col;
+               int curr_col=x+CURRENT_VIEW->verify_col-1;
+               int num_cols = (CURRENT_VIEW->autoscroll == (-1)) ? CURRENT_SCREEN.cols[WINDOW_FILEAREA]/2 : CURRENT_VIEW->autoscroll;
+
+               num_cols = min(num_cols,CURRENT_SCREEN.cols[WINDOW_FILEAREA]);
+               CURRENT_VIEW->verify_col = max(1,CURRENT_VIEW->verify_col-num_cols);
                build_screen(current_screen);
                display_screen(current_screen);
-               x = old_col - (CURRENT_VIEW->verify_col-1);
-               wmove(CURRENT_WINDOW,y,x-1);
-#endif
-
+               wmove(CURRENT_WINDOW,y,curr_col-CURRENT_VIEW->verify_col);
               }
             else
               {
-               extern short compatible_feel;
-               if (compatible_feel == COMPAT_KEDIT)
+               if (compatible_feel == COMPAT_KEDIT
+               ||  compatible_feel == COMPAT_KEDITW)
                  {
                   if (CURRENT_VIEW->prefix)
                      if ((CURRENT_VIEW->prefix&PREFIX_LOCATION_MASK) == PREFIX_LEFT)
@@ -417,28 +395,27 @@ bool escreen,kedit_defaults;
     default:
          break;
    }
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
 }
 /***********************************************************************/
 #ifdef HAVE_PROTO
-short cursor_right(bool escreen,bool kedit_defaults)
+short THEcursor_right(bool escreen,bool kedit_defaults)
 #else
-short cursor_right(escreen,kedit_defaults)
+short THEcursor_right(escreen,kedit_defaults)
 bool escreen,kedit_defaults;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
 /*--------------------------- local data ------------------------------*/
  unsigned short x=0,y=0,tempx=0;
  short right_column=0;
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
- trace_function("cursor.c:  cursor_right");
+#ifdef THE_TRACE
+ trace_function("cursor.c:  THEcursor_right");
 #endif
 /*---------------------------------------------------------------------*/
 /* The following should be a temporary fix for KEDIT compatability...  */
@@ -452,7 +429,7 @@ bool escreen,kedit_defaults;
 /*---------------------------------------------------------------------*/
  if (CURRENT_VIEW->verify_col+x+1 > max_line_length)
    {
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_OK);
@@ -464,7 +441,7 @@ bool escreen,kedit_defaults;
  if (x < right_column)
    {
     wmove(CURRENT_WINDOW,y,x+1);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_OK);
@@ -485,20 +462,19 @@ bool escreen,kedit_defaults;
            }
          else
            {
-#ifdef VERSHIFT
-            rc = execute_move_cursor(right_column+1);
-#else
             tempx = getmaxx(CURRENT_WINDOW);
-            if (x == tempx-1)
+            if (x == tempx-1
+            &&  CURRENT_VIEW->autoscroll != 0)
               {
-               x = (tempx / 2);
-               CURRENT_VIEW->verify_col += x;
+               int curr_col=x+CURRENT_VIEW->verify_col-1;
+               int num_cols = (CURRENT_VIEW->autoscroll == (-1)) ? CURRENT_SCREEN.cols[WINDOW_FILEAREA]/2 : CURRENT_VIEW->autoscroll;
+
+               num_cols = min(num_cols,CURRENT_SCREEN.cols[WINDOW_FILEAREA]);
+               CURRENT_VIEW->verify_col += num_cols;
                build_screen(current_screen);
                display_screen(current_screen);
-               wmove(CURRENT_WINDOW,y,x+(tempx % 2));
+               wmove(CURRENT_WINDOW,y,curr_col-CURRENT_VIEW->verify_col+2);
               }
-#endif
-
            }
          break;
     case WINDOW_PREFIX:
@@ -512,36 +488,33 @@ bool escreen,kedit_defaults;
     default:
          break;
    }
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
 }
 /***********************************************************************/
 #ifdef HAVE_PROTO
-short cursor_up(bool escreen)
+short THEcursor_up(bool escreen)
 #else
-short cursor_up(escreen)
+short THEcursor_up(escreen)
 bool escreen;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern CHARTYPE CMDARROWSTABCMDx;
- extern bool in_readv;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
  CHARTYPE *current_command=NULL;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
- trace_function("cursor.c:  cursor_up");
+#ifdef THE_TRACE
+ trace_function("cursor.c:  THEcursor_up");
 #endif
 /*---------------------------------------------------------------------*/
 /* If in READV CMDLINE, return without doing anything                  */
 /*---------------------------------------------------------------------*/
  if (in_readv)
    {
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_OK);
@@ -572,22 +545,21 @@ bool escreen;
          rc = RC_INVALID_OPERAND;
          break;
    }
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
 }
 /***********************************************************************/
 #ifdef HAVE_PROTO
-short cursor_move(bool escreen,short row,short col)
+short THEcursor_move(bool escreen,short row,short col)
 #else
-short cursor_move(escreen,row,col)
+short THEcursor_move(escreen,row,col)
 bool escreen;
 short row,col;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
 /*--------------------------- local data ------------------------------*/
  register int i=0;
  short rc=RC_OK;
@@ -595,8 +567,8 @@ short row,col;
  unsigned short max_row=0,min_row=0,max_col=0;
  short idx=(-1);
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
- trace_function("cursor.c:  cursor_move");
+#ifdef THE_TRACE
+ trace_function("cursor.c:  THEcursor_move");
 #endif
  getyx(CURRENT_WINDOW_FILEAREA,y,x);
  post_process_line(CURRENT_VIEW,CURRENT_VIEW->focus_line,(LINE *)NULL,TRUE);
@@ -604,14 +576,14 @@ short row,col;
    {
     if (find_last_focus_line(&max_row) != RC_OK)
       {
-#ifdef TRACE
+#ifdef THE_TRACE
        trace_return();
 #endif
        return(rc);
       }
     if (find_first_focus_line(&min_row) != RC_OK)
       {
-#ifdef TRACE
+#ifdef THE_TRACE
        trace_return();
 #endif
        return(rc);
@@ -633,7 +605,7 @@ short row,col;
              else
                {
                 display_error(63,(CHARTYPE *)"",FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
                 trace_return();
 #endif
                 return(RC_TOF_EOF_REACHED);/* this is a strange RC :-( */
@@ -652,7 +624,7 @@ short row,col;
     switch(CURRENT_VIEW->current_window)
       {
        case WINDOW_COMMAND:
-            rc = cursor_home(FALSE);
+            rc = THEcursor_home(FALSE);
             break;
        case WINDOW_PREFIX:
             CURRENT_VIEW->current_window = WINDOW_FILEAREA;
@@ -687,7 +659,7 @@ short row,col;
     ||  col > max_col)
       {
        display_error(63,(CHARTYPE *)"",FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
        trace_return();
 #endif
        return(RC_TOF_EOF_REACHED);/* this is a strange RC :-( */
@@ -717,7 +689,7 @@ short row,col;
             if (!CURRENT_SCREEN.sl[row].main_enterable)
               {
                display_error(63,(CHARTYPE *)"",FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
                trace_return();
 #endif
                return(RC_TOF_EOF_REACHED);/* this is a strange RC :-( */
@@ -732,7 +704,7 @@ short row,col;
             if (!CURRENT_SCREEN.sl[row].prefix_enterable)
               {
                display_error(63,(CHARTYPE *)"",FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
                trace_return();
 #endif
                return(RC_TOF_EOF_REACHED);/* this is a strange RC :-( */
@@ -742,7 +714,7 @@ short row,col;
             &&  col >= CURRENT_VIEW->prefix_width-CURRENT_VIEW->prefix_gap)
               {
                display_error(63,(CHARTYPE *)"",FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
                trace_return();
 #endif
                return(RC_TOF_EOF_REACHED);/* this is a strange RC :-( */
@@ -751,7 +723,7 @@ short row,col;
             &&  col < CURRENT_VIEW->prefix_gap)
               {
                display_error(63,(CHARTYPE *)"",FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
                trace_return();
 #endif
                return(RC_TOF_EOF_REACHED);/* this is a strange RC :-( */
@@ -764,50 +736,56 @@ short row,col;
             pre_process_line(CURRENT_VIEW,CURRENT_VIEW->focus_line,(LINE *)NULL);
             break;
        case WINDOW_COMMAND:
-            rc = cursor_cmdline(col+1);
+            rc = THEcursor_cmdline(col+1);
             break;
        default:
             display_error(63,(CHARTYPE *)"",FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
             trace_return();
 #endif
             return(RC_TOF_EOF_REACHED);/* this is a strange RC :-( */
             break;
       }
    }
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
 }
 /***********************************************************************/
 #ifdef HAVE_PROTO
-short cursor_mouse(void)
+short THEcursor_mouse(void)
 #else
-short cursor_mouse()
+short THEcursor_mouse()
 #endif
 /***********************************************************************/
 {
+#if defined(PDCURSES_MOUSE_ENABLED)
 #define MOUSE_Y (MOUSE_Y_POS+1-screen[scrn].screen_start_row)
 #define MOUSE_X (MOUSE_X_POS+1-screen[scrn].screen_start_col)
-/*------------------------- external data -----------------------------*/
- extern bool in_readv;
+#endif
+#if defined(NCURSES_MOUSE_VERSION)
+#define MOUSE_Y (ncurses_mouse_event.y+1-screen[scrn].screen_start_row)
+#define MOUSE_X (ncurses_mouse_event.x+1-screen[scrn].screen_start_col)
+#endif
 /*--------------------------- local data ------------------------------*/
+#if defined(PDCURSES_MOUSE_ENABLED) || defined(NCURSES_MOUSE_VERSION)
  int w=0;
  CHARTYPE scrn=0;
+#endif
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
- trace_function("cursor.c:  cursor_mouse");
+#ifdef THE_TRACE
+ trace_function("cursor.c:  THEcursor_mouse");
 #endif
 
-#if defined(MOUSE_SUPPORT_ENABLED)
+#if defined(PDCURSES_MOUSE_ENABLED) || defined(NCURSES_MOUSE_VERSION)
 /*---------------------------------------------------------------------*/
 /* If in READV CMDLINE, return without doing anything                  */
 /*---------------------------------------------------------------------*/
  if (in_readv)
    {
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_OK);
@@ -818,7 +796,7 @@ short cursor_mouse()
  which_window_is_mouse_in(&scrn,&w);
  if (w == (-1)) /* shouldn't happen! */
    {
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_INVALID_ENVIRON);
@@ -833,10 +811,10 @@ short cursor_mouse()
 /*---------------------------------------------------------------------*/
 /* Move the cursor to the correct screen coordinates...                */
 /*---------------------------------------------------------------------*/
- rc = cursor_move(TRUE,MOUSE_Y,MOUSE_X);
+ rc = THEcursor_move(TRUE,MOUSE_Y,MOUSE_X);
 #endif
 
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
@@ -849,13 +827,11 @@ long where_now()
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern CHARTYPE display_screens;
 /*--------------------------- local data ------------------------------*/
  long rc=0L;
  unsigned short x=0,y=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("cursor.c:  where_now");
 #endif
  getyx(CURRENT_WINDOW,y,x);
@@ -887,7 +863,7 @@ long where_now()
        rc |= WHERE_SCREEN_LAST;
    }
  rc |= (long)y;
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
@@ -900,11 +876,10 @@ long what_current_now()
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
 /*--------------------------- local data ------------------------------*/
  long rc=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("cursor.c:  what_current_now");
 #endif
  if (CURRENT_WINDOW_PREFIX != NULL)
@@ -919,7 +894,7 @@ long what_current_now()
  else
     if (CURRENT_VIEW->cmd_line == 'T')
        rc |= WHERE_WINDOW_CMDLINE_TOP;
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
@@ -932,17 +907,15 @@ long what_other_now()
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern CHARTYPE display_screens;
 /*--------------------------- local data ------------------------------*/
  long rc=0L;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("cursor.c:  what_other_now");
 #endif
 if (display_screens == 1)
   {
-#ifdef TRACE
+#ifdef THE_TRACE
    trace_return();
 #endif
    return(rc);
@@ -959,7 +932,7 @@ if (display_screens == 1)
  else
     if (OTHER_SCREEN.screen_view->cmd_line == 'T')
        rc |= WHERE_WINDOW_CMDLINE_TOP;
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
@@ -973,7 +946,6 @@ long where,what_current,what_other;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
 /*--------------------------- local data ------------------------------*/
  long where_row=0L,where_window=0L,where_screen=0L;
  long what_current_window=0L;
@@ -1153,7 +1125,6 @@ long where,what_current,what_other;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
 /*--------------------------- local data ------------------------------*/
  long where_row=0L,where_window=0L,where_screen=0L;
  long what_current_window=0L;
@@ -1333,14 +1304,13 @@ long where;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
 /*--------------------------- local data ------------------------------*/
  bool rc=TRUE;
  ROWTYPE row=0;
  long where_screen=0L;
  CHARTYPE scrn=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("cursor.c:  enterable_field");
 #endif
  where_screen = where & WHERE_SCREEN_MASK;
@@ -1361,7 +1331,7 @@ long where;
     case WHERE_WINDOW_CMDLINE_BOTTOM:
          break;
    }
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
@@ -1375,15 +1345,13 @@ long save_where,where;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
  long save_where_screen=0L,where_screen=0L;
  long save_where_window=0L,where_window=0L;
- unsigned short x=0;
  ROWTYPE where_row=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("cursor.c:  go_to_new_field");
 #endif
  save_where_screen = save_where & WHERE_SCREEN_MASK;
@@ -1452,17 +1420,8 @@ long save_where,where;
             break;
       }
    }
-#if 0
- if (CURRENT_VIEW->current_window == WINDOW_PREFIX
- &&  (CURRENT_VIEW->prefix&PREFIX_LOCATION_MASK) == PREFIX_RIGHT)
-    x = CURRENT_VIEW->prefix_gap;
- else
-    x = 0;
- wmove(CURRENT_WINDOW,where_row,x);
-#else
  wmove(CURRENT_WINDOW,where_row,0);
-#endif
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
@@ -1476,13 +1435,11 @@ LINETYPE *screen_line,*screen_column,*file_line,*file_column;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern bool curses_started;
 /*--------------------------- local data ------------------------------*/
  unsigned short y=0,x=0;
  unsigned short begy=0,begx=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("cursor.c:  get_cursor_position");
 #endif
  if (curses_started)
@@ -1508,7 +1465,7 @@ LINETYPE *screen_line,*screen_column,*file_line,*file_column;
          *file_line = *file_column = (-1L);
          break;
    }
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return;
@@ -1522,15 +1479,13 @@ LINETYPE num_lines;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern bool curses_started;
 /*--------------------------- local data ------------------------------*/
  unsigned short y=0,x=0;
  LINE *curr=NULL;
  LINETYPE actual_lines=num_lines;
  short direction=DIRECTION_FORWARD;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("cursor.c:  advance_focus_line");
 #endif
  if (num_lines < 0L)
@@ -1549,8 +1504,8 @@ LINETYPE num_lines;
      if (curr == NULL)
         break;
      CURRENT_VIEW->focus_line += (LINETYPE)direction;
-     if (in_scope(CURRENT_VIEW,curr)
-     || CURRENT_VIEW->scope_all)
+     if (CURRENT_VIEW->scope_all
+     ||  IN_SCOPE(CURRENT_VIEW,curr))
         actual_lines--;
     }
  if (!line_in_view(current_screen,CURRENT_VIEW->focus_line))
@@ -1565,7 +1520,7 @@ LINETYPE num_lines;
                                CURRENT_VIEW->current_row);
     wmove(CURRENT_WINDOW,y,x);
    }
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  if (FOCUS_TOF || FOCUS_BOF)
@@ -1582,16 +1537,13 @@ LINETYPE num_lines;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern short compatible_feel;
- extern bool curses_started;
 /*--------------------------- local data ------------------------------*/
  LINE *curr=NULL;
  LINETYPE actual_lines=num_lines;
  short direction=DIRECTION_FORWARD;
  short y=0,x=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("cursor.c:  advance_current_line");
 #endif
  if (num_lines < 0L)
@@ -1610,15 +1562,15 @@ LINETYPE num_lines;
      if (curr == NULL)
         break;
      CURRENT_VIEW->current_line += (LINETYPE)direction;
-     if (in_scope(CURRENT_VIEW,curr)
-     || CURRENT_VIEW->scope_all)
+     if (CURRENT_VIEW->scope_all
+     ||  IN_SCOPE(CURRENT_VIEW,curr))
         actual_lines--;
     }
  build_screen(current_screen);
  if (!line_in_view(current_screen,CURRENT_VIEW->focus_line))
    {
     if (compatible_feel == COMPAT_XEDIT)
-       cursor_cmdline(1);
+       THEcursor_cmdline(1);
     CURRENT_VIEW->focus_line = CURRENT_VIEW->current_line;
    }
  if (CURRENT_VIEW->current_window != WINDOW_COMMAND
@@ -1628,12 +1580,12 @@ LINETYPE num_lines;
     if (CURRENT_VIEW->current_window == WINDOW_FILEAREA)
        getyx(CURRENT_WINDOW,y,x);
     y = get_row_for_focus_line(current_screen,CURRENT_VIEW->focus_line,CURRENT_VIEW->current_line);
-    cursor_move(FALSE,y+1,x+1);
+    THEcursor_move(FALSE,y+1,x+1);
    }
  pre_process_line(CURRENT_VIEW,CURRENT_VIEW->focus_line,(LINE *)NULL);
  build_screen(current_screen);
  display_screen(current_screen);
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  if (CURRENT_TOF || CURRENT_BOF)
@@ -1650,12 +1602,10 @@ LINETYPE num_lines;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern short compatible_feel;
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("cursor.c:  advance_current_or_focus_line");
 #endif
  if (CURRENT_VIEW->current_window == WINDOW_COMMAND
@@ -1663,7 +1613,7 @@ LINETYPE num_lines;
     rc = advance_current_line(num_lines);
  else
     rc = advance_focus_line(num_lines);
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
@@ -1717,15 +1667,11 @@ bool sos;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern short compatible_feel;
- extern bool curses_started;
 /*--------------------------- local data ------------------------------*/
- short rc=RC_OK;
  short y=0,x=0;
  short save_compatible_feel=compatible_feel;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("cursor.c:  resolve_current_and_focus_lines");
 #endif
 /*---------------------------------------------------------------------*/
@@ -1735,7 +1681,7 @@ bool sos;
    {
     build_screen(current_screen);
     display_screen(current_screen);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return;
@@ -1753,7 +1699,7 @@ bool sos;
    {
     build_screen(current_screen);
     display_screen(current_screen);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return;
@@ -1767,7 +1713,7 @@ bool sos;
     view->current_line = true_line+num_lines-(LINETYPE)direction;
     build_screen(current_screen);
     display_screen(current_screen);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return;
@@ -1780,6 +1726,7 @@ bool sos;
    {
     case COMPAT_THE:
     case COMPAT_KEDIT:
+    case COMPAT_KEDITW:
          view->focus_line = true_line+num_lines-(LINETYPE)direction;
          build_screen(current_screen);
          if (!line_in_view(current_screen,view->focus_line))
@@ -1800,7 +1747,7 @@ bool sos;
          pre_process_line(view,view->focus_line,(LINE *)NULL);
          build_screen(current_screen);
          if (!line_in_view(current_screen,view->focus_line))
-            cursor_cmdline(1);
+            THEcursor_cmdline(1);
          else
            {
             if (curses_started)
@@ -1808,13 +1755,13 @@ bool sos;
                if (view->current_window == WINDOW_FILEAREA)
                   getyx(SCREEN_WINDOW(current_screen),y,x);
                y = get_row_for_focus_line(current_screen,view->focus_line,view->current_line);
-               cursor_move(FALSE,y+1,x+1);
+               THEcursor_move(FALSE,y+1,x+1);
               }
            }
          display_screen(current_screen);
          break;
    }
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return;
