@@ -3,7 +3,7 @@
 /***********************************************************************/
 /*
  * THE - The Hessling Editor. A text editor similar to VM/CMS xedit.
- * Copyright (C) 1991-1997 Mark Hessling
+ * Copyright (C) 1991-1999 Mark Hessling
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -29,16 +29,14 @@
  * This software is going to be maintained and enhanced as deemed
  * necessary by the community.
  *
- * Mark Hessling                 Email:             M.Hessling@qut.edu.au
- * PO Box 203                    Phone:                    +617 3802 0800
- * Bellara                       http://www.gu.edu.au/gext/the/markh.html
- * QLD 4507                      **** Maintainer PDCurses & REXX/SQL ****
- * Australia                     ************* Author of THE ************
+ * Mark Hessling,  M.Hessling@qut.edu.au  http://www.lightlink.com/hessling/
+ * PO Box 203, Bellara, QLD 4507, AUSTRALIA
+ * Author of THE, a Free XEDIT/KEDIT editor and, Rexx/SQL
+ * Maintainer of PDCurses: Public Domain Curses and, Regina Rexx interpreter
+ * Use Rexx ? join the Rexx Language Association: http://www.rexxla.org
  */
 
-/*
-$Id: default.c 2.1 1995/06/24 16:29:29 MH Rel MH $
-*/
+static char RCSid[] = "$Id: default.c,v 1.2 1999/07/06 04:06:04 mark Exp mark $";
 
 #include <the.h>
 #include <proto.h>
@@ -49,6 +47,7 @@ $Id: default.c 2.1 1995/06/24 16:29:29 MH Rel MH $
  bool CAPREXXOUTx;
  LINETYPE CAPREXXMAXx;
  bool CLEARSCREENx;
+ int  CLEARERRORKEYx;
  bool CLOCKx;
  CHARTYPE CMDARROWSTABCMDx;
  CHARTYPE EOLx;
@@ -68,8 +67,121 @@ $Id: default.c 2.1 1995/06/24 16:29:29 MH Rel MH $
  bool SLKx=FALSE;                            /* soft label key support */
  bool SBx=FALSE;                                  /* scrollbar support */
  bool UNTAAx=FALSE;         /* unsigned numerical targets are absolute */
+ bool READONLYx=FALSE;                             /* SET READONLY OFF */
  int DEFSORTx=DIRSORT_NAME;                       /* sort on file attr */
  int DIRORDERx=DIRSORT_ASC;                          /* sort ascending */
+ int popup_escape_key=-1;
+ PARSER_DETAILS *first_parser=NULL,*last_parser=NULL;
+ PARSER_MAPPING *first_parser_mapping=NULL,*last_parser_mapping=NULL;
+ bool CTLCHARx=FALSE;
+ CHARTYPE ctlchar_escape=0;
+ COLOUR_ATTR ctlchar_attr[MAX_CTLCHARS];  /* colour attributes for ctlchar */
+ CHARTYPE ctlchar_char[MAX_CTLCHARS];      /* escape chars for ctlchar */
+/*--------------------------- default parsers -------------------------*/
+   typedef struct
+   {
+      CHARTYPE *filename;
+      CHARTYPE *name;
+      CHARTYPE *contents;
+   } DEFAULT_PARSERS;
+  
+   DEFAULT_PARSERS default_parsers[] =
+   {
+      { (CHARTYPE *)"*REXX.TLD",
+        (CHARTYPE *)"REXX",
+        (CHARTYPE *)"* REXX\n:case\nignore\n:option\nrexx\nfunction ( noblank\n:number\nrexx\n:identifier\n[a-zA-Z!?_@#$] [a-zA-Z0-9.!?_@#$]\n" \
+            ":string\nsingle\ndouble\n:comment\npaired /* */ nest\nline -- any\n"                                           \
+            ":label\ndelimiter : any\n:match\n( )\ndo,select end when,otherwise\n:header\nline #! column 1\n"               \
+            ":keyword\naddress type 5\narg type 7\nby type 2\ncall type 5\ndigits type 2\ndo type 5\ndrop type 1\n"         \
+            "else type 1\nend type 1\nengineering type 2\nexit type 1\nexpose type 2\nfor type 2\nforever type 2\n"         \
+            "form type 2\nfuzz type 2\nif type 1\ninterpret type 1\niterate type 1\nleave type 1\nname type 2\nnop type 1\n"  \
+            "novalue\nnumeric type 5\noff type 2\non type 2\noptions type 1\notherwise type 1\nparse type 5\nprocedure type 5\n"     \
+            "pull type 7\npush type 1\nqueue type 1\nreturn type 1\nsay type 1\nscientific type 2\nselect type 1\n"         \
+            "signal type 5\nsource type 2\nsyntax\nto type 2\nthen type 1\ntrace type 5\nuntil type 2\nupper type 2\nvalue type 2\n"  \
+            "var type 2\nversion type 2\nwhen type 1\nwhile type 2\nwith type 2\n"                                          \
+            ":function\n"                                                                                                   \
+            "abbrev\ncenter\nchangestr\ncompare\ncopies\ncountstr\ndatatype\ndelstr\ndelword\n"                             \
+            "insert\nlastpos\nleft\nlength\noverlay\npos\nreverse\nright\nspace\nstrip\nsubstr\n"                           \
+            "subword\ntranslate\nverify\nword\nwordindex\nwordlength\nwordpos\nwords\nxrange\n"                             \
+            "abs\nformat\nmax\nmin\nsign\ntrunc\naddress\narg\ncondition\ndigits\nerrortext\nform\n"                        \
+            "fuzz\nsourceline\ntrace\nb2x\nbitand\nbitor\nbitxor\nc2d\nc2x\nd2c\nd2x\nx2b\nx2c\nx2d\n"                      \
+            "charin\ncharout\nchars\nlinein\nlineout\nlines\nqualify\nstream\ndate\nqueued\nrandom\n"                       \
+            "symbol\ntime\nvalue\n"
+      },
+      { (CHARTYPE *)"*C.TLD",
+        (CHARTYPE *)"C",
+        (CHARTYPE *)"* C\n:case\nrespect\n:option\npreprocessor #\n:number\nc\n:identifier\n[a-zA-Z_] [a-zA-Z0-9_]\n"       \
+            ":string\nsingle backslash\ndouble backslash\n:comment\npaired /* */ nonest\nline // any\n"                     \
+            ":label\ndelimiter : column 1\n:match\n( )\n{ }\n#ifdef,#if,#ifndef #endif #else,#elif,#elseif\n"               \
+            ":keyword\n#define\n#elif\n#else\n#endif\n#error\n#if\n#ifdef\n#ifndef\n#include\n#line\n#pragma\n#undef\n"     \
+            "auto\nbool\nbreak\ncase\nchar\nconst\ncontinue\ndefault\ndelete\ndo\ndouble\nelse\nenum\nextern\nfloat\n"      \
+            "for\ngoto\nif\nint\nlong\nnew\nregister\nreturn\nshort\nsigned\nsizeof\nstatic\nstruct\nswitch\n"              \
+            "typedef\nunion\nunsigned\nvoid\nvolatile\nwhile\nclass\nprivate\npublic\n"
+      },
+      { (CHARTYPE *)"*SH.TLD",
+        (CHARTYPE *)"SH",
+        (CHARTYPE *)"* SH\n:case\nrespect\n"       \
+            ":string\nsingle backslash\ndouble backslash\n:identifier\n[a-zA-Z_] [a-zA-Z0-9_]\n"                            \
+            ":comment\nline # any\n:header\nline #! column 1\n"                                                                                        \
+            ":keyword\nif\nfi\nelif\nfor\nuntil\ncase\nesac\nwhile\nthen\nelse\ntest alt 4\nshift alt 4\ndo\ndone\nin\n"          \
+            "continue alt 4\nbreak alt 4\ncd alt 4\necho alt 4\neval alt 4\nexec alt 4\n" \
+            "exit alt 4\nexport alt 4\ngetopts alt 4\nset alt 4\nunset alt 4\ntrap alt 4\n"
+      },
+      { (CHARTYPE *)"*TLD.TLD",
+        (CHARTYPE *)"TLD",
+        (CHARTYPE *)"* TLD\n:case\nignore\n"                                                                                \
+            ":comment\nline * firstnonblank\n"                                                                                        \
+            ":header\nline : column 1\n"
+      },
+      { (CHARTYPE *)"*HTML.TLD",
+        (CHARTYPE *)"HTML",
+        (CHARTYPE *)"* HTML" \
+            ":case\nignore\n" \
+            ":identifier\n[a-zA-Z] [a-zA-Z0-9]\n" \
+            ":string\ndouble\n" \
+            ":comment\npaired <! --> nonest\n" \
+            ":markup\ntag < >\nreference & ;\n"
+      },
+      {
+        NULL, NULL
+      }
+   };
+  
+   PARSER_MAPPING default_parser_mapping[] =
+   {
+      /*
+       * The following describes this table for those interested in
+       * updating it manually.
+       * Parameter 1 - Always NULL
+       * Parameter 2 - Always NULL
+       * Parameter 3 - Name of parser to associate mapping
+       * Parameter 4 - Filemask - NULL if using "magic numbers"
+       * Parameter 4 - Magic number string - NULL if using filemask
+       * Parameter 5 - Length of "magic number" - 0 if using filemask
+       * Parameter 6 - Always NULL
+       */
+      { NULL,NULL,(CHARTYPE*)"C",    (CHARTYPE*)"*.c"    , NULL  ,0, NULL },
+      { NULL,NULL,(CHARTYPE*)"C",    (CHARTYPE*)"*.cc"   , NULL  ,0, NULL },
+      { NULL,NULL,(CHARTYPE*)"C",    (CHARTYPE*)"*.cpp"  , NULL  ,0, NULL },
+      { NULL,NULL,(CHARTYPE*)"C",    (CHARTYPE*)"*.h"    , NULL  ,0, NULL },
+      { NULL,NULL,(CHARTYPE*)"C",    (CHARTYPE*)"*.hpp"  , NULL  ,0, NULL },
+      { NULL,NULL,(CHARTYPE*)"REXX", (CHARTYPE*)"*.cmd"  , NULL  ,0, NULL },
+      { NULL,NULL,(CHARTYPE*)"REXX", (CHARTYPE*)"*.rex"  , NULL  ,0, NULL },
+      { NULL,NULL,(CHARTYPE*)"REXX", (CHARTYPE*)"*.rexx" , NULL  ,0, NULL },
+      { NULL,NULL,(CHARTYPE*)"REXX", (CHARTYPE*)"*.the"  , NULL  ,0, NULL },
+      { NULL,NULL,(CHARTYPE*)"REXX", (CHARTYPE*)".therc" , NULL  ,0, NULL },
+      { NULL,NULL,(CHARTYPE*)"TLD",  (CHARTYPE*)"*.tld"  , NULL  ,0, NULL },
+      { NULL,NULL,(CHARTYPE*)"HTML", (CHARTYPE*)"*.htm"  , NULL  ,0, NULL },
+      { NULL,NULL,(CHARTYPE*)"HTML", (CHARTYPE*)"*.html" , NULL  ,0, NULL },
+      { NULL,NULL,(CHARTYPE*)"REXX", NULL    ,(CHARTYPE*)"rexx"  ,4, NULL },
+      { NULL,NULL,(CHARTYPE*)"REXX", NULL    ,(CHARTYPE*)"regina",6, NULL },
+      { NULL,NULL,(CHARTYPE*)"REXX", NULL    ,(CHARTYPE*)"rxx"   ,3, NULL },
+      { NULL,NULL,(CHARTYPE*)"SH",   NULL    ,(CHARTYPE*)"sh"    ,2, NULL },
+      { NULL,NULL,(CHARTYPE*)"SH",   NULL    ,(CHARTYPE*)"ksh"   ,3, NULL },
+      { NULL,NULL,(CHARTYPE*)"SH",   NULL    ,(CHARTYPE*)"bash"  ,4, NULL },
+      { NULL,NULL,(CHARTYPE*)"SH",   NULL    ,(CHARTYPE*)"zsh"   ,3, NULL },
+      { NULL,NULL,NULL,              NULL    , NULL              ,0, NULL }
+   };
 
 /***********************************************************************/
 #ifdef HAVE_PROTO
@@ -79,12 +191,10 @@ void set_global_defaults()
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern LENGTHTYPE display_length;
- extern short prefix_width;
 /*--------------------------- local data ------------------------------*/
+ int i;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("default.c: set_global_defaults");
 #endif
 /*---------------------------------------------------------------------*/
@@ -94,12 +204,14 @@ void set_global_defaults()
  CAPREXXOUTx = FALSE;
  CAPREXXMAXx = 1000L;
  INSERTMODEx = FALSE;
+ CLEARERRORKEYx = -1;
  LINEND_VALUEx = '#';
  REPROFILEx = FALSE;
  TABI_ONx = FALSE;
  TABI_Nx = 8;
  UNTAAx = FALSE;
-#if defined(MOUSE_SUPPORT_ENABLED)
+ READONLYx = FALSE;
+#if defined(PDCURSES_MOUSE_ENABLED) || defined(NCURSES_MOUSE_VERSION)
  MOUSEx = TRUE;
 #else
  MOUSEx = FALSE;
@@ -116,6 +228,14 @@ void set_global_defaults()
 #endif
    }
 /*---------------------------------------------------------------------*/
+/* Set CTLCHAR defaults...                                             */
+/*---------------------------------------------------------------------*/
+ for (i=0;i<MAX_CTLCHARS;i++)
+ {
+    memset((CHARTYPE *)&ctlchar_attr[i],0,sizeof(COLOUR_ATTR));
+    ctlchar_char[i] = 0;
+ }
+/*---------------------------------------------------------------------*/
 /* If STATUSLINE is OFF before we come here, leave it OFF.             */
 /*---------------------------------------------------------------------*/
  if (STATUSLINEx != 'O')
@@ -128,7 +248,7 @@ void set_global_defaults()
 /*---------------------------------------------------------------------*/
  set_global_look_defaults();
  set_global_feel_defaults();
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return;
@@ -141,12 +261,9 @@ void set_global_look_defaults()
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern short compatible_look;
- extern short prefix_gap;
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("default.c: set_global_look_defaults");
 #endif
  switch(compatible_look)
@@ -159,6 +276,7 @@ void set_global_look_defaults()
          prefix_gap = 0;
          NONDISPx = '#';
          break;
+    case COMPAT_KEDITW:
     case COMPAT_KEDIT:
          CLEARSCREENx = TRUE;
          CLOCKx = TRUE;
@@ -176,7 +294,7 @@ void set_global_look_defaults()
          prefix_gap = 1;
          break;
    }
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return;
@@ -189,11 +307,9 @@ void set_global_feel_defaults()
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern short compatible_feel;
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("default.c: set_global_feel_defaults");
 #endif
  switch(compatible_feel)
@@ -203,6 +319,7 @@ void set_global_feel_defaults()
          LINEND_STATUSx = FALSE;
          break;
     case COMPAT_KEDIT:
+    case COMPAT_KEDITW:
          CMDARROWSTABCMDx = TRUE;
          LINEND_STATUSx = FALSE;
          break;
@@ -211,7 +328,7 @@ void set_global_feel_defaults()
          LINEND_STATUSx = TRUE;
          break;
    }
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return;
@@ -225,11 +342,9 @@ FILE_DETAILS *filep;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern short compatible_feel;
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("default.c: set_file_defaults");
 #endif
 /*---------------------------------------------------------------------*/
@@ -242,24 +357,34 @@ FILE_DETAILS *filep;
  filep->display_actual_filename = TRUE;
  filep->tabsout_num =  8;
  filep->eolout = EOLx;
+ filep->timecheck = TRUE;
  filep->undoing = TRUE;
+ filep->autocolour = TRUE;
  set_up_default_colours(filep,(COLOUR_ATTR *)NULL,ATTR_MAX);
+ set_up_default_ecolours(filep);
 /*---------------------------------------------------------------------*/
 /* Set defaults for individual environments next...                    */
 /*---------------------------------------------------------------------*/
  switch(compatible_feel)
    {
     case COMPAT_THE:
+         filep->colouring = TRUE;
          filep->backup = BACKUP_KEEP;
          break;
     case COMPAT_XEDIT:
+         filep->colouring = TRUE;
+         filep->backup = BACKUP_OFF;
+         break;
+    case COMPAT_KEDITW:
+         filep->colouring = TRUE;
          filep->backup = BACKUP_OFF;
          break;
     case COMPAT_KEDIT:
+         filep->colouring = FALSE;
          filep->backup = BACKUP_OFF;
          break;
    }
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return;
@@ -273,14 +398,11 @@ VIEW_DETAILS *viewp;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern short compatible_look;
- extern short compatible_feel;
 /*--------------------------- local data ------------------------------*/
  register int i=0;
  short tabinc=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("default.c: set_view_defaults");
 #endif
 /*---------------------------------------------------------------------*/
@@ -294,6 +416,7 @@ VIEW_DETAILS *viewp;
  viewp->case_change = CASE_RESPECT;
  viewp->case_sort = CASE_RESPECT;
  viewp->cmd_line = 'B';
+ viewp->cmdline_col = 0;
  viewp->id_line = TRUE;
  viewp->in_ring = FALSE;
  viewp->current_row = 0;   /* this is set once we know the screen size */
@@ -322,6 +445,7 @@ VIEW_DETAILS *viewp;
  viewp->tab_on = FALSE;
  viewp->numtabs = 32;
  viewp->tabsinc = 0;
+ viewp->tofeof = TRUE;
  viewp->verify_start = 1;
  viewp->verify_col = 1;
  viewp->verify_end = max_line_length;
@@ -333,6 +457,7 @@ VIEW_DETAILS *viewp;
  viewp->wrap = FALSE;
  viewp->zone_start = 1;
  viewp->zone_end = max_line_length;
+ viewp->autoscroll = (-1);  /* scroll half */
 
  if (viewp->cmd_line == 'O')
    {
@@ -371,6 +496,7 @@ VIEW_DETAILS *viewp;
          viewp->msgline_off = 2;
          viewp->msgline_rows = 2;
          break;
+    case COMPAT_KEDITW:
     case COMPAT_KEDIT:
          viewp->number = FALSE;
          viewp->prefix = PREFIX_OFF;
@@ -413,6 +539,7 @@ VIEW_DETAILS *viewp;
          viewp->tab_off = (-3);
          tabinc = 3;
          break;
+    case COMPAT_KEDITW:
     case COMPAT_KEDIT:
          viewp->case_enter = CASE_MIXED;
          viewp->imp_macro = FALSE;
@@ -426,7 +553,7 @@ VIEW_DETAILS *viewp;
    }
  for (i=0;i<MAX_NUMTABS;i++)
      viewp->tabs[i] = 1 + (i*tabinc);
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return;
@@ -440,16 +567,13 @@ CHARTYPE *prf_file,*prf_arg;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern bool in_macro;
- extern bool rexx_support;
 /*--------------------------- local data ------------------------------*/
  FILE *fp=NULL;
  short rc=RC_OK;
  bool save_in_macro=in_macro;
  short macrorc=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("default.c: get_profile");
 #endif
 /*---------------------------------------------------------------------*/
@@ -463,7 +587,7 @@ CHARTYPE *prf_file,*prf_arg;
  if (rexx_support)
    {
     post_process_line(CURRENT_VIEW,CURRENT_VIEW->focus_line,(LINE *)NULL,TRUE);
-    rc = execute_macro_file(prf_file,prf_arg,&macrorc);
+    rc = execute_macro_file(prf_file,prf_arg,&macrorc,FALSE);
     if (rc != RC_OK)
       {
        display_error(54,(CHARTYPE *)"",FALSE);
@@ -492,7 +616,7 @@ CHARTYPE *prf_file,*prf_arg;
        display_error(52,(CHARTYPE *)"",FALSE);
    }
  in_macro = save_in_macro;
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
 /* return(rc);*/
@@ -506,14 +630,10 @@ short defaults_for_first_file()
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern VIEW_DETAILS *vd_first;
- extern VIEW_DETAILS *vd_last;
- extern CHARTYPE number_of_views;
 /*--------------------------- local data ------------------------------*/
  register int i=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("default.c: defaults_for_first_file");
 #endif
 /*---------------------------------------------------------------------*/
@@ -522,7 +642,7 @@ short defaults_for_first_file()
  if ((CURRENT_VIEW = vll_add(vd_first,vd_current,sizeof(VIEW_DETAILS)))
                    == (VIEW_DETAILS *)NULL)
    {
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_OUT_OF_MEMORY);
@@ -568,7 +688,7 @@ short defaults_for_first_file()
     CURRENT_VIEW->previous_window =       WINDOW_FILEAREA;
    }
  CURRENT_VIEW->preserved_view_details = (PRESERVED_VIEW_DETAILS *)NULL;
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(RC_OK);
@@ -582,20 +702,16 @@ VIEW_DETAILS *base_view;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern VIEW_DETAILS *vd_first;
- extern VIEW_DETAILS *vd_last;
- extern CHARTYPE number_of_views;
 /*--------------------------- local data ------------------------------*/
  register int i=0;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("default.c: defaults_for_other_files");
 #endif
  if ((CURRENT_VIEW = vll_add(vd_first,vd_current,sizeof(VIEW_DETAILS)))
                    == (VIEW_DETAILS *)NULL)
    {
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_OUT_OF_MEMORY);
@@ -627,6 +743,7 @@ VIEW_DETAILS *base_view;
     CURRENT_VIEW->verify_end =      base_view->verify_end;
     CURRENT_VIEW->zone_start =      base_view->zone_start;
     CURRENT_VIEW->zone_end =        base_view->zone_end;
+    CURRENT_VIEW->autoscroll =      base_view->autoscroll;
     
     for (i=0;i<VIEW_WINDOWS;i++)
       {
@@ -680,6 +797,7 @@ VIEW_DETAILS *base_view;
     CURRENT_VIEW->tab_base =        base_view->tab_base;
     CURRENT_VIEW->tab_off =         base_view->tab_off;
     CURRENT_VIEW->tab_on =          base_view->tab_on;
+    CURRENT_VIEW->tofeof=           base_view->tofeof;
     CURRENT_VIEW->word =            base_view->word;
     CURRENT_VIEW->wordwrap =        base_view->wordwrap;
     CURRENT_VIEW->wrap =            base_view->wrap;
@@ -746,6 +864,7 @@ VIEW_DETAILS *base_view;
     CURRENT_VIEW->tab_base =        PREVIOUS_VIEW->tab_base;
     CURRENT_VIEW->tab_off =         PREVIOUS_VIEW->tab_off;
     CURRENT_VIEW->tab_on =          PREVIOUS_VIEW->tab_on;
+    CURRENT_VIEW->tofeof =          PREVIOUS_VIEW->tofeof;
     CURRENT_VIEW->word =            PREVIOUS_VIEW->word;
     CURRENT_VIEW->wordwrap =        PREVIOUS_VIEW->wordwrap;
     CURRENT_VIEW->wrap =            PREVIOUS_VIEW->wrap;
@@ -770,7 +889,7 @@ VIEW_DETAILS *base_view;
     CURRENT_VIEW->previous_window =       WINDOW_FILEAREA;
    }
  CURRENT_VIEW->preserved_view_details = (PRESERVED_VIEW_DETAILS *)NULL;
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(RC_OK);
@@ -784,12 +903,11 @@ FILE_DETAILS *fd;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
 /*--------------------------- local data ------------------------------*/
  RESERVED *curr=NULL;
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("default.c: default_file_attributes");
 #endif
 
@@ -804,30 +922,40 @@ FILE_DETAILS *fd;
  CURRENT_FILE->editv =           (LINE *)NULL;
  CURRENT_FILE->first_reserved  = (RESERVED *)NULL;
  CURRENT_FILE->fmode =           0;
+ CURRENT_FILE->modtime =         0;
  CURRENT_FILE->pseudo_file =     PSEUDO_REAL;
  CURRENT_FILE->first_ppc = CURRENT_FILE->last_ppc = NULL;
  CURRENT_FILE->preserved_file_details = NULL;
  CURRENT_FILE->fp = NULL;
+ CURRENT_FILE->parser = NULL;
 /*---------------------------------------------------------------------*/
 /* Set defaults for the current file based on the settings for the     */
 /* previous file. The defaults to copy are:                            */
 /* - colours, reserved lines.                                          */
 /*---------------------------------------------------------------------*/
  if (fd != NULL)
-   {
+ {
     CURRENT_FILE->display_actual_filename = fd->display_actual_filename;
     memcpy(CURRENT_FILE->attr,fd->attr,ATTR_MAX*sizeof(COLOUR_ATTR));
-    curr = fd->first_reserved;
-    while(curr!=NULL)
-      {
-       rc = add_reserved_line(curr->spec,curr->line,curr->base,curr->off,
-                        curr->attr);
-       if (rc != RC_OK)
-          break;
-       curr = curr->next;
-      }
-   }
-#ifdef TRACE
+    /*
+     * If in XEDIT compatibility mode, don't copy reserved lines to the
+     * new file.
+     */
+    if (compatible_feel != COMPAT_XEDIT)
+    {
+       curr = fd->first_reserved;
+       while(curr!=NULL)
+       {
+          if (add_reserved_line(curr->spec,curr->line,curr->base,curr->off, curr->attr) == NULL)
+          {
+             rc = RC_OUT_OF_MEMORY;
+             break;
+          }
+          curr = curr->next;
+       }
+    }
+ }
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
@@ -840,11 +968,6 @@ void set_screen_defaults()
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern CHARTYPE display_screens;
- extern bool horizontal;
- extern short terminal_lines;
- extern short terminal_cols;
 /*--------------------------- local data ------------------------------*/
  register int i=0;
  register int j=0;
@@ -854,7 +977,7 @@ void set_screen_defaults()
  short my_prefix_width=0,my_prefix_gap=0;
  bool my_arrow=TRUE;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("default.c: set_screen_defaults");
 #endif
 /*---------------------------------------------------------------------*/
@@ -882,7 +1005,10 @@ void set_screen_defaults()
 /*---------------------------------------------------------------------*/
  if (horizontal)
    {
-    screen[0].screen_rows = (terminal_lines - number_rows_less) / display_screens;
+    if (screen_rows[0] == 0)
+       screen[0].screen_rows = (terminal_lines - number_rows_less) / display_screens;
+    else
+       screen[0].screen_rows = screen_rows[0];
     screen[0].screen_cols = terminal_cols;
     screen[0].screen_start_row = start_row;
     screen[0].screen_start_col = 0;
@@ -1037,31 +1163,31 @@ void set_screen_defaults()
 /* line arrays.                                                        */
 /*---------------------------------------------------------------------*/
  if (screen[0].sl != NULL)
-   {
+ {
     (*the_free)(screen[0].sl);
     screen[0].sl = NULL;
-   }
+ }
  if (screen[1].sl != NULL)
-   {
+ {
     (*the_free)(screen[1].sl);
     screen[1].sl = NULL;
-   }
+ }
  if ((screen[0].sl = (SHOW_LINE *)(*the_malloc)(screen[0].rows[WINDOW_FILEAREA]*sizeof(SHOW_LINE))) == NULL)
-   {
+ {
     cleanup();
     display_error(30,(CHARTYPE *)"",FALSE);
     exit(1);
-   }
+ }
  if (display_screens > 1)
-   {
+ {
     if ((screen[1].sl = (SHOW_LINE *)(*the_malloc)(screen[1].rows[WINDOW_FILEAREA]*sizeof(SHOW_LINE))) == NULL)
-      {
+    {
        cleanup();
        display_error(30,(CHARTYPE *)"",FALSE);
        exit(1);
-      }
-   }
-#ifdef TRACE
+    }
+ }
+#ifdef THE_TRACE
  trace_return();
 #endif
  return;
@@ -1074,12 +1200,9 @@ void set_defaults()
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern CHARTYPE *cmd_rec;
- extern LENGTHTYPE cmd_rec_len;
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("default.c: set_defaults");
 #endif
 /*---------------------------------------------------------------------*/
@@ -1100,26 +1223,25 @@ void set_defaults()
  memset(cmd_rec,' ',max_line_length);
  cmd_rec_len = 0;
 
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return;
 }
 /***********************************************************************/
 #ifdef HAVE_PROTO
-short set_THE_defaults(int prey,int prex)
+short set_THE_key_defaults(int prey,int prex)
 #else
-short set_THE_defaults(prey,prex)
+short set_THE_key_defaults(prey,prex)
 int prey,prex;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
- trace_function("default.c: set_THE_defaults");
+#ifdef THE_TRACE
+ trace_function("default.c: set_THE_key_defaults");
 #endif
 /*---------------------------------------------------------------------*/
 /* This function is for resetting all default values for THE           */
@@ -1152,26 +1274,25 @@ int prey,prex;
  Define((CHARTYPE *)"S-TAB");
  Define((CHARTYPE *)"ENTER");
 #endif
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
 }
 /***********************************************************************/
 #ifdef HAVE_PROTO
-short set_XEDIT_defaults(int prey,int prex)
+short set_XEDIT_key_defaults(int prey,int prex)
 #else
-short set_XEDIT_defaults(prey,prex)
+short set_XEDIT_key_defaults(prey,prex)
 int prey,prex;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
- trace_function("default.c: set_XEDIT_defaults");
+#ifdef THE_TRACE
+ trace_function("default.c: set_XEDIT_key_defaults");
 #endif
 /*---------------------------------------------------------------------*/
 /* This function is for resetting all default values for XEDIT         */
@@ -1203,26 +1324,25 @@ int prey,prex;
  Define((CHARTYPE *)"S-TAB sos tabfieldb");
  Define((CHARTYPE *)"TAB sos tabfieldf");
 #endif
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
 }
 /***********************************************************************/
 #ifdef HAVE_PROTO
-short set_KEDIT_defaults(int prey,int prex)
+short set_KEDIT_key_defaults(int prey,int prex)
 #else
-short set_KEDIT_defaults(prey,prex)
+short set_KEDIT_key_defaults(prey,prex)
 int prey,prex;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
 /*--------------------------- local data ------------------------------*/
  short rc=RC_OK;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
- trace_function("default.c: set_KEDIT_defaults");
+#ifdef THE_TRACE
+ trace_function("default.c: set_KEDIT_key_defaults");
 #endif
 /*---------------------------------------------------------------------*/
 /* This function is for resetting all default values for KEDIT         */
@@ -1257,8 +1377,187 @@ int prey,prex;
  Define((CHARTYPE *)"S-TAB");
 #endif
 
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(rc);
 }
+/***********************************************************************/
+#ifdef HAVE_PROTO
+short construct_default_parsers(void)
+#else
+short construct_default_parsers()
+#endif
+/***********************************************************************/
+{
+/*--------------------------- local data ------------------------------*/
+   short rc=RC_OK;
+   PARSER_DETAILS *curr;
+   int i;
+   CHARTYPE tmp[20];
+/*--------------------------- processing ------------------------------*/
+#ifdef THE_TRACE
+   trace_function("default.c: construct_default_parsers");
+#endif
+/*---------------------------------------------------------------------*/
+   for (i=0;;i++)
+   {
+      if (default_parsers[i].contents == NULL)
+         break;
+      rc = construct_parser(default_parsers[i].contents,
+                            strlen((DEFCHAR *)default_parsers[i].contents),
+                            &curr,
+                            default_parsers[i].name,
+                            default_parsers[i].filename);
+      if (rc != RC_OK)
+         break;
+      if (rexx_support)
+      {
+         /*
+          * If we have a Rexx interpreter, register an implied extract
+          * function for the number of parsers we now have.
+          */
+         sprintf((DEFCHAR *)tmp,"parser.%d",i+1);
+         MyRexxRegisterFunctionExe(tmp);
+      }
+   }
+
+#ifdef THE_TRACE
+   trace_return();
+#endif
+   return(rc);
+}
+/***********************************************************************/
+#ifdef HAVE_PROTO
+short destroy_all_parsers(void)
+#else
+short destroy_all_parsers()
+#endif
+/***********************************************************************/
+{
+/*--------------------------- local data ------------------------------*/
+ short rc=RC_OK;
+ PARSER_DETAILS *curr=first_parser;
+/*--------------------------- processing ------------------------------*/
+#ifdef THE_TRACE
+ trace_function("default.c: destroy_all_parsers");
+#endif
+ while( curr->next != NULL )
+ {
+    destroy_parser(curr);
+    curr = curr->next;
+ }
+ first_parser = last_parser = parserll_free(first_parser);
+#ifdef THE_TRACE
+ trace_return();
+#endif
+ return(rc);
+}
+/***********************************************************************/
+#ifdef HAVE_PROTO
+short construct_default_parser_mapping(void)
+#else
+short construct_default_parser_mapping()
+#endif
+/***********************************************************************/
+{
+/*--------------------------- local data ------------------------------*/
+ short rc=RC_OK;
+ PARSER_MAPPING *curr;
+ PARSER_DETAILS *currp;
+ int i;
+/*--------------------------- processing ------------------------------*/
+#ifdef THE_TRACE
+ trace_function("default.c: construct_default_parser_mapping");
+#endif
+/*---------------------------------------------------------------------*/
+ for (i=0;;i++)
+ {
+    if (default_parser_mapping[i].parser_name == NULL)
+       break;
+    last_parser_mapping = curr = mappingll_add(first_parser_mapping,last_parser_mapping,sizeof(PARSER_MAPPING));
+    if (first_parser_mapping == NULL)
+       first_parser_mapping = curr;
+    if (default_parser_mapping[i].filemask)
+    {
+       curr->filemask = (CHARTYPE *)(*the_malloc)(1+strlen((DEFCHAR *)default_parser_mapping[i].filemask)*sizeof(CHARTYPE));
+       if (curr->filemask == NULL)
+       {
+          display_error(30,(CHARTYPE *)"",FALSE);
+          return(RC_OUT_OF_MEMORY);
+       }
+       strcpy((DEFCHAR *)curr->filemask,(DEFCHAR *)default_parser_mapping[i].filemask);
+    }
+    if (default_parser_mapping[i].magic_number)
+    {
+       curr->magic_number = (CHARTYPE *)(*the_malloc)((1+default_parser_mapping[i].magic_number_length)*sizeof(CHARTYPE));
+       if (curr->magic_number == NULL)
+       {
+          display_error(30,(CHARTYPE *)"",FALSE);
+          return(RC_OUT_OF_MEMORY);
+       }
+       strcpy((DEFCHAR *)curr->magic_number,(DEFCHAR *)default_parser_mapping[i].magic_number);
+       curr->magic_number_length = default_parser_mapping[i].magic_number_length;
+    }
+    curr->parser = NULL;
+    for(currp=first_parser;currp!=NULL;currp=currp->next)
+    {
+       if (my_stricmp((DEFCHAR *)currp->parser_name,(DEFCHAR *)default_parser_mapping[i].parser_name) == 0)
+       {
+          curr->parser = currp;
+          break;
+       }
+    }
+   if (rexx_support)
+   {
+      /*
+       * If we have a Rexx interpreter, register an implied extract
+       * function for the number of parsers we now have.
+       */
+      CHARTYPE tmp[20];
+      sprintf((DEFCHAR *)tmp,"autocolor.%d",i+1);
+      MyRexxRegisterFunctionExe(tmp);
+      sprintf((DEFCHAR *)tmp,"autocolour.%d",i+1);
+      MyRexxRegisterFunctionExe(tmp);
+   }
+ }
+#ifdef THE_TRACE
+ trace_return();
+#endif
+ return(rc);
+}
+/***********************************************************************/
+#ifdef HAVE_PROTO
+CHARTYPE *find_default_parser(CHARTYPE *name,CHARTYPE *tldname)
+#else
+CHARTYPE *find_default_parser(name,tldname)
+CHARTYPE *name;
+CHARTYPE *tldname;
+#endif
+/***********************************************************************/
+{
+/*--------------------------- local data ------------------------------*/
+ int i;
+ CHARTYPE *contents=NULL;
+/*--------------------------- processing ------------------------------*/
+#ifdef THE_TRACE
+ trace_function("default.c: find_default_parser");
+#endif
+/*---------------------------------------------------------------------*/
+ tldname = NULL;
+ for (i=0;;i++)
+ {
+    if (default_parsers[i].filename == NULL)
+       break;
+    if (my_stricmp((DEFCHAR *)default_parsers[i].filename,(DEFCHAR *)name) == 0)
+    {
+       contents = default_parsers[i].contents;
+       tldname = default_parsers[i].filename;
+       break;
+    }
+ }
+#ifdef THE_TRACE
+ trace_return();
+#endif
+ return(contents);
+}
