@@ -3,7 +3,7 @@
 /***********************************************************************/
 /*
  * THE - The Hessling Editor. A text editor similar to VM/CMS xedit.
- * Copyright (C) 1991-1997 Mark Hessling
+ * Copyright (C) 1991-1999 Mark Hessling
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -29,16 +29,15 @@
  * This software is going to be maintained and enhanced as deemed
  * necessary by the community.
  *
- * Mark Hessling                 Email:             M.Hessling@qut.edu.au
- * PO Box 203                    Phone:                    +617 3802 0800
- * Bellara                       http://www.gu.edu.au/gext/the/markh.html
- * QLD 4507                      **** Maintainer PDCurses & REXX/SQL ****
- * Australia                     ************* Author of THE ************
+ * Mark Hessling,  M.Hessling@qut.edu.au  http://www.lightlink.com/hessling/
+ * PO Box 203, Bellara, QLD 4507, AUSTRALIA
+ * Author of THE, a Free XEDIT/KEDIT editor and, Rexx/SQL
+ * Maintainer of PDCurses: Public Domain Curses and, Regina Rexx interpreter
+ * Use Rexx ? join the Rexx Language Association: http://www.rexxla.org
  */
 
-/*
-$Id: directry.c 2.1 1995/06/24 16:29:33 MH Rel MH $
-*/
+static char RCSid[] = "$Id: directry.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
+
 #if defined(__OS2__) && !defined(__EMX__)
 #   define INCL_DOS
 #endif
@@ -47,7 +46,7 @@ $Id: directry.c 2.1 1995/06/24 16:29:33 MH Rel MH $
 #include <proto.h>
 
 #include <directry.h>
-#include <fnmatch.h>
+#include <thematch.h>
 
 #ifdef HAVE_PROTO
 int is_a_dir(ATTR_TYPE);
@@ -55,7 +54,20 @@ int is_a_dir(ATTR_TYPE);
 int is_a_dir();
 #endif
 
-static ATTR_TYPE curr_dirtype = (F_DI | F_AR | F_RO | F_HI | F_SY);
+#define NUM_DIRTYPE 5
+static ATTR_TYPE curr_dirtype = 
+       (F_DI | F_AR | F_RO | F_HI | F_SY);
+static ATTR_TYPE all_dirtype =
+       (F_DI | F_AR | F_RO | F_HI | F_SY);
+static CHARTYPE *dirtype[NUM_DIRTYPE] =
+       {(CHARTYPE *)"normal",
+       (CHARTYPE *)"readonly",
+       (CHARTYPE *)"system",
+       (CHARTYPE *)"hidden",
+       (CHARTYPE *)"directory"};
+static ATTR_TYPE att[NUM_DIRTYPE] =
+       {0,F_RO,F_SY,F_HI,F_DI};
+
 /*********************************************************************/
 #ifdef HAVE_PROTO
 CHARTYPE *make_full(CHARTYPE *path, CHARTYPE *file)
@@ -117,7 +129,7 @@ struct dirfile **dplast;
 
  for (direntp = readdir(dirp);direntp != NULL;direntp = readdir(dirp))
     {
-     if (fnmatch(files,(CHARTYPE *)direntp->d_name,0) == 0)
+     if (thematch(files,(CHARTYPE *)direntp->d_name,0) == 0)
        {
         if ((full_name = make_full(path,(CHARTYPE *)direntp->d_name)) == NULL)
            return(RC_OUT_OF_MEMORY);
@@ -248,7 +260,10 @@ struct dirfile **dplast;
 #if defined (WIN32) && defined(_MSC_VER)
  ffblk.attrib = attrs;
  handle = _findfirst(full_path,&ffblk);
- local = localtime(&ffblk.time_write);
+ if (handle == (-1))
+    done = (-1);
+ else
+    local = localtime(&ffblk.time_write);
 #endif
 #ifdef OS2
 #  if defined(__32BIT__) || defined(__386__)
@@ -272,7 +287,7 @@ struct dirfile **dplast;
 
  while(!done)
     {
-     if (fnmatch(files,ffblk.NAME_NAME,FNM_IGNORECASE) == 0)
+     if (thematch(files,ffblk.NAME_NAME,FNM_IGNORECASE) == 0)
        {
         dp->fname_length = strlen(ffblk.NAME_NAME)+1;
         if ((dp->fname = (CHARTYPE *)(*the_malloc)(dp->fname_length*sizeof(CHARTYPE))) == NULL)
@@ -389,8 +404,6 @@ struct dirfile* next;
 #endif
 /*********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern int DIRORDERx;
 /*--------------------------- local data ------------------------------*/
  int rc=0;
 /*--------------------------- processing ------------------------------*/
@@ -420,8 +433,6 @@ struct dirfile* next;
 #endif
 /*********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern int DIRORDERx;
 /*--------------------------- local data ------------------------------*/
  int rc=0;
 /*--------------------------- processing ------------------------------*/
@@ -449,8 +460,6 @@ struct dirfile* next;
 #endif
 /*********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern int DIRORDERx;
 /*--------------------------- local data ------------------------------*/
  int first_dir=0;
  int next_dir=0;
@@ -485,8 +494,6 @@ struct dirfile* next;
 #endif
 /*********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern int DIRORDERx;
 /*--------------------------- local data ------------------------------*/
  int rc=0;
 /*--------------------------- processing ------------------------------*/
@@ -520,8 +527,6 @@ struct dirfile* next;
 #endif
 /*********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern int DIRORDERx;
 /*--------------------------- local data ------------------------------*/
  int rc=0;
 /*--------------------------- processing ------------------------------*/
@@ -589,7 +594,13 @@ int facl;
 #endif
     case S_IFDIR:  str_attr[0] = 'd'; break;
     case S_IFCHR:  str_attr[0] = 'c'; break;
+#if defined(S_IFIFO)
     case S_IFIFO:  str_attr[0] = 'p'; break;
+#else
+# if defined(S_IFFIFO)
+    case S_IFFIFO:  str_attr[0] = 'p'; break;
+# endif
+#endif
 #if defined(S_IFSOCK)
     case S_IFSOCK: str_attr[0] = 's'; break;
 #endif
@@ -654,15 +665,6 @@ CHARTYPE *params;
 /***********************************************************************/
 {
 /*--------------------------- local data ------------------------------*/
-#define NUM_DIRTYPE 5
- static CHARTYPE *dirtype[NUM_DIRTYPE] =
-         {(CHARTYPE *)"normal",
-          (CHARTYPE *)"readonly",
-          (CHARTYPE *)"system",
-          (CHARTYPE *)"hidden",
-          (CHARTYPE *)"directory"};
- static ATTR_TYPE att[NUM_DIRTYPE] =
-         {0,F_RO,F_SY,F_HI,F_DI};
  CHARTYPE *p=NULL;
  register short i=0;
  ATTR_TYPE attribs=0;
@@ -699,4 +701,34 @@ CHARTYPE *params;
    }
  curr_dirtype = attribs;
  return(RC_OK);
- }
+}
+
+/*********************************************************************/
+#ifdef HAVE_PROTO
+CHARTYPE *get_dirtype(CHARTYPE *buf)
+#else
+CHARTYPE *get_dirtype(buf)
+CHARTYPE *buf;
+#endif
+/***********************************************************************/
+{
+/*--------------------------- local data ------------------------------*/
+/*--------------------------- processing ------------------------------*/
+ if (curr_dirtype == all_dirtype)                 /* all masks enabled */
+   {
+    strcpy((DEFCHAR*)buf,"*");
+   }
+ else
+   {
+    strcpy((DEFCHAR*)buf,"normal");
+    if (curr_dirtype & F_DI)
+       strcat((DEFCHAR*)buf," directory");
+    if (curr_dirtype & F_RO)
+       strcat((DEFCHAR*)buf," readonly");
+    if (curr_dirtype & F_HI)
+       strcat((DEFCHAR*)buf," hidden");
+    if (curr_dirtype & F_SY)
+       strcat((DEFCHAR*)buf," system");
+   }
+ return(buf);
+}
