@@ -3,7 +3,7 @@
 /***********************************************************************/
 /*
  * THE - The Hessling Editor. A text editor similar to VM/CMS xedit.
- * Copyright (C) 1991-1997 Mark Hessling
+ * Copyright (C) 1991-1999 Mark Hessling
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -29,16 +29,14 @@
  * This software is going to be maintained and enhanced as deemed
  * necessary by the community.
  *
- * Mark Hessling                 Email:             M.Hessling@qut.edu.au
- * PO Box 203                    Phone:                    +617 3802 0800
- * Bellara                       http://www.gu.edu.au/gext/the/markh.html
- * QLD 4507                      **** Maintainer PDCurses & REXX/SQL ****
- * Australia                     ************* Author of THE ************
+ * Mark Hessling,  M.Hessling@qut.edu.au  http://www.lightlink.com/hessling/
+ * PO Box 203, Bellara, QLD 4507, AUSTRALIA
+ * Author of THE, a Free XEDIT/KEDIT editor and, Rexx/SQL
+ * Maintainer of PDCurses: Public Domain Curses and, Regina Rexx interpreter
+ * Use Rexx ? join the Rexx Language Association: http://www.rexxla.org
  */
 
-/*
-$Id: error.c 2.1 1995/06/24 16:29:50 MH Rel MH $
-*/
+static char RCSid[] = "$Id: error.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
 
 #include <the.h>
 #include <proto.h>
@@ -67,19 +65,6 @@ bool ignore_bell;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern WINDOW *error_window;
- extern bool error_on_screen;
- extern bool in_nomsg;
- extern bool first_screen_display;
- extern bool curses_started;
- extern bool BEEPx;
- extern CHARTYPE number_of_files;
- extern bool rexx_output;
- extern bool CAPREXXOUTx;
- extern LINE *rexxout_first_line;
- extern LINE *rexxout_curr;
- extern LINETYPE rexxout_number_lines;
 /*--------------------------- local data ------------------------------*/
 
 static CHARTYPE *error_message[] =
@@ -146,7 +131,7 @@ static CHARTYPE *error_message[] =
  (CHARTYPE *)"",
  (CHARTYPE *)"Error 0060: Line name not found:",
  (CHARTYPE *)"Error 0061: Colour support not available:",
- (CHARTYPE *)"",
+ (CHARTYPE *)"Error 0062: Operation invalid for multi-line stream blocks",
  (CHARTYPE *)"Error 0063: Invalid cursor line or column",
  (CHARTYPE *)"Error 0064: Line not reserved",
  (CHARTYPE *)"",
@@ -162,20 +147,149 @@ static CHARTYPE *error_message[] =
  (CHARTYPE *)"",
  (CHARTYPE *)"",
  (CHARTYPE *)"Error 0077: Files still open in batch:",
- (CHARTYPE *)"",
+ (CHARTYPE *)"Error 0078: Printing error:",
  (CHARTYPE *)"Error 0079: Can't add another tab position; already have 32 defined",
- (CHARTYPE *)"",
+ (CHARTYPE *)"Error 0080: Can't add another CTLCHAR; already have 64 defined",
  (CHARTYPE *)"Error 0081: Only single-line marked blocks allowed",
- (CHARTYPE *)"Error 0082: Support for this command unavailable",
+ (CHARTYPE *)"Error 0082: Feature not supported:",
  (CHARTYPE *)"Error 0083: Command invalid when ring is empty",
  (CHARTYPE *)"Unable to restore",
  (CHARTYPE *)"Error 0085: Length of operand > 10",
  (CHARTYPE *)"Error 0086: Command line unavailable",
- (CHARTYPE *)"Error 0087: Cursor line not in scope"
+ (CHARTYPE *)"Error 0087: Cursor line not in scope",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"Error 0138: Unexpected file time stamp change - use FFILE/SSAVE",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"Error 0186: Error accessing clipboard",
+ (CHARTYPE *)"Error 0187: No text in clipboard",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"Error 0199: Parser not defined:",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"",
+ (CHARTYPE *)"Error 0216: TLD error:",
 };
  int new_last_message_length = 0;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("error.c:   display_error");
 #endif
 /*---------------------------------------------------------------------*/
@@ -212,7 +326,7 @@ static CHARTYPE *error_message[] =
    {
     if (!CURRENT_VIEW->msgmode_status)
       {
-#ifdef TRACE
+#ifdef THE_TRACE
        trace_return();
 #endif
        return;
@@ -224,7 +338,7 @@ static CHARTYPE *error_message[] =
 /*---------------------------------------------------------------------*/
  if (in_nomsg)
    {
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return;
@@ -233,39 +347,41 @@ static CHARTYPE *error_message[] =
 #ifdef MSWIN
  {
  char hdr[512];
- if(in_profile)
-      {
-      if(!error_on_screen)
-           {
-           if(number_of_files == 0)
-                sprintf(hdr,"*** Messages from profile file  ***\n");
-                else
-                sprintf(hdr,"*** Messages from profile file for ***\n%s%s\n",
+ if (in_profile)
+ {
+    if (!error_on_screen
+    &&  !be_quiet)
+    {
+       if (number_of_files == 0)
+          sprintf(hdr,"*** Messages from profile file  ***\n");
+       else
+          sprintf(hdr,"*** Messages from profile file for ***\n%s%s\n",
                          CURRENT_FILE->fpath,CURRENT_FILE->fname);
-           }
-      error_on_screen = TRUE;
-      Operator("%s%s",hdr,last_message);
-      return;
-      }
+    }
+    error_on_screen = TRUE;
+    Operator("%s%s",hdr,last_message);
+    return;
+ }
  }
 #else
  if (!curses_started)
-   {
-    if (!error_on_screen)
-      {
+ {
+    if (!error_on_screen
+    &&  !be_quiet)
+    {
        if (number_of_files == 0)
-          fprintf(stderr,"*** Messages from profile file  ***\n");
+          fprintf(stderr,"*** Messages from profile file ***\n");
        else
           fprintf(stderr,"*** Messages from profile file for %s%s ***\n",
                          CURRENT_FILE->fpath,CURRENT_FILE->fname);
-      }
+    }
     error_on_screen = TRUE;
     fprintf(stderr,"%s\n",last_message);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return;
-   }
+ }
 #endif
 /*---------------------------------------------------------------------*/
 /* Append the current message to the end of the error linked list.     */
@@ -294,7 +410,7 @@ static CHARTYPE *error_message[] =
  &&  rexx_output)
    {
     rexxout_number_lines++;
-    rexxout_curr = add_line(rexxout_first_line,rexxout_curr,
+    rexxout_curr = add_LINE(rexxout_first_line,rexxout_curr,
                             last_message,strlen((DEFCHAR *)last_message),0,FALSE);
    }
 #ifdef HAVE_BEEP
@@ -304,7 +420,7 @@ static CHARTYPE *error_message[] =
 #endif
  if (first_screen_display)
     wrefresh(error_window);
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return;
@@ -320,13 +436,11 @@ ROWTYPE rows;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern WINDOW *error_window;
 /*--------------------------- local data ------------------------------*/
  int start_row=0;
  COLOUR_ATTR attr;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("error.c:   open_msgline");
 #endif
  if (CURRENT_VIEW == NULL
@@ -341,41 +455,46 @@ ROWTYPE rows;
     delwin(error_window);
  error_window = newwin(rows,CURRENT_SCREEN.screen_cols,CURRENT_SCREEN.screen_start_row+start_row,CURRENT_SCREEN.screen_start_col);
  wattrset(error_window,set_colour(&attr));
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return;
 }
 /***********************************************************************/
 #ifdef HAVE_PROTO
-void clear_msgline(void)
+void clear_msgline(int key)
 #else
-void clear_msgline()
+void clear_msgline(key)
+int key;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern WINDOW *error_window;
- extern bool error_on_screen;
- extern CHARTYPE display_screens;
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("error.c:   clear_msgline");
 #endif
- errors_displayed = 0;
- error_on_screen = FALSE;
- if (error_window != (WINDOW *)NULL)
+ /*
+  * Only clear the message line if the supplied key matches that set
+  * by SET CLEARERRORKEY.  -1 indicates any key can clear
+  */
+ if (key == CLEARERRORKEYx
+ ||  CLEARERRORKEYx == -1)
    {
-    delwin(error_window);
-    error_window = (WINDOW *)NULL;
+    errors_displayed = 0;
+    error_on_screen = FALSE;
+    if (error_window != (WINDOW *)NULL)
+      {
+       delwin(error_window);
+       error_window = (WINDOW *)NULL;
+      }
+    first_error = last_error = lll_free(first_error);
+    if (display_screens > 1)
+       redraw_screen(other_screen);
+    redraw_screen(current_screen);
+    doupdate();
    }
- first_error = last_error = lll_free(first_error);
- if (display_screens > 1)
-    redraw_screen(other_screen);
- redraw_screen(current_screen);
- doupdate();
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return;
@@ -389,12 +508,9 @@ CHARTYPE *prompt;
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern WINDOW *error_window;
- extern bool error_on_screen;
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("error.c:   display_prompt");
 #endif
  open_msgline(CURRENT_VIEW->msgline_base,CURRENT_VIEW->msgline_off,1);
@@ -403,7 +519,7 @@ CHARTYPE *prompt;
  put_string(error_window,0,0,prompt,strlen((DEFCHAR *)prompt));
  wrefresh(error_window);
  error_on_screen = TRUE;
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return;
@@ -416,9 +532,6 @@ void expose_msgline()
 #endif
 /***********************************************************************/
 {
-/*------------------------- external data -----------------------------*/
- extern WINDOW *error_window;
- extern bool error_on_screen;
 /*--------------------------- local data ------------------------------*/
  LINE *curr_error=NULL;
  register int i=0,errors_to_display=0;
@@ -426,7 +539,7 @@ void expose_msgline()
  short msgline_off=2;
  ROWTYPE msgline_rows=5;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("error.c:   expose_msgline");
 #endif
 /*---------------------------------------------------------------------*/
@@ -436,7 +549,7 @@ void expose_msgline()
    {
     if (!CURRENT_VIEW->msgmode_status)
       {
-#ifdef TRACE
+#ifdef THE_TRACE
        trace_return();
 #endif
        return;
@@ -472,7 +585,7 @@ void expose_msgline()
    }
  wnoutrefresh(error_window);
  error_on_screen = TRUE;
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return;
