@@ -3,7 +3,7 @@
 /***********************************************************************/
 /*
  * THE - The Hessling Editor. A text editor similar to VM/CMS xedit.
- * Copyright (C) 1991-1997 Mark Hessling
+ * Copyright (C) 1991-1999 Mark Hessling
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -29,17 +29,19 @@
  * This software is going to be maintained and enhanced as deemed
  * necessary by the community.
  *
- * Mark Hessling                 Email:             M.Hessling@qut.edu.au
- * PO Box 203                    Phone:                    +617 3802 0800
- * Bellara                       http://www.gu.edu.au/gext/the/markh.html
- * QLD 4507                      **** Maintainer PDCurses & REXX/SQL ****
- * Australia                     ************* Author of THE ************
+ * Mark Hessling,  M.Hessling@qut.edu.au  http://www.lightlink.com/hessling/
+ * PO Box 203, Bellara, QLD 4507, AUSTRALIA
+ * Author of THE, a Free XEDIT/KEDIT editor and, Rexx/SQL
+ * Maintainer of PDCurses: Public Domain Curses and, Regina Rexx interpreter
+ * Use Rexx ? join the Rexx Language Association: http://www.rexxla.org
  *
  * The code in this module is borrowed from:
  * The Regina Rexx Interpreter
  * Copyright (C) 1992-1994  Anders Christensen <anders@pvv.unit.no>
  */
 
+static char RCSid[] = "$Id: memory.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
+
 /*
  * The routines in this file try to minimize the the number of calls
  * to malloc() and free(). Since it would generally not be possible to
@@ -82,7 +84,7 @@
  *
  * If you don't #define FLISTS, then malloc() and free() should be
  * used instead. That might be very slow on some machines, since rexx
- * tend to use lots of small size memory. If you #define TRACEMEM,
+ * tend to use lots of small size memory. If you #define THE_TRACEMEM,
  * memory is traced, which also tend to be slow, since there is a lot
  * of overhead in allocation and deallocation. Also note that in the
  * current implementation you can use malloc()/free() in parallel with
@@ -95,7 +97,7 @@
  * this metod (typical less than 100 for medium sized programs). But
  * this is of course dependent on how the program uses memory. 
  *
- * The tracing part of this file, (#ifdef TRACEMEM) is an optional
+ * The tracing part of this file, (#ifdef THE_TRACEMEM) is an optional
  * extention for debugging purposes. Whenever memory is allocated,
  * mymalloc() allocates 16 bytes more than needed. These bytes are
  * used like this:
@@ -113,7 +115,7 @@
  * there to fill the space, and can be used for more useful purposed
  * if needed.
  *
- * An additional option to TRACEMEM is filling allocated and deallocated
+ * An additional option to THE_TRACEMEM is filling allocated and deallocated
  * memory with bitpatterns. If the PATTERN_MEMORY cpp-variable is set,
  * all allocated memory is initated to NOT_USED, and deallocated memory 
  * is set BEEN_USED before deallocation.
@@ -127,12 +129,36 @@
  * be traced and then garbage collected, or it should have a sort 
  * of transaction oriented memory management (yuk!).
  *
- * NOTE that #define'ing TRACEMEM requires that your machine follows
+ * NOTE that #define'ing THE_TRACEMEM requires that your machine follows
  *      this:  sizeof(int) = sizeof(char*) = 32 bits. It might work
  *      for other machines to (having larger word size), but I don't
  *      guarantee it. 
  *
  */
+#ifdef __BOUNDS_CHECKING_ON
+void *get_a_block( int size )
+{
+   return( malloc( size ) );
+}
+
+void give_a_block( void *ptr )
+{
+   free( ptr );
+}
+
+void *resize_a_block( void *ptr, int size )
+{
+   return( realloc( ptr, size ) );
+}
+
+void init_memory_table( void )
+{
+}
+
+void the_free_flists( void )
+{
+}
+#else
 
 #define FLISTS
 #define PATTERN_MEMORY
@@ -284,7 +310,7 @@ void *chunk;
 {
    meminfo *mem=NULL;
 
-   if ((mem = malloc( sizeof( meminfo ))) == NULL )
+   if ((mem = (meminfo *)malloc( sizeof( meminfo ))) == NULL )
       return(1);
    mem->start = chunk;
    mem->next = NULL;
@@ -455,7 +481,7 @@ int bin_no;
    if (indeks>=128)
    {
       /* Stupid SunOS acc gives incorrect warning for the next line */
-      if  (!(mem = malloc( sizeof( meminfo) * 128 )))
+      if  (!(mem = (meminfo *)malloc( sizeof( meminfo) * 128 )))
           return(1);
       if (register_mem( (void *)mem ))
          return(1);
@@ -467,7 +493,7 @@ int bin_no;
     * requested bin in hashtable
     */
    ptr = &mem[ indeks++ ] ;   
-   ptr->next = hashtable[tmp=mem_hash_func((unsigned int)addr)] ;
+   ptr->next = hashtable[tmp=mem_hash_func((unsigned long)addr)] ;
    ptr->size = bin_no ;
    ptr->start = start ;
    hashtable[tmp] = ptr ;
@@ -590,7 +616,7 @@ void *ptr;
     * hashtable that returns memory size given a specific address
     */
    cptr = (char*)ptr ;
-   mptr = hashtable[ mem_hash_func( ((unsigned int)cptr) ) ] ;
+   mptr = hashtable[ mem_hash_func( ((unsigned long)cptr) ) ] ;
 
    /* 
     * For each element in the list attached to the specific hashvalue, 
@@ -647,7 +673,7 @@ int size;
     * hashtable that returns memory size given a specific address
     */
    cptr = (char*)ptr ;
-   mptr = hashtable[ mem_hash_func( ((unsigned int)cptr) ) ] ;
+   mptr = hashtable[ mem_hash_func( ((unsigned long)cptr) ) ] ;
 
    /* 
     * For each element in the list attached to the specific hashvalue, 
@@ -720,4 +746,4 @@ void the_free_flists()
    }
    return;
 }
-
+#endif /* __BOUNDS_CHECKING_ON */
