@@ -4,7 +4,7 @@
 /***********************************************************************/
 /*
  * THE - The Hessling Editor. A text editor similar to VM/CMS xedit.
- * Copyright (C) 1991-1997 Mark Hessling
+ * Copyright (C) 1991-1999 Mark Hessling
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -30,16 +30,14 @@
  * This software is going to be maintained and enhanced as deemed
  * necessary by the community.
  *
- * Mark Hessling                 Email:             M.Hessling@qut.edu.au
- * PO Box 203                    Phone:                    +617 3802 0800
- * Bellara                       http://www.gu.edu.au/gext/the/markh.html
- * QLD 4507                      **** Maintainer PDCurses & REXX/SQL ****
- * Australia                     ************* Author of THE ************
+ * Mark Hessling,  M.Hessling@qut.edu.au  http://www.lightlink.com/hessling/
+ * PO Box 203, Bellara, QLD 4507, AUSTRALIA
+ * Author of THE, a Free XEDIT/KEDIT editor and, Rexx/SQL
+ * Maintainer of PDCurses: Public Domain Curses and, Regina Rexx interpreter
+ * Use Rexx ? join the Rexx Language Association: http://www.rexxla.org
  */
 
-/*
-$Id: nonansi.c 2.1 1995/06/24 16:30:30 MH Rel MH $
-*/
+static char RCSid[] = "$Id: nonansi.c,v 1.2 1999/08/07 06:27:43 mark Exp mark $";
 
 #include <the.h>
 #include <proto.h>
@@ -79,17 +77,17 @@ CHARTYPE *filename;
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("nonansi.c: file_readable");
 #endif
  if (access((DEFCHAR *)filename,R_OK) == (-1))
    {
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(FALSE);
    }
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
  return(TRUE);
@@ -105,24 +103,24 @@ CHARTYPE *filename;
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("nonansi.c: file_writable");
 #endif
  if (!file_exists(filename))
    {
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(TRUE);
    }
  if (access((DEFCHAR *)filename,W_OK) == (-1))
    {
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(FALSE);
    }
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(TRUE);
@@ -138,17 +136,17 @@ CHARTYPE *filename;
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("nonansi.c: file_exists");
 #endif
  if (access((DEFCHAR *)filename,F_OK) == (-1))
    {
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(FALSE);
    }
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(TRUE);
@@ -164,7 +162,7 @@ CHARTYPE *filename;
 {
 /*--------------------------- local data ------------------------------*/
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("nonansi.c: remove_file");
 #endif
 if(filename == NULL)
@@ -175,12 +173,12 @@ if(filename == NULL)
  if (unlink((DEFCHAR *)filename) == (-1))
 #endif
    {
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_ACCESS_DENIED);
    }
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(RC_OK);
@@ -195,10 +193,6 @@ CHARTYPE *filename;
 #endif
 /***********************************************************************/
 {
-/*-------------------------- external data ----------------------------*/
- extern CHARTYPE curr_path[MAX_FILE_NAME+1];
- extern CHARTYPE sp_fname[MAX_FILE_NAME+1];
- extern CHARTYPE sp_path[MAX_FILE_NAME+1];
 /*--------------------------- local data ------------------------------*/
  short len=0;
  CHARTYPE work_filename[MAX_FILE_NAME+1] ;
@@ -220,8 +214,16 @@ CHARTYPE *filename;
  unsigned int temp_disk=0;
 #endif
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("nonansi.c: splitpath");
+#endif
+/*---------------------------------------------------------------------*/
+/* Save the current directory.                                         */
+/*---------------------------------------------------------------------*/
+#if defined(EMX)
+ _getcwd2(curr_path,MAX_FILE_NAME);
+#else
+ getcwd((DEFCHAR *)curr_path,MAX_FILE_NAME);
 #endif
  strcpy(sp_path,"");
  strcpy(sp_fname,"");
@@ -299,7 +301,7 @@ CHARTYPE *filename;
 
     if (temp_disk != new_dos_disk)  /* invalid drive */
       {
-#ifdef TRACE
+#ifdef THE_TRACE
        trace_return();
 #endif
        return (RC_BAD_DRIVE);
@@ -410,7 +412,7 @@ CHARTYPE *filename;
 #endif
       }
     chdir(curr_path);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_FILE_NOT_FOUND);
@@ -432,7 +434,7 @@ CHARTYPE *filename;
    {
     if (chdir(current_dir) != 0)
       {
-#ifdef TRACE
+#ifdef THE_TRACE
        trace_return();
 #endif
        return(RC_FILE_NOT_FOUND);
@@ -467,7 +469,126 @@ CHARTYPE *filename;
     if (sp_path[len-1] != ISLASH)
        strcat(sp_path,(CHARTYPE *)ISTR_SLASH);
 #endif
-#ifdef TRACE
+#ifdef THE_TRACE
+ trace_return();
+#endif
+ return(RC_OK);
+}
+#elif defined(__QNX__)
+/***********************************************************************/
+#ifdef HAVE_PROTO
+short splitpath(CHARTYPE *filename)
+#else
+short splitpath(filename)
+CHARTYPE *filename;
+#endif
+/***********************************************************************/
+{
+/*--------------------------- local data ------------------------------*/
+ short len=0;
+ CHARTYPE work_filename[MAX_FILE_NAME+1] ;
+/*--------------------------- processing ------------------------------*/
+#ifdef THE_TRACE
+ trace_function("nonansi.c: splitpath");
+#endif
+/*---------------------------------------------------------------------*/
+/* Copy the argument to a working area                                 */
+/*---------------------------------------------------------------------*/
+ getcwd((DEFCHAR *)curr_path,MAX_FILE_NAME);
+ strcpy((DEFCHAR *)sp_path,"");
+ strcpy((DEFCHAR *)sp_fname,"");
+ strcpy((DEFCHAR *)work_filename,(DEFCHAR *)filename);
+/*---------------------------------------------------------------------*/
+/* If the supplied filename is empty, set the path = cwd and filename  */
+/* equal to blank.                                                     */
+/*---------------------------------------------------------------------*/
+ if (strcmp((DEFCHAR *)filename,"") == 0)
+ {
+    getcwd((DEFCHAR *)sp_path,MAX_FILE_NAME);
+    strcpy((DEFCHAR *)sp_fname,"");
+ }
+/*---------------------------------------------------------------------*/
+/* Check if the first character is tilde; translate HOME env variable  */
+/* if there is one. Obviously only applicable to UNIX.                 */
+/*---------------------------------------------------------------------*/
+ if (*(work_filename) == '~')
+ {
+    if (*(work_filename+1) == ISLASH
+    ||  *(work_filename+1) == '\0')
+    {
+       strcpy((DEFCHAR *)work_filename,(DEFCHAR *)getenv("HOME"));
+       strcat((DEFCHAR *)work_filename,(DEFCHAR *)(filename+1));
+    }
+    else
+    {
+       struct passwd *pwd;
+
+       strcpy((DEFCHAR *)sp_path,(DEFCHAR *)filename+1);
+       if ((len = strzeq(sp_path,ISLASH)) != (-1))
+          sp_path[len] = '\0';
+       if ((pwd = getpwnam((DEFCHAR *)sp_path)) == NULL)
+          return(RC_BAD_FILEID);
+       strcpy((DEFCHAR *)work_filename,pwd->pw_dir);
+       if (len != (-1))
+          strcat((DEFCHAR *)work_filename,(DEFCHAR *)(filename+1+len));
+    }
+ }
+/*---------------------------------------------------------------------*/
+/* First determine if the supplied filename is a directory.            */
+/*---------------------------------------------------------------------*/
+ if (chdir(work_filename) == 0)
+ {
+    chdir(curr_path);
+    strcpy((DEFCHAR *)sp_path,(DEFCHAR *)work_filename);
+    strcpy((DEFCHAR *)sp_fname,"");
+ }
+ else          /* here if the file doesn't exist or is not a directory */
+ {
+    len = strzreveq(work_filename,ISLASH);
+    switch(len)
+    {
+       case (-1):
+          getcwd((DEFCHAR *)sp_path,MAX_FILE_NAME);
+          strcpy((DEFCHAR *)sp_fname,(DEFCHAR *)work_filename);
+          break;
+       case 0:
+          strcpy((DEFCHAR *)sp_path,(DEFCHAR *)work_filename);
+          sp_path[1] = '\0';
+          strcpy((DEFCHAR *)sp_fname,(DEFCHAR *)work_filename+1+len);
+          break;
+      default:
+          strcpy((DEFCHAR *)sp_path,(DEFCHAR *)work_filename);
+          sp_path[len] = '\0';
+          strcpy((DEFCHAR *)sp_fname,(DEFCHAR *)work_filename+1+len);
+          break;
+    }
+ }
+/*---------------------------------------------------------------------*/
+/* Change directory to the supplied path, if possible and store the    */
+/* expanded path.                                                      */
+/* If an error, restore the current path.                              */
+/*---------------------------------------------------------------------*/
+ if (qnx_fullpath((DEFCHAR *)work_filename,(DEFCHAR *)sp_path) == NULL)
+ {
+    chdir((DEFCHAR *)curr_path);
+#ifdef THE_TRACE
+    trace_return();
+#endif
+    return(RC_FILE_NOT_FOUND);
+ }
+ strcpy(sp_path,work_filename);
+ chdir((DEFCHAR *)curr_path);
+/*---------------------------------------------------------------------*/
+/* Append the OS directory character to the path if it doesn't already */
+/* end in the character.                                               */
+/*---------------------------------------------------------------------*/
+ len = strlen((DEFCHAR *)sp_path);
+ if (len > 0)
+ {
+    if (sp_path[len-1] != ISLASH)
+       strcat((DEFCHAR *)sp_path,(DEFCHAR *)ISTR_SLASH);
+ }
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(RC_OK);
@@ -482,17 +603,20 @@ CHARTYPE *filename;
 #endif
 /***********************************************************************/
 {
-/*-------------------------- external data ----------------------------*/
- extern CHARTYPE curr_path[MAX_FILE_NAME+1];
- extern CHARTYPE sp_fname[MAX_FILE_NAME+1];
- extern CHARTYPE sp_path[MAX_FILE_NAME+1];
- extern struct stat stat_buf;
 /*--------------------------- local data ------------------------------*/
  short len=0;
  CHARTYPE work_filename[MAX_FILE_NAME+1] ;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("nonansi.c: splitpath");
+#endif
+/*---------------------------------------------------------------------*/
+/* Save the current directory.                                         */
+/*---------------------------------------------------------------------*/
+#if defined(EMX)
+ _getcwd2(curr_path,MAX_FILE_NAME);
+#else
+ getcwd((DEFCHAR *)curr_path,MAX_FILE_NAME);
 #endif
  strcpy((DEFCHAR *)sp_path,"");
  strcpy((DEFCHAR *)sp_fname,"");
@@ -512,7 +636,8 @@ CHARTYPE *filename;
 /*---------------------------------------------------------------------*/
  if (*(work_filename) == '~')
    {
-    if (*(work_filename+1) == ISLASH)
+    if (*(work_filename+1) == ISLASH
+    ||  *(work_filename+1) == '\0')
       {
        strcpy((DEFCHAR *)work_filename,(DEFCHAR *)getenv("HOME"));
        strcat((DEFCHAR *)work_filename,(DEFCHAR *)(filename+1));
@@ -569,7 +694,7 @@ CHARTYPE *filename;
  if (chdir((DEFCHAR *)sp_path) != 0)
    {
     chdir((DEFCHAR *)curr_path);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_FILE_NOT_FOUND);
@@ -586,7 +711,7 @@ CHARTYPE *filename;
     if (sp_path[len-1] != ISLASH)
        strcat((DEFCHAR *)sp_path,(DEFCHAR *)ISTR_SLASH);
 #endif
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(RC_OK);
@@ -609,24 +734,24 @@ CHARTYPE *path2;
 /* Return    : 0 on success, -1 on error                               */
 /***********************************************************************/
 {
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("nonansi.c: rename");
 #endif
   if (link(path1,path2) != 0)
     {
-#ifdef TRACE
+#ifdef THE_TRACE
      trace_return();
 #endif
      return(-1);
     }
   if (unlink(path1) != 0)
     {
-#ifdef TRACE
+#ifdef THE_TRACE
      trace_return();
 #endif
      return(-1);
     }
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(0);
@@ -645,7 +770,7 @@ bool IsPathAndFilenameValid(CHARTYPE *PathFn)
  CHARTYPE FullFn[CCHMAXPATH];
  CHARTYPE *buf;
  ULONG rc;
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("nonansi.c: IsPathAndFilenameValid");
 #endif
 
@@ -689,7 +814,7 @@ bool LongFileNames(CHARTYPE *path)
         char bName[3];
         ULONG bDataLen=0L;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("nonansi.c: LongFileNames");
 #endif
  if ((strlen (path) > 0) && path [1] == ':')
@@ -733,7 +858,7 @@ typedef FSQINFO FAR *PFSQINFO;
  BYTE bName[3];
  FSNAME *pFSName=NULL;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("nonansi.c: LongFileNames");
 #endif
  if ((strlen(path) > 0) && path[1] == ':')
@@ -794,3 +919,280 @@ short drive;
  return ((short) regs.h.al);
 }
 #endif
+
+/***********************************************************************/
+#ifdef HAVE_PROTO
+LINE *getclipboard(LINE *now)
+#else
+LINE *getclipboard(now)
+LINE *now;
+#endif
+/***********************************************************************/
+/* Function  : Reads the contents of the clipboard into the file.      */
+/* Parameters: pointer to line after which lines are to be added       */
+/* Return    : 0 on success.                                           */
+/***********************************************************************/
+{
+/*--------------------------- local data ------------------------------*/
+ CHARTYPE *ptr=NULL;
+ LINE *curr=now;
+ LINETYPE i,line_start,numlines=0;
+ LENGTHTYPE maxlen=0;
+ long length=0;
+ short rc=RC_OK;
+#if defined(UNIX) || defined(MAC)
+ int offset = 0;
+#else
+ int offset = 1;
+#endif
+/*--------------------------- processing ------------------------------*/
+#ifdef THE_TRACE
+ trace_function("nonansi.c: getclipboard");
+#endif
+#if defined(PDC_CLIP_SUCCESS) && !defined(DOS)
+ rc = PDC_getclipboard( (DEFCHAR **)&ptr, &length );
+
+ switch( rc )
+ {
+    case PDC_CLIP_MEMORY_ERROR:
+       display_error(30,(CHARTYPE *)"",FALSE);
+       rc = RC_OUT_OF_MEMORY;
+       break;
+    case PDC_CLIP_ACCESS_ERROR:
+       display_error(186,(CHARTYPE *)"",FALSE);
+       rc = RC_INVALID_ENVIRON;
+       break;
+    case PDC_CLIP_EMPTY:
+       display_error(187,(CHARTYPE *)"",FALSE);
+       rc = RC_INVALID_ENVIRON;
+       break;
+    default:
+       rc = RC_OK;
+       break;
+ }
+#else
+ display_error(82,(CHARTYPE *)"CLIP:",FALSE);
+#ifdef THE_TRACE
+ trace_return();
+#endif
+ return NULL;
+#endif
+ if (rc != RC_OK)
+ {
+#ifdef THE_TRACE
+    trace_return();
+#endif
+    return NULL;
+ }
+
+ line_start=0;
+
+ for (i=0; i<length; i++)
+ {
+    if (*(ptr+i) == 0x0A) /* CR was prior character */
+    {
+       *(ptr+i-offset) = '\0';
+       if ((curr = add_LINE(CURRENT_FILE->first_line,curr,ptr+line_start,i-line_start-offset,0,TRUE)) == NULL)
+       {
+          curr = NULL;
+          break;
+       }
+       line_start = i+1;
+       numlines++;
+       if (i-line_start-offset > maxlen)
+          maxlen = i-line_start-offset;
+    }
+ }
+ if (line_start != i
+ &&  curr)
+ {
+    curr = add_LINE(CURRENT_FILE->first_line,curr,ptr+line_start,i-line_start,0,TRUE);
+    numlines++;
+    if (i-line_start > maxlen)
+       maxlen = i-line_start;
+ }
+
+ if (curr)
+ {
+    CURRENT_FILE->max_line_length = maxlen;
+    CURRENT_FILE->number_lines += numlines;
+ }
+ free(ptr);
+ return curr;
+}
+/***********************************************************************/
+#ifdef HAVE_PROTO
+short setclipboard(FILE_DETAILS *cf,CHARTYPE *new_fname,bool force,LINETYPE in_lines,
+                LINETYPE start_line,LINETYPE *num_file_lines,bool append,LENGTHTYPE start_col, LENGTHTYPE end_col,bool ignore_scope,bool lines_based_on_scope)
+#else
+short setclipboard(cf,new_fname,force,in_lines,start_line,num_file_lines,append,start_col,end_col,ignore_scope,lines_based_on_scope)
+FILE_DETAILS *cf;
+CHARTYPE *new_fname;
+bool force,append;
+LINETYPE in_lines,start_line;
+LINETYPE *num_file_lines;
+LENGTHTYPE start_col,end_col;
+bool ignore_scope;
+bool lines_based_on_scope;
+#endif
+/***********************************************************************/
+{
+/*--------------------------- local data ------------------------------*/
+ LINETYPE i=0L;
+ LINETYPE abs_num_lines=(in_lines < 0L ? -in_lines : in_lines);
+ LINETYPE num_actual_lines=0L;
+ LINETYPE my_num_file_lines=0L;
+ short direction=(in_lines < 0L ? DIRECTION_BACKWARD : DIRECTION_FORWARD);
+ LINE *curr=NULL;
+ short rc=RC_OK;
+ bool save_scope_all=CURRENT_VIEW->scope_all;
+#ifdef UNIX
+ CHARTYPE *eol = (CHARTYPE *)"\n";
+ int eol_len=1;
+#elif defined(MAC)
+ CHARTYPE *eol = (CHARTYPE *)"\r";
+ int eol_len=1;
+#else
+ CHARTYPE *eol = (CHARTYPE *)"\r\n";
+ int eol_len=2;
+#endif
+ long clip_size=1024;
+ CHARTYPE *ptr=NULL;
+ long len=0,pos=0;
+/*--------------------------- processing ------------------------------*/
+#ifdef THE_TRACE
+ trace_function("file.c:    setclipboard");
+#endif
+/*---------------------------------------------------------------------*/
+/* Determine where to start writing from in the linked list.           */
+/*---------------------------------------------------------------------*/
+ curr = lll_find(cf->first_line,cf->last_line,start_line,cf->number_lines);
+/*---------------------------------------------------------------------*/
+/* Save the setting of scope_all if we are ignoring scope. ie full file*/
+/* is being written...                                                 */
+/*---------------------------------------------------------------------*/
+ if (ignore_scope)
+    CURRENT_VIEW->scope_all = TRUE;
+/*---------------------------------------------------------------------*/
+/* Now write out the contents of the file array to the new filename.   */
+/*---------------------------------------------------------------------*/
+ ptr = (CHARTYPE *)malloc(clip_size);
+ if (!ptr)
+ {
+    display_error(30,(CHARTYPE *)"",FALSE);
+#ifdef THE_TRACE
+    trace_return();
+#endif
+    return(RC_OUT_OF_MEMORY);
+ }
+
+ rc = RC_OK;
+ for (i=0L,num_actual_lines=0L;;i++)
+ {
+    if (lines_based_on_scope)
+    {
+       if (num_actual_lines == abs_num_lines)
+          break;
+    }
+    else
+    {
+       if (abs_num_lines == i)
+          break;
+    }
+    rc = processable_line(CURRENT_VIEW,start_line+(LINETYPE)(i*direction),curr);
+    switch(rc)
+    {
+       case LINE_SHADOW:
+            rc = 0;
+            break;
+       case LINE_TOF:
+       case LINE_EOF:
+            rc = 0;
+            num_actual_lines++;
+            break;
+       default:
+            rc = 0;
+            if (start_col < curr->length)
+            {
+               len = min(curr->length-start_col,(end_col - start_col) + 1);
+               if ( pos + len > clip_size)
+               {
+                  ptr = (CHARTYPE *)realloc((DEFCHAR *)ptr, clip_size * 2);
+                  clip_size *= 2;
+               }
+               memcpy((DEFCHAR *)ptr+pos,(DEFCHAR *)curr->line+start_col,len);
+               /*
+               if ((rc = write_line(curr->line+start_col,min(curr->length-start_col,(end_col - start_col) + 1),fp)) == RC_DISK_FULL)
+                  break;
+               */
+               pos += len;
+            }
+            if ( pos + 1 + eol_len > clip_size)
+            {
+               ptr = (CHARTYPE *)realloc((DEFCHAR *)ptr, clip_size * 2);
+               if (!ptr)
+               {
+                  display_error(30,(CHARTYPE *)"",FALSE);
+#ifdef THE_TRACE
+                  trace_return();
+#endif
+                  return(RC_OUT_OF_MEMORY);
+               }
+               clip_size *= 2;
+            }
+            memcpy((DEFCHAR *)ptr+pos,(DEFCHAR *)eol,eol_len);
+            pos += eol_len;
+            num_actual_lines++;
+            break;
+    }
+/*---------------------------------------------------------------------*/
+/* Proceed to the next record, even if the current record not in scope.*/
+/*---------------------------------------------------------------------*/
+    if (rc) 
+       break;
+    if (direction == DIRECTION_BACKWARD)
+       curr = curr->prev;
+    else
+       curr = curr->next;
+    my_num_file_lines += (LINETYPE)direction;
+    if (curr == NULL)
+       break;
+ }
+/*---------------------------------------------------------------------*/
+/* Nul terminate the string.                                           */
+/*---------------------------------------------------------------------*/
+ *(ptr+pos) = '\0';
+/*---------------------------------------------------------------------*/
+/* Restore the setting of scope_all if we changed it before...         */
+/*---------------------------------------------------------------------*/
+ if (ignore_scope)
+    CURRENT_VIEW->scope_all = save_scope_all;
+
+#if defined(PDC_CLIP_SUCCESS) && !defined(DOS)
+ rc = PDC_setclipboard( (DEFCHAR *)ptr, pos );
+
+ switch( rc )
+ {
+    case PDC_CLIP_MEMORY_ERROR:
+       display_error(30,(CHARTYPE *)"",FALSE);
+       return(RC_OUT_OF_MEMORY);
+       break;
+    case PDC_CLIP_ACCESS_ERROR:
+       display_error(186,(CHARTYPE *)"",FALSE);
+       rc = RC_INVALID_ENVIRON;
+       break;
+    default:
+       rc = RC_OK;
+       break;
+ }
+#else
+ display_error(82,(CHARTYPE *)"CLIP:",FALSE);
+ rc = RC_INVALID_ENVIRON;
+#endif
+
+ free(ptr);
+#ifdef THE_TRACE
+ trace_return();
+#endif
+ return(rc);
+}
