@@ -3,7 +3,7 @@
 /***********************************************************************/
 /*
  * THE - The Hessling Editor. A text editor similar to VM/CMS xedit.
- * Copyright (C) 1991-1997 Mark Hessling
+ * Copyright (C) 1991-1999 Mark Hessling
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -29,11 +29,11 @@
  * This software is going to be maintained and enhanced as deemed
  * necessary by the community.
  *
- * Mark Hessling                 Email:             M.Hessling@qut.edu.au
- * PO Box 203                    Phone:                    +617 3802 0800
- * Bellara                       http://www.gu.edu.au/gext/the/markh.html
- * QLD 4507                      **** Maintainer PDCurses & REXX/SQL ****
- * Australia                     ************* Author of THE ************
+ * Mark Hessling,  M.Hessling@qut.edu.au  http://www.lightlink.com/hessling/
+ * PO Box 203, Bellara, QLD 4507, AUSTRALIA
+ * Author of THE, a Free XEDIT/KEDIT editor and, Rexx/SQL
+ * Maintainer of PDCurses: Public Domain Curses and, Regina Rexx interpreter
+ * Use Rexx ? join the Rexx Language Association: http://www.rexxla.org
  *
  *======================================================================
  * This code based heavily on sample code provided as part of the IBM 
@@ -42,9 +42,8 @@
  *
  */
 
-/*
-$Id: os2eas.c 2.1 1995/06/24 16:30:41 MH Rel MH $
-*/
+static char RCSid[] = "$Id: os2eas.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
+
 #ifdef __EMX__                                /* EMX has its own routines, which   */
                                       /* work in both read and protected   */
                                       /* mode.                             */
