@@ -1,6 +1,6 @@
 /*
  * THE - The Hessling Editor. A text editor similar to VM/CMS xedit.
- * Copyright (C) 1991-1997 Mark Hessling
+ * Copyright (C) 1991-1999 Mark Hessling
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -26,22 +26,22 @@
  * This software is going to be maintained and enhanced as deemed
  * necessary by the community.
  *
- * Mark Hessling                 Email:             M.Hessling@qut.edu.au
- * PO Box 203                    Phone:                    +617 3802 0800
- * Bellara                       http://www.gu.edu.au/gext/the/markh.html
- * QLD 4507                      **** Maintainer PDCurses & REXX/SQL ****
- * Australia                     ************* Author of THE ************
+ * Mark Hessling,  M.Hessling@qut.edu.au  http://www.lightlink.com/hessling/
+ * PO Box 203, Bellara, QLD 4507, AUSTRALIA
+ * Author of THE, a Free XEDIT/KEDIT editor and, Rexx/SQL
+ * Maintainer of PDCurses: Public Domain Curses and, Regina Rexx interpreter
+ * Use Rexx ? join the Rexx Language Association: http://www.rexxla.org
  */
 
 /*
-$Id: proto.h 2.1 1995/06/24 16:30:47 MH Rel MH $
+$Id: proto.h,v 1.2 1999/07/06 04:06:04 mark Exp mark $
 */
 
 #ifdef HAVE_PROTO
                                                          /* commutil.c */
-CHARTYPE *get_key_name(int);
+CHARTYPE *get_key_name(int,int *);
 CHARTYPE *get_key_definition(int,bool,bool,bool);
-short function_key(int,int);
+short function_key(int,int,bool);
 CHARTYPE *build_default_key_definition(int, CHARTYPE *);
 short display_all_keys(void);
 short command_line(CHARTYPE *,bool);
@@ -50,16 +50,10 @@ void split_command(CHARTYPE *,CHARTYPE *,CHARTYPE *);
 short param_split(CHARTYPE *,CHARTYPE *[],short,CHARTYPE *,CHARTYPE,CHARTYPE *,bool);
 short command_split(CHARTYPE *,CHARTYPE *[],short,CHARTYPE *,CHARTYPE *);
 LINETYPE get_true_line(bool);
-void print_line(bool ,LINETYPE,LINETYPE ,short ,CHARTYPE *,CHARTYPE *,short);
-#if defined(OS2) && !defined(__EMX__)
-void print_shadow_line(HFILE ,CHARTYPE *,LINETYPE);
-#else
-void print_shadow_line(FILE *,CHARTYPE *,LINETYPE);
-#endif
 CHARTYPE next_char(LINE *,long *,LENGTHTYPE);
 short add_define(DEFINE **,DEFINE **,int,CHARTYPE *,bool);
 short remove_define(DEFINE **,DEFINE **,int);
-short append_define(DEFINE **,DEFINE **,int,short,CHARTYPE *);
+short append_define(DEFINE **,DEFINE **,int,short,CHARTYPE *,CHARTYPE *,int);
 int find_key_value(CHARTYPE *);
 short find_command(CHARTYPE *,bool);
 void init_command(void);
@@ -79,13 +73,29 @@ short execute_set_sos_command(bool,CHARTYPE *);
 short valid_command_type(bool,CHARTYPE *);
 short allocate_temp_space(unsigned short,CHARTYPE);
 void free_temp_space(CHARTYPE);
+#ifdef MSWIN
+void init_temp_space(void);
+#endif
 CHARTYPE calculate_actual_row(CHARTYPE,short,CHARTYPE,bool);
-short get_valid_macro_file_name(CHARTYPE *,CHARTYPE *,short *);
+short get_valid_macro_file_name(CHARTYPE *,CHARTYPE *,CHARTYPE *,short *);
 bool define_command(CHARTYPE *);
 int find_key_name(CHARTYPE *);
-int readv_cmdline(CHARTYPE *);
+int readv_cmdline(CHARTYPE *, WINDOW *, int);
 short execute_mouse_commands(int);
 short validate_n_m(CHARTYPE *,short *,short *);
+
+                                                            /* print.c */
+#ifdef WIN32
+void StartTextPrnt(void);
+void StopTextPrnt(void);
+#endif
+void print_line(bool ,LINETYPE,LINETYPE ,short ,CHARTYPE *,CHARTYPE *,short);
+short setprintername(char*);
+short setfontname(char*);
+short setfontcpi(int);
+short setfontlpi(int);
+short setorient(char);
+short setpagesize(int);
                                                            /* target.c */
 short split_change_params(CHARTYPE *,CHARTYPE **,CHARTYPE **,TARGET *,LINETYPE *,LINETYPE *);
 short parse_target(CHARTYPE *,LINETYPE,TARGET *,short,bool,bool,bool);
@@ -100,20 +110,19 @@ bool find_rtarget_column_target(CHARTYPE *,LENGTHTYPE,TARGET *,LENGTHTYPE,LENGTH
 LINETYPE find_next_in_scope(VIEW_DETAILS *,LINE *,LINETYPE,short);
 LINETYPE find_last_not_in_scope(VIEW_DETAILS *,LINE *,LINETYPE,short);
 short validate_target(CHARTYPE *,TARGET *,short,LINETYPE,bool,bool);
-bool in_scope(VIEW_DETAILS *,LINE *);
 void calculate_scroll_values(short *,LINETYPE *,LINETYPE *,bool *,bool *,bool *,short);
 short find_first_focus_line(unsigned short *);
 short find_last_focus_line(unsigned short *);
 CHARTYPE find_unique_char(CHARTYPE *);
                                                          /* reserved.c */
-short add_reserved_line(CHARTYPE *,CHARTYPE *,short,short,COLOUR_ATTR *);
+RESERVED *add_reserved_line(CHARTYPE *,CHARTYPE *,short,short,COLOUR_ATTR *);
 RESERVED *find_reserved_line(CHARTYPE,bool,ROWTYPE,short,short);
 short delete_reserved_line(short,short);
+#ifdef CTLCHAR
+chtype *apply_ctlchar_to_reserved_line(RESERVED *);
+#endif
                                                               /* box.c */
 void box_operations(short ,CHARTYPE ,bool ,CHARTYPE );
-short box_delete(BOXP *);
-short box_move(BOXP *,bool);
-short box_fill(BOXP *,CHARTYPE);
                                                           /* execute.c */
 short execute_os_command(CHARTYPE *,bool ,bool );
 short execute_change_command(CHARTYPE *,bool );
@@ -121,6 +130,7 @@ short selective_change(CHARTYPE *,short,CHARTYPE *,short,LINETYPE ,LINETYPE ,sho
 short insert_new_line(CHARTYPE *,unsigned short,LINETYPE,LINETYPE,bool,bool,bool,CHARTYPE,bool,bool);
 short execute_makecurr(LINETYPE);
 short execute_shift_command(short,short,LINETYPE,LINETYPE,bool,short,bool);
+short execute_set_lineflag( unsigned int, unsigned int, unsigned int, LINETYPE, LINETYPE, bool, short );
 short execute_change_case(CHARTYPE *,CHARTYPE);
 short rearrange_line_blocks(CHARTYPE,CHARTYPE,LINETYPE,LINETYPE,LINETYPE,short,VIEW_DETAILS*,VIEW_DETAILS*,bool,LINETYPE *);
 short execute_set_point(CHARTYPE *,LINETYPE ,bool);
@@ -138,6 +148,9 @@ short execute_find_command(CHARTYPE *,short);
 short execute_modify_command(CHARTYPE *);
 LENGTHTYPE calculate_rec_len(short,LENGTHTYPE,LENGTHTYPE,LINETYPE);
 short execute_editv(short,bool,CHARTYPE *);
+short prepare_dialog(CHARTYPE *,bool,CHARTYPE *);
+short execute_dialog(CHARTYPE *,CHARTYPE *,CHARTYPE *,bool,short,short,CHARTYPE *,short,bool);
+short execute_popup(int , int , int , int , int , CHARTYPE **);
                                                           /* default.c */
 void set_global_defaults(void);
 void set_global_look_defaults(void);
@@ -150,22 +163,27 @@ short defaults_for_other_files(VIEW_DETAILS *);
 short default_file_attributes(FILE_DETAILS *);
 void set_screen_defaults(void);
 void set_defaults(void);
-short set_THE_defaults(int,int);
-short set_XEDIT_defaults(int,int);
-short set_KEDIT_defaults(int,int);
+short set_THE_key_defaults(int,int);
+short set_XEDIT_key_defaults(int,int);
+short set_KEDIT_key_defaults(int,int);
+short construct_default_parsers(void);
+short destroy_all_parsers(void);
+short construct_default_parser_mapping(void);
+CHARTYPE *find_default_parser(CHARTYPE *,CHARTYPE *);
                                                              /* edit.c */
 void editor(void);
-int process_key(int);
+int process_key(int,bool);
+short EditFile(CHARTYPE *,bool);
                                                             /* error.c */
 void display_error(unsigned short ,CHARTYPE *,bool);
-void clear_msgline(void);
+void clear_msgline(int);
 void display_prompt(CHARTYPE *);
 void expose_msgline(void);
                                                              /* file.c */
 short get_file(CHARTYPE *);
 LINE *read_file(FILE *,LINE *,CHARTYPE *,LINETYPE,LINETYPE,bool);
 LINE *read_fixed_file(FILE *,LINE *,CHARTYPE *,LINETYPE,LINETYPE);
-short save_file(FILE_DETAILS *,CHARTYPE *,bool,LINETYPE,LINETYPE,LINETYPE *,bool,LENGTHTYPE,LENGTHTYPE,bool,bool);
+short save_file(FILE_DETAILS *,CHARTYPE *,bool,LINETYPE,LINETYPE,LINETYPE *,bool,LENGTHTYPE,LENGTHTYPE,bool,bool,bool);
 void increment_alt(FILE_DETAILS *);
 CHARTYPE *new_filename(CHARTYPE *,CHARTYPE *,CHARTYPE *,CHARTYPE *);
 short remove_aus_file(FILE_DETAILS *);
@@ -176,6 +194,7 @@ short read_directory(void);
 VIEW_DETAILS *find_file(CHARTYPE *,CHARTYPE *);
 short execute_command_file(FILE *);
 short process_command_line(CHARTYPE *,short);
+CHARTYPE *read_file_into_memory(CHARTYPE *,int *);
                                                             /* getch.c */
 #if !defined(DOS) && !defined(OS2)
 int my_getch (WINDOW *);
@@ -193,10 +212,20 @@ short rename(CHARTYPE *,CHARTYPE *);
 bool LongFileNames(CHARTYPE *);
 bool IsPathAndFilenameValid(CHARTYPE *);
 #endif
+LINE *getclipboard(LINE *);
+short setclipboard(FILE_DETAILS *,CHARTYPE *,bool,LINETYPE,LINETYPE,LINETYPE *,bool,LENGTHTYPE,LENGTHTYPE,bool,bool);
+                                                           /* parser.c */
+short parse_line(CHARTYPE,FILE_DETAILS *,SHOW_LINE *,short);
+short parse_paired_comments(CHARTYPE,FILE_DETAILS *);
+short construct_parser(CHARTYPE *, int, PARSER_DETAILS **,CHARTYPE *,CHARTYPE *);
+short destroy_parser(PARSER_DETAILS *);
+bool find_parser_mapping(FILE_DETAILS *, PARSER_MAPPING *);
+PARSER_DETAILS *find_auto_parser(FILE_DETAILS *);
+short parse_reserved_line(RESERVED *);
                                                            /* prefix.c */
 short execute_prefix_commands(void);
-void clear_pending_prefix_command(PPC *,LINE *);
-PPC *delete_pending_prefix_command(PPC *,FILE_DETAILS *,LINE *);
+void clear_pending_prefix_command(THE_PPC *,LINE *);
+THE_PPC *delete_pending_prefix_command(THE_PPC *,FILE_DETAILS *,LINE *);
 void add_prefix_command(LINE *,LINETYPE,bool);
 short add_prefix_synonym(CHARTYPE *,CHARTYPE *);
 CHARTYPE *find_prefix_synonym(CHARTYPE *);
@@ -234,7 +263,10 @@ void init_colour_pairs(void);
 int setup_profile_files(CHARTYPE *);
 void cleanup(void);
 int allocate_working_memory(void);
+char **StringToArgv( int *, char* );
                                                              /* util.c */
+CHARTYPE *ebc2asc(CHARTYPE *, int, int, int);
+CHARTYPE *asc2ebc(CHARTYPE *, int, int, int);
 short memreveq(CHARTYPE *,CHARTYPE ,short );
 short memrevne(CHARTYPE *,CHARTYPE ,short );
 CHARTYPE *meminschr(CHARTYPE *,CHARTYPE ,short ,short ,short );
@@ -242,7 +274,7 @@ CHARTYPE *meminsmem(CHARTYPE *,CHARTYPE *,short ,short ,short ,short );
 CHARTYPE *memdeln(CHARTYPE *,short ,short,short );
 CHARTYPE *strdelchr(CHARTYPE *,CHARTYPE);
 CHARTYPE *memrmdup(CHARTYPE *,short *,CHARTYPE);
-CHARTYPE *strrmdup(CHARTYPE *,CHARTYPE);
+CHARTYPE *strrmdup(CHARTYPE *,CHARTYPE,bool);
 short strzne(CHARTYPE *,CHARTYPE );
 CHARTYPE *my_strdup(CHARTYPE *);
 short memne(CHARTYPE *,CHARTYPE ,short );
@@ -252,15 +284,16 @@ CHARTYPE *strtrunc(CHARTYPE *);
 CHARTYPE *MyStrip(CHARTYPE *,char,char);
 short memfind(CHARTYPE *,CHARTYPE *,short ,short ,bool ,bool ,CHARTYPE ,CHARTYPE);
 short memcmpi(CHARTYPE *,CHARTYPE *,short );
+short my_strcmpi(char *,char * );
 CHARTYPE *make_upper(CHARTYPE *);
 unsigned short equal(CHARTYPE *,CHARTYPE *,short );
 short valid_integer(CHARTYPE *);
 short valid_positive_integer(CHARTYPE *);
 short strzeq(CHARTYPE *,CHARTYPE );
 CHARTYPE *strtrans(CHARTYPE *,CHARTYPE,CHARTYPE);
-LINE *add_line(LINE *,LINE *,CHARTYPE *,LENGTHTYPE,SELECTTYPE,bool);
-LINE *append_line(LINE *,CHARTYPE *,LENGTHTYPE);
-LINE *delete_line(LINE *,LINE *,short);
+LINE *add_LINE(LINE *,LINE *,CHARTYPE *,LENGTHTYPE,SELECTTYPE,bool);
+LINE *append_LINE(LINE *,CHARTYPE *,LENGTHTYPE);
+LINE *delete_LINE(LINE *,LINE *,LINE *,short);
 void put_string(WINDOW *,short ,short ,CHARTYPE *,short);
 void put_char(WINDOW *,chtype ,CHARTYPE );
 short set_up_windows(short);
@@ -276,7 +309,11 @@ void add_to_recovery_list(CHARTYPE *,LENGTHTYPE);
 void get_from_recovery_list(short );
 void free_recovery_list(void);
 short my_wmove(WINDOW *,short ,short ,short ,short );
+short my_isalphanum(CHARTYPE);
 short get_row_for_tof_eof(short,CHARTYPE);
+int search_query_item_array(void *, size_t, size_t, const char *, int );
+int split_function_name(CHARTYPE *, int *);
+char *thetmpnam(char *);
 
 #if THIS_APPEARS_TO_NOT_BE_USED
 WINDOW *adjust_window(WINDOW *,short ,short ,short ,short );
@@ -301,49 +338,76 @@ VIEW_DETAILS *vll_del(VIEW_DETAILS **,VIEW_DETAILS **,VIEW_DETAILS *,short );
 DEFINE *dll_add(DEFINE *,DEFINE *,unsigned short );
 DEFINE *dll_del(DEFINE **,DEFINE **,DEFINE *,short );
 DEFINE *dll_free(DEFINE *);
-PPC *pll_add(PPC *,PPC *,unsigned short );
-PPC *pll_del(PPC **,PPC **,PPC *,short );
-PPC *pll_free(PPC *);
-PPC *pll_find(PPC *,LINETYPE);
+THE_PPC *pll_add(THE_PPC *,THE_PPC *,unsigned short );
+THE_PPC *pll_del(THE_PPC **,THE_PPC **,THE_PPC *,short );
+THE_PPC *pll_free(THE_PPC *);
+THE_PPC *pll_find(THE_PPC *,LINETYPE);
 RESERVED *rll_add(RESERVED *,RESERVED *,unsigned short );
 RESERVED *rll_del(RESERVED **,RESERVED **,RESERVED *,short );
 RESERVED *rll_free(RESERVED *);
 RESERVED *rll_find(RESERVED *,short);
+PARSER_DETAILS *parserll_add(PARSER_DETAILS *,PARSER_DETAILS *,unsigned short );
+PARSER_DETAILS *parserll_del(PARSER_DETAILS **,PARSER_DETAILS **,PARSER_DETAILS *,short );
+PARSER_DETAILS *parserll_free(PARSER_DETAILS *);
+PARSER_DETAILS *parserll_find(PARSER_DETAILS *,CHARTYPE *);
+PARSE_KEYWORDS *parse_keywordll_add(PARSE_KEYWORDS *,PARSE_KEYWORDS *,unsigned short );
+PARSE_KEYWORDS *parse_keywordll_del(PARSE_KEYWORDS **,PARSE_KEYWORDS **,PARSE_KEYWORDS *,short );
+PARSE_KEYWORDS *parse_keywordll_free(PARSE_KEYWORDS *);
+PARSE_FUNCTIONS *parse_functionll_add(PARSE_FUNCTIONS *,PARSE_FUNCTIONS *,unsigned short );
+PARSE_FUNCTIONS *parse_functionll_del(PARSE_FUNCTIONS **,PARSE_FUNCTIONS **,PARSE_FUNCTIONS *,short );
+PARSE_FUNCTIONS *parse_functionll_free(PARSE_FUNCTIONS *);
+PARSE_HEADERS *parse_headerll_add(PARSE_HEADERS *,PARSE_HEADERS *,unsigned short );
+PARSE_HEADERS *parse_headerll_free(PARSE_HEADERS *);
+PARSER_MAPPING *mappingll_add(PARSER_MAPPING *,PARSER_MAPPING *,unsigned short );
+PARSER_MAPPING *mappingll_del(PARSER_MAPPING **,PARSER_MAPPING **,PARSER_MAPPING *,short );
+PARSER_MAPPING *mappingll_free(PARSER_MAPPING *);
+PARSER_MAPPING *mappingll_find(PARSER_MAPPING *,CHARTYPE *,CHARTYPE *);
+PARSE_COMMENTS *parse_commentsll_add(PARSE_COMMENTS *,PARSE_COMMENTS *,unsigned short );
+PARSE_COMMENTS *parse_commentsll_del(PARSE_COMMENTS **,PARSE_COMMENTS **,PARSE_COMMENTS *,short );
+PARSE_COMMENTS *parse_commentsll_free(PARSE_COMMENTS *);
+PARSE_COMMENTS *parse_commentsll_find(PARSE_COMMENTS *,CHARTYPE *);
                                                              /* rexx.c */
+unsigned long MyRexxRegisterFunctionExe(CHARTYPE *);
+unsigned long MyRexxDeregisterFunction(CHARTYPE *);
 short initialise_rexx(void);
 short finalise_rexx(void);
-short execute_macro_file(CHARTYPE *,CHARTYPE *,short *);
-short execute_macro_instore(CHARTYPE *,short *);
+short execute_macro_file(CHARTYPE *,CHARTYPE *,short *,bool);
+short execute_macro_instore(CHARTYPE *,short *,CHARTYPE **,int *,int *,int);
 short get_rexx_variable(CHARTYPE *,CHARTYPE **,int *);
 short set_rexx_variable(CHARTYPE *,CHARTYPE *,short,short);
+CHARTYPE *get_rexx_interpreter_version(CHARTYPE *);
                                                            /* os2eas.c */
 #if defined(OS2)
 bool ReadEAs(CHARTYPE *);
 bool WriteEAs(CHARTYPE *);
 #endif
                                                             /* query.c */
-short find_item(CHARTYPE *,CHARTYPE);
+short find_query_item(CHARTYPE *,int,CHARTYPE *);
 short show_status(void);
 short save_status(CHARTYPE *);
 short set_extract_variables(short);
-short get_item_values(short,CHARTYPE *,CHARTYPE,LINETYPE,CHARTYPE *,LINETYPE);
+short get_item_values(int,short,CHARTYPE *,CHARTYPE,LINETYPE,CHARTYPE *,LINETYPE);
+int number_query_item( void );
+int number_function_item( void );
+void format_options( CHARTYPE * );
                                                          /* directry.c */
 short set_dirtype(CHARTYPE *);
-                                                          /* fnmatch.c */
-int fnmatch(CHARTYPE *,CHARTYPE *,int);
+CHARTYPE *get_dirtype(CHARTYPE *);
+                                                          /* thematch.c */
+int thematch(CHARTYPE *,CHARTYPE *,int);
                                                              /* sort.c */
 short execute_sort(CHARTYPE *);
                                                            /* cursor.c */
-short cursor_cmdline(short);
-short cursor_column(void);
-short cursor_down(bool);
-short cursor_file(LINETYPE,LENGTHTYPE);
-short cursor_home(bool);
-short cursor_left(bool,bool);
-short cursor_right(bool,bool);
-short cursor_up(bool);
-short cursor_move(bool,short,short);
-short cursor_mouse(void);
+short THEcursor_cmdline(short);
+short THEcursor_column(void);
+short THEcursor_down(bool);
+short THEcursor_file(LINETYPE,LENGTHTYPE);
+short THEcursor_home(bool);
+short THEcursor_left(bool,bool);
+short THEcursor_right(bool,bool);
+short THEcursor_up(bool);
+short THEcursor_move(bool,short,short);
+short THEcursor_mouse(void);
 long where_now(void);
 long what_current_now(void);
 long what_other_now(void);
@@ -358,15 +422,21 @@ short advance_current_or_focus_line(LINETYPE);
 void resolve_current_and_focus_lines(VIEW_DETAILS *, LINETYPE, LINETYPE , short, bool , bool);
                                                            /* colour.c */
 short parse_colours(CHARTYPE *,COLOUR_ATTR *,CHARTYPE **,bool,bool*);
-chtype set_colour(COLOUR_ATTR *);
+chtype merge_curline_colour(COLOUR_ATTR *, COLOUR_ATTR *);
 void set_up_default_colours(FILE_DETAILS *,COLOUR_ATTR *,int);
+void set_up_default_ecolours(FILE_DETAILS *);
 CHARTYPE *get_colour_strings(COLOUR_ATTR *);
                                                            /* column.c */
 short column_command(CHARTYPE *,int);
                                                             /* mouse.c */
+#if defined(NCURSES_MOUSE_VERSION)
+void wmouse_position(WINDOW *, int *, int *);
+#endif
 short THEMouse(CHARTYPE *);
 short get_mouse_info(int *,int *,int *);
 void which_window_is_mouse_in(CHARTYPE *,int *);
+void reset_saved_mouse_pos(void);
+void get_saved_mouse_pos(int *, int *);
 void initialise_mouse_commands(void);
 int mouse_info_to_key(int,int,int,int);
 CHARTYPE *mouse_key_number_to_name(int,CHARTYPE *);
@@ -382,10 +452,13 @@ void *resize_a_block( void *, int );
 void the_free_flists ( void );
                                                             /* comm*.c */
 short Add(CHARTYPE *);
+short Alert(CHARTYPE *);
 short All(CHARTYPE *);
 short Alt(CHARTYPE *);
 short Arbchar(CHARTYPE *);
+short Autocolour(CHARTYPE *);
 short Autosave(CHARTYPE *);
+short Autoscroll(CHARTYPE *);
 short Backup(CHARTYPE *);
 short Backward(CHARTYPE *);
 short BeepSound(CHARTYPE *);
@@ -399,6 +472,7 @@ short Cfirst(CHARTYPE *);
 short Change(CHARTYPE *);
 short Cinsert(CHARTYPE *);
 short Clast(CHARTYPE *);
+short Clearerrorkey(CHARTYPE *);
 short Clearscreen(CHARTYPE *);
 short Clocate(CHARTYPE *);
 short Clock(CHARTYPE *);
@@ -407,6 +481,7 @@ short Cmdarrows(CHARTYPE *);
 short Cmdline(CHARTYPE *);
 short Cmsg(CHARTYPE *);
 short Colour(CHARTYPE *);
+short Colouring(CHARTYPE *);
 short Compat(CHARTYPE *);
 short Compress(CHARTYPE *);
 short THECommand(CHARTYPE *);
@@ -414,16 +489,19 @@ short ControlChar(CHARTYPE *);
 short Copy(CHARTYPE *);
 short Coverlay(CHARTYPE *);
 short Creplace(CHARTYPE *);
+short Ctlchar(CHARTYPE *);
 short Curline(CHARTYPE *);
 short Cursor(CHARTYPE *);
 short CursorStay(CHARTYPE *);
 short Define(CHARTYPE *);
 short Defsort(CHARTYPE *);
 short DeleteLine(CHARTYPE *);
+short Dialog(CHARTYPE *);
 short Directory(CHARTYPE *);
 short Dirinclude(CHARTYPE *);
 short Display(CHARTYPE *);
 short Duplicate(CHARTYPE *);
+short Ecolour(CHARTYPE *);
 short Emsg(CHARTYPE *);
 short THEEditv(CHARTYPE *);
 short Enter(CHARTYPE *);
@@ -458,6 +536,7 @@ short Inputmode(CHARTYPE *);
 short Insertmode(CHARTYPE *);
 short Join(CHARTYPE *);
 short Left(CHARTYPE *);
+short Lineflag(CHARTYPE *);
 short Linend(CHARTYPE *);
 short Locate(CHARTYPE *);
 short Lowercase(CHARTYPE *);
@@ -487,8 +566,10 @@ short Os(CHARTYPE *);
 short Osnowait(CHARTYPE *);
 short Osquiet(CHARTYPE *);
 short Osredir(CHARTYPE *);
+short Parser(CHARTYPE *);
 short Pending(CHARTYPE *);
 short Point(CHARTYPE *);
+short Popup(CHARTYPE *);
 short Position(CHARTYPE *);
 short Prefix(CHARTYPE *);
 short Preserve(CHARTYPE *);
@@ -501,6 +582,7 @@ short Putd(CHARTYPE *);
 short Qquit(CHARTYPE *);
 short Quit(CHARTYPE *);
 short Query(CHARTYPE *);
+short THEReadonly(CHARTYPE *);
 short Readv(CHARTYPE *);
 short Recover(CHARTYPE *);
 short Reexecute(CHARTYPE *);
@@ -573,6 +655,7 @@ short Spill(CHARTYPE *);
 short Split(CHARTYPE *);
 short Spltjoin(CHARTYPE *);
 short Ssave(CHARTYPE *);
+short Statopt(CHARTYPE *);
 short Status(CHARTYPE *);
 short Statusline(CHARTYPE *);
 short Stay(CHARTYPE *);
@@ -584,7 +667,11 @@ short Tabpre(CHARTYPE *);
 short Tabs(CHARTYPE *);
 short Tabsin(CHARTYPE *);
 short Tabsout(CHARTYPE *);
+short Tag(CHARTYPE *);
 short Text(CHARTYPE *);
+short Timecheck(CHARTYPE *);
+short Toascii(CHARTYPE *);
+short Tofeof(CHARTYPE *);
 short Top(CHARTYPE *);
 short Trunc(CHARTYPE *);
 short THETypeahead(CHARTYPE *);
@@ -614,8 +701,6 @@ void split_command();
 short param_split();
 short command_split();
 LINETYPE get_true_line();
-void print_line();
-void print_shadow_line();
 CHARTYPE next_char();
 short add_define();
 short remove_define();
@@ -646,6 +731,19 @@ int find_key_name();
 int readv_cmdline();
 short execute_mouse_commands();
 short validate_n_m();
+
+                                                            /* print.c */
+#ifdef WIN32
+void StartTextPrnt();
+void StopTextPrnt();
+#endif
+void print_line();
+short setprintername();
+short setfontname();
+short setfontcpi();
+short setfontlpi();
+short setorient();
+short setpagesize();
                                                            /* target.c */
 short split_change_params();
 short parse_target();
@@ -660,20 +758,19 @@ bool find_rtarget_column_target();
 LINETYPE find_next_in_scope();
 LINETYPE find_last_not_in_scope();
 short validate_target();
-bool in_scope();
 void calculate_scroll_values();
 short find_first_focus_line();
 short find_last_focus_line();
 CHARTYPE find_unique_char();
                                                          /* reserved.c */
-short add_reserved_line();
+RESERVED *add_reserved_line();
 RESERVED *find_reserved_line();
 short delete_reserved_line();
+#ifdef CTLCHAR
+chtype *apply_ctlchar_to_reserved_line();
+#endif
                                                               /* box.c */
 void box_operations();
-short box_delete();
-short box_move();
-short box_fill();
                                                           /* execute.c */
 short execute_os_command();
 short execute_change_command();
@@ -681,6 +778,7 @@ short selective_change();
 short insert_new_line();
 short execute_makecurr();
 short execute_shift_command();
+short execute_set_lineflag();
 short execute_change_case();
 short rearrange_line_blocks();
 short execute_set_point();
@@ -698,6 +796,9 @@ short execute_find_command();
 short execute_modify_command();
 LENGTHTYPE calculate_rec_len();
 short execute_editv();
+short prepare_dialog();
+short execute_dialog();
+short execute_popup();
                                                           /* default.c */
 void set_global_defaults();
 void set_global_look_defaults();
@@ -710,12 +811,17 @@ short defaults_for_other_files();
 short default_file_attributes();
 void set_screen_defaults();
 void set_defaults();
-short set_THE_defaults();
-short set_XEDIT_defaults();
-short set_KEDIT_defaults();
+short set_THE_key_defaults();
+short set_XEDIT_key_defaults();
+short set_KEDIT_key_defaults();
+short construct_default_parsers();
+short destroy_all_parsers();
+short construct_default_parser_mapping();
+CHARTYPE *find_default_parser();
                                                              /* edit.c */
 void editor();
 int process_key();
+short EditFile();
                                                             /* error.c */
 void display_error();
 void clear_msgline();
@@ -736,6 +842,7 @@ short read_directory();
 VIEW_DETAILS *find_file();
 short execute_command_file();
 short process_command_line();
+CHARTYPE *read_file_into_memory();
                                                             /* getch.c */
 #if !defined(DOS) && !defined(OS2)
 int my_getch ();
@@ -753,10 +860,20 @@ short rename();
 bool LongFileNames();
 bool IsPathAndFilenameValid();
 #endif
+LINE *getclipboard();
+short setclipboard();
+                                                           /* parser.c */
+short parse_line();
+short parse_paired_comments();
+short construct_parser();
+short destroy_parser();
+bool find_parser_mapping();
+PARSER_DETAILS *find_auto_parser();
+short parse_reserved_line();
                                                            /* prefix.c */
 short execute_prefix_commands();
 void clear_pending_prefix_command();
-PPC *delete_pending_prefix_command();
+THE_PPC *delete_pending_prefix_command();
 void add_prefix_command();
 short add_prefix_synonym();
 CHARTYPE *find_prefix_synonym();
@@ -794,7 +911,10 @@ void init_colour_pairs();
 void display_info();
 void cleanup();
 int allocate_working_memory();
+char **StringToArgv();
                                                              /* util.c */
+CHARTYPE *ebc2asc();
+CHARTYPE *asc2ebc();
 short memreveq();
 short memrevne();
 CHARTYPE *meminschr();
@@ -812,15 +932,16 @@ CHARTYPE *strtrunc();
 CHARTYPE *MyStrip();
 short memfind();
 short memcmpi();
+short my_strcmpi();
 CHARTYPE *make_upper();
 unsigned short equal();
 short valid_integer();
 short valid_positive_integer();
 short strzeq();
 CHARTYPE *strtrans();
-LINE *add_line();
-LINE *append_line();
-LINE *delete_line();
+LINE *add_LINE();
+LINE *append_LINE();
+LINE *delete_LINE();
 void put_string();
 void put_char();
 short set_up_windows();
@@ -835,8 +956,12 @@ CHARTYPE case_translate();
 void add_to_recovery_list();
 void get_from_recovery_list();
 void free_recovery_list();
+short my_isalphanum();
 short my_wmove();
 short get_row_for_tof_eof();
+int search_query_item_array();
+int split_function_name();
+char *thetmpnam();
 
 #if THIS_APPEARS_TO_NOT_BE_USED
 WINDOW *adjust_window();
@@ -861,44 +986,69 @@ VIEW_DETAILS *vll_del();
 DEFINE *dll_add();
 DEFINE *dll_del();
 DEFINE *dll_free();
-PPC *pll_add();
-PPC *pll_del();
-PPC *pll_free();
-PPC *pll_find();
+THE_PPC *pll_add();
+THE_PPC *pll_del();
+THE_PPC *pll_free();
+THE_PPC *pll_find();
 RESERVED *rll_add();
 RESERVED *rll_del();
 RESERVED *rll_free();
 RESERVED *rll_find();
+PARSER_DETAILS *parserll_add();
+PARSER_DETAILS *parserll_del();
+PARSER_DETAILS *parserll_free();
+PARSER_DETAILS *parserll_find();
+PARSE_KEYWORDS *parse_keywordll_add();
+PARSE_KEYWORDS *parse_keywordll_del();
+PARSE_KEYWORDS *parse_keywordll_free();
+PARSE_FUNCTIONS *parse_functionll_add();
+PARSE_FUNCTIONS *parse_functionll_del();
+PARSE_FUNCTIONS *parse_functionll_free();
+PARSER_MAPPING *mappingll_add();
+PARSER_MAPPING *mappingll_del();
+PARSER_MAPPING *mappingll_free();
+PARSER_MAPPING *mappingll_find();
+PARSE_COMMENTS *parse_commentsll_add();
+PARSE_COMMENTS *parse_commentsll_del();
+PARSE_COMMENTS *parse_commentsll_free();
+PARSE_COMMENTS *parse_commentsll_find();
                                                              /* rexx.c */
+unsigned long MyRexxRegisterFunctionExe();
+unsigned long MyRexxDeregisterFunctionExe();
 short initialise_rexx();
 short finalise_rexx();
 short execute_macro_file();
 short execute_macro_instore();
 short get_rexx_variable();
 short set_rexx_variable();
+CHARTYPE *get_rexx_interpreter_version();
                                                             /* query.c */
-short find_item();
+short find_query_item();
 short show_status();
 short save_status();
 short set_extract_variables();
 short get_item_values();
+int number_query_item( );
+int number_function_item( );
+void format_options( );
                                                          /* directry.c */
 short set_dirtype();
-                                                          /* fnmatch.c */
-int fnmatch();
+CHARTYPE *get_dirtype();
+                                                          /* thematch.c */
+int thematch();
                                                              /* sort.c */
 short execute_sort();
                                                            /* cursor.c */
-short cursor_cmdline();
-short cursor_column();
-short cursor_down();
-short cursor_file();
-short cursor_home();
-short cursor_left();
-short cursor_right();
-short cursor_up();
-short cursor_move();
-short cursor_mouse();
+short THEcursor_cmdline();
+short THEcursor_column();
+short THEcursor_down();
+short THEcursor_file();
+short THEcursor_home();
+short THEcursor_left();
+short THEcursor_right();
+short THEcursor_up();
+short THEcursor_move();
+short THEcursor_mouse();
 long where_now();
 long what_current_now();
 long what_other_now();
@@ -913,15 +1063,21 @@ short advance_current_or_focus_line();
 void resolve_current_and_focus_lines();
                                                            /* colour.c */
 short parse_colours();
-chtype set_colour();
+chtype merge_curline_colour();
 void set_up_default_colours();
+void set_up_default_ecolours();
 CHARTYPE *get_colour_strings();
                                                            /* column.c */
 short column_command();
                                                             /* mouse.c */
+#if defined(NCURSES_MOUSE_VERSION)
+void wmouse_position();
+#endif
 short THEMouse();
 short get_mouse_info();
 void which_window_is_mouse_in();
+void reset_saved_mouse_pos();
+void get_saved_mouse_pos();
 void initialise_mouse_commands();
 int mouse_info_to_key();
 CHARTYPE *mouse_key_number_to_name();
@@ -937,10 +1093,13 @@ void *resize_a_block();
 void the_free_flists ();
                                                             /* comm*.c */
 short Add();
+short Alert();
 short All();
 short Alt();
 short Arbchar();
+short Autocolour();
 short Autosave();
+short Autoscroll();
 short Backup();
 short Backward();
 short BeepSound();
@@ -954,6 +1113,7 @@ short Cfirst();
 short Change();
 short Cinsert();
 short Clast();
+short Clearerrorkey();
 short Clearscreen();
 short Clocate();
 short Clock();
@@ -962,6 +1122,7 @@ short Cmdarrows();
 short Cmdline();
 short Cmsg();
 short Colour();
+short Colouring();
 short Compat();
 short Compress();
 short THECommand();
@@ -969,17 +1130,20 @@ short ControlChar();
 short Copy();
 short Coverlay();
 short Creplace();
+short Ctlchar();
 short Curline();
 short Cursor();
 short CursorStay();
 short Define();
 short Defsort();
 short DeleteLine();
+short Dialog();
 short Directory();
 short Dirinclude();
 short Display();
 short Duplicate();
 short THEEditv();
+short Ecolour();
 short Emsg();
 short Enter();
 short Eolout();
@@ -1013,6 +1177,7 @@ short Inputmode();
 short Insertmode();
 short Join();
 short Left();
+short Lineflag();
 short Linend();
 short Locate();
 short Lowercase();
@@ -1037,13 +1202,16 @@ short Nomsg();
 short Nondisp();
 short Nop();
 short Number();
+short THEOptions();
 short Overlaybox();
 short Os();
 short Osnowait();
 short Osquiet();
 short Osredir();
+short Parser();
 short Pending();
 short Point();
+short Popup();
 short Position();
 short Prefix();
 short Preserve();
@@ -1056,6 +1224,7 @@ short Putd();
 short Qquit();
 short Quit();
 short Query();
+short THEReadonly();
 short Readv();
 short Recover();
 short Reexecute();
@@ -1128,6 +1297,7 @@ short Spill();
 short Split();
 short Spltjoin();
 short Ssave();
+short Statopt();
 short Status();
 short Statusline();
 short Stay();
@@ -1139,7 +1309,11 @@ short Tabpre();
 short Tabs();
 short Tabsin();
 short Tabsout();
+short Tag();
 short Text();
+short Timecheck();
+short Toascii();
+short Tofeof();
 short Top();
 short Trunc();
 short THETypeahead();
