@@ -3,7 +3,7 @@
 /***********************************************************************/
 /*
  * THE - The Hessling Editor. A text editor similar to VM/CMS xedit.
- * Copyright (C) 1991-1997 Mark Hessling
+ * Copyright (C) 1991-1999 Mark Hessling
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -29,16 +29,14 @@
  * This software is going to be maintained and enhanced as deemed
  * necessary by the community.
  *
- * Mark Hessling                 Email:             M.Hessling@qut.edu.au
- * PO Box 203                    Phone:                    +617 3802 0800
- * Bellara                       http://www.gu.edu.au/gext/the/markh.html
- * QLD 4507                      **** Maintainer PDCurses & REXX/SQL ****
- * Australia                     ************* Author of THE ************
+ * Mark Hessling,  M.Hessling@qut.edu.au  http://www.lightlink.com/hessling/
+ * PO Box 203, Bellara, QLD 4507, AUSTRALIA
+ * Author of THE, a Free XEDIT/KEDIT editor and, Rexx/SQL
+ * Maintainer of PDCurses: Public Domain Curses and, Regina Rexx interpreter
+ * Use Rexx ? join the Rexx Language Association: http://www.rexxla.org
  */
 
-/*
-$Id: sort.c 2.1 1995/06/24 16:31:17 MH Rel MH $
-*/
+static char RCSid[] = "$Id: sort.c,v 1.1 1999/06/25 06:11:56 mark Exp mark $";
 
 #include <the.h>
 #include <proto.h>
@@ -80,7 +78,6 @@ void *first,*second;
 #endif
 /***********************************************************************/
 {
-/*-------------------------- external data ----------------------------*/
 /*--------------------------- local data ------------------------------*/
  register short i=0,j=0;
  short len=0,rc=RC_OK;
@@ -165,9 +162,6 @@ short execute_sort(params)
 #endif
 /***********************************************************************/
 {
-/*-------------------------- external data ----------------------------*/
- extern CHARTYPE *temp_cmd;
- extern VIEW_DETAILS *vd_mark;
 /*--------------------------- local data ------------------------------*/
 #define STATE_REAL   0
 #define STATE_SHADOW 1
@@ -193,7 +187,7 @@ short execute_sort(params)
  bool lines_based_on_scope=FALSE;
  short state=STATE_REAL;
 /*--------------------------- processing ------------------------------*/
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_function("sort.c:    execute_sort");
 #endif
 /*---------------------------------------------------------------------*/
@@ -204,7 +198,7 @@ short execute_sort(params)
  if (rc != RC_OK)
    {
     free_target(&target);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_INVALID_OPERAND);
@@ -220,7 +214,7 @@ short execute_sort(params)
    {
     free_target(&target);
     display_error(55,(CHARTYPE *)"",FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_OK);
@@ -280,7 +274,7 @@ short execute_sort(params)
 /*---------------------------------------------------------------------*/
            display_error(1,(CHARTYPE *)word[0],FALSE);
            free_target(&target);
-#ifdef TRACE
+#ifdef THE_TRACE
            trace_return();
 #endif
            return(RC_INVALID_OPERAND);
@@ -358,7 +352,7 @@ short execute_sort(params)
                 {
                  free_target(&target);
                  display_error(1,(CHARTYPE *)word[i],FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
                  trace_return();
 #endif
                  return(RC_INVALID_OPERAND);
@@ -380,7 +374,7 @@ short execute_sort(params)
                    {
                     free_target(&target);
                     display_error(1,strtrunc(target.rt[target.spare].string),FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
                     trace_return();
 #endif
                     return(RC_INVALID_OPERAND);
@@ -403,7 +397,7 @@ short execute_sort(params)
    {
     free_target(&target);
     display_error(30,(CHARTYPE *)"",FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_OUT_OF_MEMORY);
@@ -412,7 +406,7 @@ short execute_sort(params)
    {
     free_target(&target);
     display_error(30,(CHARTYPE *)"",FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_OUT_OF_MEMORY);
@@ -430,7 +424,7 @@ short execute_sort(params)
    {
     free_target(&target);
     display_error(30,(CHARTYPE *)"",FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_OUT_OF_MEMORY);
@@ -439,7 +433,7 @@ short execute_sort(params)
    {
     free_target(&target);
     display_error(30,(CHARTYPE *)"",FALSE);
-#ifdef TRACE
+#ifdef THE_TRACE
     trace_return();
 #endif
     return(RC_OUT_OF_MEMORY);
@@ -469,9 +463,15 @@ short execute_sort(params)
             break;
        default:
             lp[num_sorted_lines] = curr;
+#if 0
             memcpy(origlp++,&curr,sizeof(LINE*));
             memcpy(origlp++,&curr->next,sizeof(LINE*));
             memcpy(origlp++,&curr->prev,sizeof(LINE*));
+#else
+            *origlp++ = curr;
+            *origlp++ = curr->next;
+            *origlp++ = curr->prev;
+#endif
             num_actual_lines++;
             num_sorted_lines++;
             break;
@@ -487,7 +487,6 @@ short execute_sort(params)
         break;
    }
  last = curr;
- origlp = origfirst;
  save_num_sorted_lines = num_sorted_lines;
  origlp = origfirst;
 /*---------------------------------------------------------------------*/
@@ -601,7 +600,7 @@ short execute_sort(params)
 
  sprintf((DEFCHAR *)temp_cmd,"%ld line(s) sorted",abs_num_lines);
  display_error(0,temp_cmd,TRUE);
-#ifdef TRACE
+#ifdef THE_TRACE
  trace_return();
 #endif
  return(RC_OK);
